Plugin class abstract

Implementers

Constructors

Plugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageCreated(Page page) → Future<void>
toString() → String
A string representation of this object.
inherited
willLaunchBrowser(LaunchOptions options) → FutureOr<LaunchOptions>

Operators

operator ==(Object other) → bool
The equality operator.
inherited