AXNodeData class

A node in the accessibility tree.

Constructors

AXNodeData({required AXNodeId nodeId, required bool ignored, List<AXProperty>? ignoredReasons, AXValue? role, AXValue? chromeRole, AXValue? name, AXValue? description, AXValue? value, List<AXProperty>? properties, AXNodeId? parentId, List<AXNodeId>? childIds, BackendNodeId? backendDOMNodeId, FrameId? frameId})
AXNodeData.fromJson(Map<String, dynamic> json)
factory

Properties

backendDOMNodeId → BackendNodeId?
The backend ID for the associated DOM node, if any.
final
childIds → List<AXNodeId>?
IDs for each of this node's child nodes.
final
chromeRole → AXValue?
This Node's Chrome raw role.
final
description → AXValue?
The accessible description for this Node.
final
frameId → FrameId?
The frame ID for the frame associated with this nodes document.
final
hashCode → int
The hash code for this object.
no setterinherited
ignored → bool
Whether this node is ignored for accessibility
final
ignoredReasons → List<AXProperty>?
Collection of reasons why this node is hidden.
final
name → AXValue?
The accessible name for this Node.
final
nodeId → AXNodeId
Unique identifier for this node.
final
parentId → AXNodeId?
ID for this node's parent.
final
properties → List<AXProperty>?
All other properties
final
role → AXValue?
This Node's role, whether explicit or implicit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → AXValue?
The value for this Node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited