AXRelatedNode class

Constructors

AXRelatedNode({required BackendNodeId backendDOMNodeId, String? idref, String? text})
AXRelatedNode.fromJson(Map<String, dynamic> json)
factory

Properties

backendDOMNodeId → BackendNodeId
The BackendNodeId of the related DOM node.
final
hashCode → int
The hash code for this object.
no setterinherited
idref → String?
The IDRef value provided, if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
The text alternative of this node in the current context.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited