AXValueSource class

A single source for a computed AX property.

Constructors

AXValueSource({required AXValueSourceType type, AXValue? value, String? attribute, AXValue? attributeValue, bool? superseded, AXValueNativeSourceType? nativeSource, AXValue? nativeSourceValue, bool? invalid, String? invalidReason})
AXValueSource.fromJson(Map<String, dynamic> json)
factory

Properties

attribute → String?
The name of the relevant attribute, if any.
final
attributeValue → AXValue?
The value of the relevant attribute, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
invalid → bool?
Whether the value for this property is invalid.
final
invalidReason → String?
Reason for the value being invalid, if it is.
final
nativeSource → AXValueNativeSourceType?
The native markup source for this value, e.g. a <label> element.
final
nativeSourceValue → AXValue?
The value, such as a node or node list, of the native source.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
superseded → bool?
Whether this source is superseded by a higher priority source.
final
type → AXValueSourceType
What type of source this is.
final
value → AXValue?
The value of this property source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited