initialOrigin property
The initial origin of the frame. To minimize the payload size, this is only sent once per frame.
Implementation
final String? initialOrigin;
The initial origin of the frame. To minimize the payload size, this is only sent once per frame.
final String? initialOrigin;