AdMetrics class

Ad metrics for a page.

Constructors

AdMetrics({required int viewportAdDensityByArea, required num averageViewportAdDensityByArea, required int viewportAdCount, required num averageViewportAdCount, required num totalAdCpuTime, required num totalAdNetworkBytes, required List<AdFrameData> updateAdFrames, required List<FrameId> removeAdFrames})
AdMetrics.fromJson(Map<String, dynamic> json)
factory

Properties

averageViewportAdCount num
The time-weighted average of the viewport ad count, measured across the duration of the page.
final
averageViewportAdDensityByArea num
The time-weighted average of the viewport ad density by area, measured across the duration of the page.
final
hashCode int
The hash code for this object.
no setterinherited
removeAdFrames List<FrameId>
The list of ad frame IDs that have been removed since the last event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAdCpuTime num
The total ad CPU usage, in milliseconds.
final
totalAdNetworkBytes num
The total ad network bytes.
final
updateAdFrames List<AdFrameData>
The list of ad frames that have been updated since the last event.
final
viewportAdCount int
The number of ads currently visible within the viewport.
final
viewportAdDensityByArea int
The viewport ad density by area, represented as a percentage (an integer between 0 and 100).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited