updateAdFrames property
The list of ad frames that have been updated since the last event.
Implementation
final List<AdFrameData> updateAdFrames;
The list of ad frames that have been updated since the last event.
final List<AdFrameData> updateAdFrames;