Animation class

Animation instance.

Constructors

Animation({required String id, required String name, required bool pausedState, required String playState, required num playbackRate, required num startTime, required num currentTime, required AnimationType type, AnimationEffect? source, String? cssId, ViewOrScrollTimeline? viewOrScrollTimeline})
Animation.fromJson(Map<String, dynamic> json)
factory

Properties

cssId → String?
A unique ID for Animation representing the sources that triggered this CSS animation/transition.
final
currentTime → num
Animation's current time.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Animation's id.
final
name → String
Animation's name.
final
pausedState → bool
Animation's internal paused state.
final
playbackRate → num
Animation's playback rate.
final
playState → String
Animation's play state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → AnimationEffect?
Animation's source animation node.
final
startTime → num
Animation's start time. Milliseconds for time based animations and percentage 0 - 100 for scroll driven animations (i.e. when viewOrScrollTimeline exists).
final
type → AnimationType
Animation type of Animation.
final
viewOrScrollTimeline → ViewOrScrollTimeline?
View or scroll timeline
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited