AnimationEffect class

AnimationEffect instance

Constructors

AnimationEffect({required num delay, required num endDelay, required num iterationStart, num? iterations, required num duration, required String direction, required String fill, BackendNodeId? backendNodeId, KeyframesRule? keyframesRule, required String easing})
AnimationEffect.fromJson(Map<String, dynamic> json)
factory

Properties

backendNodeId → BackendNodeId?
AnimationEffect's target node.
final
delay → num
AnimationEffect's delay.
final
direction → String
AnimationEffect's playback direction.
final
duration → num
AnimationEffect's iteration duration. Milliseconds for time based animations and percentage 0 - 100 for scroll driven animations (i.e. when viewOrScrollTimeline exists).
final
easing → String
AnimationEffect's timing function.
final
endDelay → num
AnimationEffect's end delay.
final
fill → String
AnimationEffect's fill mode.
final
hashCode → int
The hash code for this object.
no setterinherited
iterations → num?
AnimationEffect's iterations. Omitted if the value is infinite.
final
iterationStart → num
AnimationEffect's iteration start.
final
keyframesRule → KeyframesRule?
AnimationEffect's keyframes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited