ViewOrScrollTimeline class

Timeline instance

Constructors

ViewOrScrollTimeline({BackendNodeId? sourceNodeId, num? startOffset, num? endOffset, BackendNodeId? subjectNodeId, required ScrollOrientation axis})
ViewOrScrollTimeline.fromJson(Map<String, dynamic> json)
factory

Properties

axis → ScrollOrientation
Orientation of the scroll
final
endOffset → num?
Represents the ending scroll position of the timeline as a length offset in pixels from scroll origin.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNodeId → BackendNodeId?
Scroll container node
final
startOffset → num?
Represents the starting scroll position of the timeline as a length offset in pixels from scroll origin.
final
subjectNodeId → BackendNodeId?
The element whose principal box's visibility in the scrollport defined the progress of the timeline. Does not exist for animations with ScrollTimeline
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited