AdScriptIdentifier class

Metadata about the ad script that was on the stack that caused the current script in the AdAncestry to be considered ad related.

Constructors

AdScriptIdentifier({required ScriptId scriptId, required UniqueDebuggerId debuggerId, required String name})
AdScriptIdentifier.fromJson(Map<String, dynamic> json)
factory

Properties

debuggerId UniqueDebuggerId
v8's debugging id for the v8::Context.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The script's url (or generated name based on id if inline script).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptId ScriptId
The script's v8 identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited