ContentSecurityPolicyIssueDetails class

Constructors

ContentSecurityPolicyIssueDetails({String? blockedURL, required String violatedDirective, required bool isReportOnly, required ContentSecurityPolicyViolationType contentSecurityPolicyViolationType, AffectedFrame? frameAncestor, SourceCodeLocation? sourceCodeLocation, BackendNodeId? violatingNodeId})
ContentSecurityPolicyIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

blockedURL → String?
The url not included in allowed sources.
final
contentSecurityPolicyViolationType → ContentSecurityPolicyViolationType
final
frameAncestor → AffectedFrame?
final
hashCode → int
The hash code for this object.
no setterinherited
isReportOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCodeLocation → SourceCodeLocation?
final
violatedDirective → String
Specific directive that is violated, causing the CSP issue.
final
violatingNodeId → BackendNodeId?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited