CookieIssueInsight class

Information about the suggested solution to a cookie issue.

Constructors

CookieIssueInsight({required InsightType type, String? tableEntryUrl})
CookieIssueInsight.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableEntryUrl → String?
Link to table entry in third-party cookie migration readiness list.
final
type → InsightType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited