ElementAccessibilityIssueDetails class

This issue warns about errors in the select or summary element content model.

Constructors

ElementAccessibilityIssueDetails({required BackendNodeId nodeId, required ElementAccessibilityIssueReason elementAccessibilityIssueReason, required bool hasDisallowedAttributes})
ElementAccessibilityIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

elementAccessibilityIssueReason → ElementAccessibilityIssueReason
final
hasDisallowedAttributes → bool
final
hashCode → int
The hash code for this object.
no setterinherited
nodeId → BackendNodeId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited