GenericIssueDetails class

Depending on the concrete errorType, different properties are set.

Constructors

GenericIssueDetails({required GenericIssueErrorType errorType, FrameId? frameId, BackendNodeId? violatingNodeId, String? violatingNodeAttribute, AffectedRequest? request})
GenericIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

errorType → GenericIssueErrorType
Issues with the same errorType are aggregated in the frontend.
final
frameId → FrameId?
final
hashCode → int
The hash code for this object.
no setterinherited
request → AffectedRequest?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
violatingNodeAttribute → String?
final
violatingNodeId → BackendNodeId?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited