GenericIssueErrorType enum
Values
- formLabelForNameError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormLabelForNameError') - formDuplicateIdForInputError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormDuplicateIdForInputError') - formInputWithNoLabelError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormInputWithNoLabelError') - formAutocompleteAttributeEmptyError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormAutocompleteAttributeEmptyError') - formEmptyIdAndNameAttributesForInputError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormEmptyIdAndNameAttributesForInputError') - formAriaLabelledByToNonExistingIdError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormAriaLabelledByToNonExistingIdError') - formInputAssignedAutocompleteValueToIdOrNameAttributeError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormInputAssignedAutocompleteValueToIdOrNameAttributeError') - formLabelHasNeitherForNorNestedInputError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormLabelHasNeitherForNorNestedInputError') - formLabelForMatchesNonExistingIdError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormLabelForMatchesNonExistingIdError') - formInputHasWrongButWellIntendedAutocompleteValueError → const GenericIssueErrorType
-
const GenericIssueErrorType('FormInputHasWrongButWellIntendedAutocompleteValueError') - responseWasBlockedByOrb → const GenericIssueErrorType
-
const GenericIssueErrorType('ResponseWasBlockedByORB') -
const GenericIssueErrorType('NavigationEntryMarkedSkippable') - autofillAndManualTextPolicyControlledFeaturesInfo → const GenericIssueErrorType
-
const GenericIssueErrorType('AutofillAndManualTextPolicyControlledFeaturesInfo') - autofillPolicyControlledFeatureInfo → const GenericIssueErrorType
-
const GenericIssueErrorType('AutofillPolicyControlledFeatureInfo') - manualTextPolicyControlledFeatureInfo → const GenericIssueErrorType
-
const GenericIssueErrorType('ManualTextPolicyControlledFeatureInfo')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GenericIssueErrorType> - A constant List of the values in this enum, in order of their declaration.