GetEncodedResponseResult class

Constructors

GetEncodedResponseResult({String? body, required int originalSize, required int encodedSize})
GetEncodedResponseResult.fromJson(Map<String, dynamic> json)
factory

Properties

body → String?
The encoded body as a base64 string. Omitted if sizeOnly is true.
final
encodedSize → int
Size after re-encoding.
final
hashCode → int
The hash code for this object.
no setterinherited
originalSize → int
Size before re-encoding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited