InspectorIssue class

An inspector issue reported from the back-end.

Constructors

InspectorIssue({required InspectorIssueCode code, required InspectorIssueDetails details, IssueId? issueId})
InspectorIssue.fromJson(Map<String, dynamic> json)
factory

Properties

code → InspectorIssueCode
final
details → InspectorIssueDetails
final
hashCode → int
The hash code for this object.
no setterinherited
issueId → IssueId?
A unique id for this issue. May be omitted if no other entity (e.g. exception, CDP message, etc.) is referencing this issue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited