PermissionElementIssueDetails class

This issue warns about improper usage of the <permission> element.

Constructors

PermissionElementIssueDetails({required PermissionElementIssueType issueType, String? type, BackendNodeId? nodeId, bool? isWarning, String? permissionName, String? occluderNodeInfo, String? occluderParentNodeInfo, String? disableReason})
PermissionElementIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

disableReason String?
Used for messages about activation disabled reason
final
hashCode int
The hash code for this object.
no setterinherited
issueType PermissionElementIssueType
final
isWarning bool?
True if the issue is a warning, false if it is an error.
final
nodeId BackendNodeId?
The node ID of the <permission> element.
final
occluderNodeInfo String?
Used for messages about occlusion
final
occluderParentNodeInfo String?
Used for messages about occluder's parent
final
permissionName String?
Fields for message construction: Used for messages that reference a specific permission name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The value of the type attribute.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited