PropertyRuleIssueDetails class

This issue warns about errors in property rules that lead to property registrations being ignored.

Constructors

PropertyRuleIssueDetails({required SourceCodeLocation sourceCodeLocation, required PropertyRuleIssueReason propertyRuleIssueReason, String? propertyValue})
PropertyRuleIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
propertyRuleIssueReason → PropertyRuleIssueReason
Reason why the property rule was discarded.
final
propertyValue → String?
The value of the property rule property that failed to parse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCodeLocation → SourceCodeLocation
Source code position of the property rule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited