SelectivePermissionsInterventionIssueDetails class

The issue warns about blocked calls to privacy sensitive APIs via the Selective Permissions Intervention.

Constructors

SelectivePermissionsInterventionIssueDetails({required String apiName, required AdAncestry adAncestry, StackTraceData? stackTrace})
SelectivePermissionsInterventionIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

adAncestry AdAncestry
Why the ad script using the API is considered an ad.
final
apiName String
Which API was intervened on.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTraceData?
The stack trace at the time of the intervention.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited