SharedArrayBufferIssueDetails class

Details for a issue arising from an SAB being instantiated in, or transferred to a context that is not cross-origin isolated.

Constructors

SharedArrayBufferIssueDetails({required SourceCodeLocation sourceCodeLocation, required bool isWarning, required SharedArrayBufferIssueType type})
SharedArrayBufferIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isWarning → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCodeLocation → SourceCodeLocation
final
type → SharedArrayBufferIssueType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited