StylesheetLoadingIssueDetails class

This issue warns when a referenced stylesheet couldn't be loaded.

Constructors

StylesheetLoadingIssueDetails({required SourceCodeLocation sourceCodeLocation, required StyleSheetLoadingIssueReason styleSheetLoadingIssueReason, FailedRequestInfo? failedRequestInfo})
StylesheetLoadingIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

failedRequestInfo → FailedRequestInfo?
Contains additional info when the failure was due to a request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCodeLocation → SourceCodeLocation
Source code position that referenced the failing stylesheet.
final
styleSheetLoadingIssueReason → StyleSheetLoadingIssueReason
Reason why the stylesheet couldn't be loaded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited