AddressFormFilledEvent class

Constructors

AddressFormFilledEvent({required List<FilledField> filledFields, required AddressUI addressUi})
AddressFormFilledEvent.fromJson(Map<String, dynamic> json)
factory

Properties

addressUi → AddressUI
An UI representation of the address used to fill the form. Consists of a 2D array where each child represents an address/profile line.
final
filledFields → List<FilledField>
Information about the fields that were filled
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited