AutofillApi class
Defines commands and events for Autofill.
Constructors
- AutofillApi(Client _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onAddressFormFilled
→ Stream<
AddressFormFilledEvent> -
Emitted when an address form is filled.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disable(
) → Future< void> - Disables autofill domain notifications.
-
enable(
) → Future< void> - Enables autofill domain notifications.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAddresses(
List< Address> addresses) → Future<void> - Set addresses so that developers can verify their forms implementation.
-
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
BackendNodeId fieldId, {FrameId? frameId, CreditCard? card, Address? address}) → Future< void> -
Trigger autofill on a form identified by the fieldId.
If the field and related form cannot be autofilled, returns an error.
fieldIdIdentifies a field that serves as an anchor for autofill.frameIdIdentifies the frame that field belongs to.cardCredit card information to fill out the form. Credit card data is not saved. Mutually exclusive withaddress.addressAddress to fill out the form. Address data is not saved. Mutually exclusive withcard.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited