BackgroundServiceApi class

Defines events for background web platform features.

Constructors

BackgroundServiceApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onBackgroundServiceEventReceived → Stream<BackgroundServiceEvent>
Called with all existing backgroundServiceEvents when enabled, and all new events afterwards if enabled and recording.
no setter
onRecordingStateChanged → Stream<RecordingStateChangedEvent>
Called when the recording state for the service has been updated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearEvents(ServiceName service) → Future<void>
Clears all stored data for the service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setRecording(bool shouldRecord, ServiceName service) → Future<void>
Set the recording state for the service.
startObserving(ServiceName service) → Future<void>
Enables event updates for the service.
stopObserving(ServiceName service) → Future<void>
Disables event updates for the service.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited