BackgroundServiceEvent class

Constructors

BackgroundServiceEvent({required TimeSinceEpoch timestamp, required String origin, required RegistrationID serviceWorkerRegistrationId, required ServiceName service, required String eventName, required String instanceId, required List<EventMetadata> eventMetadata, required String storageKey})
BackgroundServiceEvent.fromJson(Map<String, dynamic> json)
factory

Properties

eventMetadata → List<EventMetadata>
A list of event-specific information.
final
eventName → String
A description of the event.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → String
An identifier that groups related events together.
final
origin → String
The origin this event belongs to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceName
The Background Service this event belongs to.
final
serviceWorkerRegistrationId → RegistrationID
The Service Worker ID that initiated the event.
final
storageKey → String
Storage key this event belongs to.
final
timestamp → TimeSinceEpoch
Timestamp of the event (in seconds).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited