CharacteristicOperationReceivedEvent class

Constructors

CharacteristicOperationReceivedEvent({required String characteristicId, required CharacteristicOperationType type, String? data, CharacteristicWriteType? writeType})
CharacteristicOperationReceivedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

characteristicId → String
final
data → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CharacteristicOperationType
final
writeType → CharacteristicWriteType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited