CharacteristicProperties class

Describes the properties of a characteristic. This follows Bluetooth Core Specification BT 4.2 Vol 3 Part G 3.3.1. Characteristic Properties.

Constructors

CharacteristicProperties({bool? broadcast, bool? read, bool? writeWithoutResponse, bool? write, bool? notify, bool? indicate, bool? authenticatedSignedWrites, bool? extendedProperties})
CharacteristicProperties.fromJson(Map<String, dynamic> json)
factory

Properties

authenticatedSignedWrites → bool?
final
broadcast → bool?
final
extendedProperties → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
indicate → bool?
final
notify → bool?
final
read → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
write → bool?
final
writeWithoutResponse → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited