DescriptorOperationReceivedEvent class

Constructors

DescriptorOperationReceivedEvent({required String descriptorId, required DescriptorOperationType type, String? data})
DescriptorOperationReceivedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

data → String?
final
descriptorId → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DescriptorOperationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited