ScanEntry class

Stores the advertisement packet information that is sent by a Bluetooth device.

Constructors

ScanEntry({required String deviceAddress, required int rssi, required ScanRecord scanRecord})
ScanEntry.fromJson(Map<String, dynamic> json)
factory

Properties

deviceAddress → String
final
hashCode → int
The hash code for this object.
no setterinherited
rssi → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanRecord → ScanRecord
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited