Bounds class

Browser window bounds information

Constructors

Bounds({int? left, int? top, int? width, int? height, WindowState? windowState})
Bounds.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int?
The window height in pixels.
final
left → int?
The offset from the left edge of the screen to the window in pixels.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → int?
The offset from the top edge of the screen to the window in pixels.
final
width → int?
The window width in pixels.
final
windowState → WindowState?
The window state. Default to normal.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited