DownloadProgressEvent class

Constructors

DownloadProgressEvent({required String guid, required num totalBytes, required num receivedBytes, required DownloadProgressEventState state, String? filePath})
DownloadProgressEvent.fromJson(Map<String, dynamic> json)
factory

Properties

filePath → String?
If download is "completed", provides the path of the downloaded file. Depending on the platform, it is not guaranteed to be set, nor the file is guaranteed to exist.
final
guid → String
Global unique identifier of the download.
final
hashCode → int
The hash code for this object.
no setterinherited
receivedBytes → num
Total bytes received.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → DownloadProgressEventState
Download status.
final
totalBytes → num
Total expected bytes to download.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited