DownloadWillBeginEvent class

Constructors

DownloadWillBeginEvent({required FrameId frameId, required String guid, required String url, required String suggestedFilename})
DownloadWillBeginEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
Id of the frame that caused the download to begin.
final
guid → String
Global unique identifier of the download.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedFilename → String
Suggested file name of the resource (the actual name of the file saved on disk may differ).
final
url → String
URL of the resource being downloaded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited