GetVersionResult class

Constructors

GetVersionResult({required String protocolVersion, required String product, required String revision, required String userAgent, required String jsVersion})
GetVersionResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsVersion → String
V8 version.
final
product → String
Product name.
final
protocolVersion → String
Protocol version.
final
revision → String
Product revision.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent → String
User-Agent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited