GetWindowForTargetResult class

Constructors

GetWindowForTargetResult({required WindowID windowId, required Bounds bounds})
GetWindowForTargetResult.fromJson(Map<String, dynamic> json)
factory

Properties

bounds → Bounds
Bounds information of the window. When window state is 'minimized', the restored window position and size are returned.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windowId → WindowID
Browser window id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited