Histogram class

Chrome histogram.

Constructors

Histogram({required String name, required int sum, required int count, required List<Bucket> buckets})
Histogram.fromJson(Map<String, dynamic> json)
factory

Properties

buckets → List<Bucket>
Buckets.
final
count → int
Total number of samples.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sum → int
Sum of sample values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited