PermissionDescriptor class

Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.

Constructors

PermissionDescriptor({required String name, bool? sysex, bool? userVisibleOnly, bool? allowWithoutSanitization, bool? allowWithoutGesture, bool? panTiltZoom})
PermissionDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

allowWithoutGesture → bool?
For "fullscreen" permission, must specify allowWithoutGesture:true.
final
allowWithoutSanitization → bool?
For "clipboard" permission, may specify allowWithoutSanitization.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of permission. See https://cs.chromium.org/chromium/src/third_party/blink/renderer/modules/permissions/permission_descriptor.idl for valid permission names.
final
panTiltZoom → bool?
For "camera" permission, may specify panTiltZoom.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sysex → bool?
For "midi" permission, may also specify sysex control.
final
userVisibleOnly → bool?
For "push" permission, may specify userVisibleOnly. Note that userVisibleOnly = true is the only currently supported type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited