Cache class

Cache identifier.

Constructors

Cache({required CacheId cacheId, required String securityOrigin, required String storageKey, StorageBucket? storageBucket, required String cacheName})
Cache.fromJson(Map<String, dynamic> json)
factory

Properties

cacheId → CacheId
An opaque unique id of the cache.
final
cacheName → String
The name of the cache.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityOrigin → String
Security origin of the cache.
final
storageBucket → StorageBucket?
Storage bucket of the cache.
final
storageKey → String
Storage key of the cache.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited