DataEntry class

Data entry.

Constructors

DataEntry({required String requestURL, required String requestMethod, required List<Header> requestHeaders, required num responseTime, required int responseStatus, required String responseStatusText, required CachedResponseType responseType, required List<Header> responseHeaders})
DataEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestHeaders → List<Header>
Request headers
final
requestMethod → String
Request method.
final
requestURL → String
Request URL.
final
responseHeaders → List<Header>
Response headers
final
responseStatus → int
HTTP response status code.
final
responseStatusText → String
HTTP response status text.
final
responseTime → num
Number of seconds since epoch.
final
responseType → CachedResponseType
HTTP response type
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited