RequestEntriesResult class

Constructors

RequestEntriesResult({required List<DataEntry> cacheDataEntries, required num returnCount})
RequestEntriesResult.fromJson(Map<String, dynamic> json)
factory

Properties

cacheDataEntries → List<DataEntry>
Array of object store data entries.
final
hashCode → int
The hash code for this object.
no setterinherited
returnCount → num
Count of returned entries from this storage. If pathFilter is empty, it is the count of all entries from this storage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited