enable method

Future<void> enable({
  1. String? presentationUrl,
})

Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.

Implementation

Future<void> enable({String? presentationUrl}) async {
  await _client.send('Cast.enable', {'presentationUrl': ?presentationUrl});
}