ConsoleApi class

This domain is deprecated - use Runtime or Log instead.

Annotations

Constructors

ConsoleApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onMessageAdded → Stream<ConsoleMessage>
Issued when new console message is added.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearMessages() → Future<void>
Does nothing.
disable() → Future<void>
Disables console domain, prevents further console messages from being reported to the client.
enable() → Future<void>
Enables console domain, sends the messages collected so far to the client by means of the messageAdded notification.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited