ConsoleMessage class

Console message.

Constructors

ConsoleMessage({required ConsoleMessageSource source, required ConsoleMessageLevel level, required String text, String? url, int? line, int? column})
ConsoleMessage.fromJson(Map<String, dynamic> json)
factory

Properties

column → int?
Column number in the resource that generated this message (1-based).
final
hashCode → int
The hash code for this object.
no setterinherited
level → ConsoleMessageLevel
Message severity.
final
line → int?
Line number in the resource that generated this message (1-based).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ConsoleMessageSource
Message source.
final
text → String
Message text.
final
url → String?
URL of the message origin.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited