CSSAnimationStyle class

CSS style coming from animations with the name of the animation.

Constructors

CSSAnimationStyle({String? name, required CSSStyle style})
CSSAnimationStyle.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the animation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → CSSStyle
The style coming from the animation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited