CSSFunctionConditionNode class

CSS function conditional block representation.

Constructors

CSSFunctionConditionNode({CSSMedia? media, CSSContainerQuery? containerQueries, CSSSupports? supports, CSSNavigation? navigation, required List<CSSFunctionNode> children, required String conditionText})
CSSFunctionConditionNode.fromJson(Map<String, dynamic> json)
factory

Properties

children → List<CSSFunctionNode>
Block body.
final
conditionText → String
The condition text.
final
containerQueries → CSSContainerQuery?
Container query for this conditional block. Only one type of condition should be set.
final
hashCode → int
The hash code for this object.
no setterinherited
media → CSSMedia?
Media query for this conditional block. Only one type of condition should be set.
final
@navigation condition. Only one type of condition should be set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supports → CSSSupports?
@supports CSS at-rule condition. Only one type of condition should be set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited