CSSFunctionRule class

CSS function at-rule representation.

Constructors

CSSFunctionRule({required Value name, StyleSheetId? styleSheetId, required StyleSheetOrigin origin, required List<CSSFunctionParameter> parameters, required List<CSSFunctionNode> children, BackendNodeId? originTreeScopeNodeId})
CSSFunctionRule.fromJson(Map<String, dynamic> json)
factory

Properties

children → List<CSSFunctionNode>
Function body.
final
hashCode → int
The hash code for this object.
no setterinherited
name → Value
Name of the function.
final
origin → StyleSheetOrigin
Parent stylesheet's origin.
final
originTreeScopeNodeId → BackendNodeId?
The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
final
parameters → List<CSSFunctionParameter>
List of parameters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleSheetId → StyleSheetId?
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited