CSSKeyframeRule class

CSS keyframe rule representation.

Constructors

CSSKeyframeRule({StyleSheetId? styleSheetId, required StyleSheetOrigin origin, required Value keyText, required CSSStyle style})
CSSKeyframeRule.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyText → Value
Associated key text.
final
origin → StyleSheetOrigin
Parent stylesheet's origin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → CSSStyle
Associated style declaration.
final
styleSheetId → StyleSheetId?
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited