CSSKeyframesRule class

CSS keyframes rule representation.

Constructors

CSSKeyframesRule({required Value animationName, required List<CSSKeyframeRule> keyframes})
CSSKeyframesRule.fromJson(Map<String, dynamic> json)
factory

Properties

animationName → Value
Animation name.
final
hashCode → int
The hash code for this object.
no setterinherited
keyframes → List<CSSKeyframeRule>
List of keyframes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited