CSSLayerData class

CSS Layer data.

Constructors

CSSLayerData({required String name, List<CSSLayerData>? subLayers, required num order})
CSSLayerData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Layer name.
final
order → num
Layer order. The order determines the order of the layer in the cascade order. A higher number has higher priority in the cascade order.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subLayers → List<CSSLayerData>?
Direct sub-layers
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited