CSSMedia class

CSS media rule descriptor.

Constructors

CSSMedia({required String text, required CSSMediaSource source, String? sourceURL, SourceRange? range, StyleSheetId? styleSheetId, List<MediaQuery>? mediaList})
CSSMedia.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaList → List<MediaQuery>?
Array of media queries.
final
range → SourceRange?
The associated rule (@media or @import) header range in the enclosing stylesheet (if available).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → CSSMediaSource
Source of the media query: "mediaRule" if specified by a @media rule, "importRule" if specified by an @import rule, "linkedSheet" if specified by a "media" attribute in a linked stylesheet's LINK tag, "inlineSheet" if specified by a "media" attribute in an inline stylesheet's STYLE tag.
final
sourceURL → String?
URL of the document containing the media query description.
final
styleSheetId → StyleSheetId?
Identifier of the stylesheet containing this object (if exists).
final
text → String
Media query text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited