CSSProperty class

CSS property declaration data.

Constructors

CSSProperty({required String name, required String value, bool? important, bool? implicit, String? text, bool? parsedOk, bool? disabled, SourceRange? range, List<CSSProperty>? longhandProperties})
CSSProperty.fromJson(Map<String, dynamic> json)
factory

Properties

disabled → bool?
Whether the property is disabled by the user (present for source-based properties only).
final
hashCode → int
The hash code for this object.
no setterinherited
implicit → bool?
Whether the property is implicit (implies false if absent).
final
important → bool?
Whether the property has "!important" annotation (implies false if absent).
final
longhandProperties → List<CSSProperty>?
Parsed longhand components of this property if it is a shorthand. This field will be empty if the given property is not a shorthand.
final
name → String
The property name.
final
parsedOk → bool?
Whether the property is understood by the browser (implies true if absent).
final
range → SourceRange?
The entire property range in the enclosing style declaration (if available).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
The full property text as specified in the style.
final
value → String
The property value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited