CSSPropertyRegistration class

Representation of a custom property registration through CSS.registerProperty

Constructors

CSSPropertyRegistration({required String propertyName, Value? initialValue, required bool inherits, required String syntax})
CSSPropertyRegistration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inherits → bool
final
initialValue → Value?
final
propertyName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syntax → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited