CSSRule class

CSS rule representation.

Constructors

CSSRule({StyleSheetId? styleSheetId, required SelectorList selectorList, List<String>? nestingSelectors, required StyleSheetOrigin origin, required CSSStyle style, BackendNodeId? originTreeScopeNodeId, List<CSSMedia>? media, List<CSSContainerQuery>? containerQueries, List<CSSSupports>? supports, List<CSSLayer>? layers, List<CSSScope>? scopes, List<CSSRuleType>? ruleTypes, List<CSSStartingStyle>? startingStyles, List<CSSNavigation>? navigations})
CSSRule.fromJson(Map<String, dynamic> json)
factory

Properties

containerQueries → List<CSSContainerQuery>?
Container query list array (for rules involving container queries). The array enumerates container queries starting with the innermost one, going outwards.
final
hashCode → int
The hash code for this object.
no setterinherited
layers → List<CSSLayer>?
Cascade layer array. Contains the layer hierarchy that this rule belongs to starting with the innermost layer and going outwards.
final
media → List<CSSMedia>?
Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards.
final
@navigation CSS at-rule array. The array enumerates @navigation at-rules starting with the innermost one, going outwards.
final
nestingSelectors → List<String>?
Array of selectors from ancestor style rules, sorted by distance from the current rule.
final
origin → StyleSheetOrigin
Parent stylesheet's origin.
final
originTreeScopeNodeId → BackendNodeId?
The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
final
ruleTypes → List<CSSRuleType>?
The array keeps the types of ancestor CSSRules from the innermost going outwards.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<CSSScope>?
@scope CSS at-rule array. The array enumerates @scope at-rules starting with the innermost one, going outwards.
final
selectorList → SelectorList
Rule selector data.
final
startingStyles → List<CSSStartingStyle>?
@starting-style CSS at-rule array. The array enumerates @starting-style at-rules starting with the innermost one, going outwards.
final
style → CSSStyle
Associated style declaration.
final
styleSheetId → StyleSheetId?
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
final
supports → List<CSSSupports>?
@supports CSS at-rule array. The array enumerates @supports at-rules starting with the innermost one, going outwards.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited