originTreeScopeNodeId property
The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
Implementation
final dom.BackendNodeId? originTreeScopeNodeId;
The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
final dom.BackendNodeId? originTreeScopeNodeId;