CSSStyle class

CSS style representation.

Constructors

CSSStyle({StyleSheetId? styleSheetId, required List<CSSProperty> cssProperties, required List<ShorthandEntry> shorthandEntries, String? cssText, SourceRange? range})
CSSStyle.fromJson(Map<String, dynamic> json)
factory

Properties

cssProperties → List<CSSProperty>
CSS properties in the style.
final
cssText → String?
Style declaration text (if available).
final
hashCode → int
The hash code for this object.
no setterinherited
range → SourceRange?
Style declaration range in the enclosing stylesheet (if available).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shorthandEntries → List<ShorthandEntry>
Computed values for all shorthands found in the style.
final
styleSheetId → StyleSheetId?
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited