FontVariationAxis class

Information about font variation axes for variable fonts

Constructors

FontVariationAxis({required String tag, required String name, required num minValue, required num maxValue, required num defaultValue})
FontVariationAxis.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → num
The default value.
final
hashCode → int
The hash code for this object.
no setterinherited
maxValue → num
The maximum value (inclusive) the font supports for this tag.
final
minValue → num
The minimum value (inclusive) the font supports for this tag.
final
name → String
Human-readable variation name in the default language (normally, "en").
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
The font-variation-setting tag (a.k.a. "axis tag").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited