GetAnimatedStylesForNodeResult class

Constructors

GetAnimatedStylesForNodeResult({List<CSSAnimationStyle>? animationStyles, CSSStyle? transitionsStyle, List<InheritedAnimatedStyleEntry>? inherited})
GetAnimatedStylesForNodeResult.fromJson(Map<String, dynamic> json)
factory

Properties

animationStyles → List<CSSAnimationStyle>?
Styles coming from animations.
final
hashCode → int
The hash code for this object.
no setterinherited
inherited → List<InheritedAnimatedStyleEntry>?
Inherited style entries for animationsStyle and transitionsStyle from the inheritance chain of the element.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionsStyle → CSSStyle?
Style coming from transitions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited