GetInlineStylesForNodeResult class

Constructors

GetInlineStylesForNodeResult({CSSStyle? inlineStyle, CSSStyle? attributesStyle})
GetInlineStylesForNodeResult.fromJson(Map<String, dynamic> json)
factory

Properties

attributesStyle → CSSStyle?
Attribute-defined element style (e.g. resulting from "width=20 height=100%").
final
hashCode → int
The hash code for this object.
no setterinherited
inlineStyle → CSSStyle?
Inline style for the specified DOM node.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited