InheritedAnimatedStyleEntry class

Inherited CSS style collection for animated styles from ancestor node.

Constructors

InheritedAnimatedStyleEntry({List<CSSAnimationStyle>? animationStyles, CSSStyle? transitionsStyle})
InheritedAnimatedStyleEntry.fromJson(Map<String, dynamic> json)
factory

Properties

animationStyles → List<CSSAnimationStyle>?
Styles coming from the animations of the ancestor, if any, in the style inheritance chain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionsStyle → CSSStyle?
The style coming from the transitions of the ancestor, if any, in the style inheritance chain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited