InheritedStyleEntry class

Inherited CSS rule collection from ancestor node.

Constructors

InheritedStyleEntry({CSSStyle? inlineStyle, required List<RuleMatch> matchedCSSRules})
InheritedStyleEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inlineStyle → CSSStyle?
The ancestor node's inline style, if any, in the style inheritance chain.
final
matchedCSSRules → List<RuleMatch>
Matches of CSS rules matching the ancestor node in the style inheritance chain.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited