MediaQuery class

Media query descriptor.

Constructors

MediaQuery({required List<MediaQueryExpression> expressions, required bool active})
MediaQuery.fromJson(Map<String, dynamic> json)
factory

Properties

active → bool
Whether the media query condition is satisfied.
final
expressions → List<MediaQueryExpression>
Array of media query expressions.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited