MediaQueryExpression class

Media query expression descriptor.

Constructors

MediaQueryExpression({required num value, required String unit, required String feature, SourceRange? valueRange, num? computedLength})
MediaQueryExpression.fromJson(Map<String, dynamic> json)
factory

Properties

computedLength → num?
Computed length of media query expression (if applicable).
final
feature → String
Media query expression feature.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → String
Media query expression units.
final
value → num
Media query expression value.
final
valueRange → SourceRange?
The associated range of the value text in the enclosing stylesheet (if available).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited