PlatformFontUsage class

Information about amount of glyphs that were rendered with given font.

Constructors

PlatformFontUsage({required String familyName, required String postScriptName, required bool isCustomFont, required num glyphCount})
PlatformFontUsage.fromJson(Map<String, dynamic> json)
factory

Properties

familyName → String
Font's family name reported by platform.
final
glyphCount → num
Amount of glyphs that were rendered with this font.
final
hashCode → int
The hash code for this object.
no setterinherited
isCustomFont → bool
Indicates if the font was downloaded or resolved locally.
final
postScriptName → String
Font's PostScript name reported by platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited