PseudoElementMatches class

CSS rule collection for a single pseudo style.

Constructors

PseudoElementMatches({required PseudoType pseudoType, String? pseudoIdentifier, required List<RuleMatch> matches})
PseudoElementMatches.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
matches → List<RuleMatch>
Matches of CSS rules applicable to the pseudo style.
final
pseudoIdentifier → String?
Pseudo element custom ident.
final
pseudoType → PseudoType
Pseudo element type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited