RuleMatch class

Match data for a CSS rule.

Constructors

RuleMatch({required CSSRule rule, required List<int> matchingSelectors})
RuleMatch.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchingSelectors → List<int>
Matching selector indices in the rule's selectorList selectors (0-based).
final
rule → CSSRule
CSS rule in the match.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited