RuleUsage class

CSS coverage information.

Constructors

RuleUsage({required StyleSheetId styleSheetId, required num startOffset, required num endOffset, required bool used})
RuleUsage.fromJson(Map<String, dynamic> json)
factory

Properties

endOffset → num
Offset of the end of the rule body from the beginning of the stylesheet.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startOffset → num
Offset of the start of the rule (including selector) from the beginning of the stylesheet.
final
styleSheetId → StyleSheetId
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
final
used → bool
Indicates whether the rule was actually used by some element in the page.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited