ShorthandEntry class

Constructors

ShorthandEntry({required String name, required String value, bool? important})
ShorthandEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
important → bool?
Whether the property has "!important" annotation (implies false if absent).
final
name → String
Shorthand name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Shorthand value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited