SourceRange class

Text range within a resource. All numbers are zero-based.

Constructors

SourceRange({required int startLine, required int startColumn, required int endLine, required int endColumn})
SourceRange.fromJson(Map<String, dynamic> json)
factory

Properties

endColumn → int
End column of range (exclusive).
final
endLine → int
End line of range
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startColumn → int
Start column of range (inclusive).
final
startLine → int
Start line of range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited