Specificity class

Constructors

Specificity({required int a, required int b, required int c})
Specificity.fromJson(Map<String, dynamic> json)
factory

Properties

a → int
The a component, which represents the number of ID selectors.
final
b → int
The b component, which represents the number of class selectors, attributes selectors, and pseudo-classes.
final
c → int
The c component, which represents the number of type selectors and pseudo-elements.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited