SpecificityComponent class
Contribution of an individual simple selector to specificity.
Constructors
- SpecificityComponent({required String text, required int a, required int b, required int c})
-
SpecificityComponent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- a → int
-
The a component contribution.
final
- b → int
-
The b component contribution.
final
- c → int
-
The c component contribution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The simple selector text that contributes to specificity.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited