StyleDeclarationEdit class

A descriptor of operation to mutate style declaration text.

Constructors

StyleDeclarationEdit({required StyleSheetId styleSheetId, required SourceRange range, required String text})
StyleDeclarationEdit.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
range → SourceRange
The range of the style text in the enclosing stylesheet.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleSheetId → StyleSheetId
The css style sheet identifier.
final
text → String
New style text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited