Value class

Data for a simple selector (these are delimited by commas in a selector list).

Constructors

Value({required String text, SourceRange? range, Specificity? specificity})
Value.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
range → SourceRange?
Value range in the underlying resource (if available).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specificity → Specificity?
Specificity of the selector.
final
text → String
Value text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited