CallFrame class

JavaScript call frame. Array of call frames form the call stack.

Constructors

CallFrame({required CallFrameId callFrameId, required String functionName, Location? functionLocation, required Location location, required List<Scope> scopeChain, required RemoteObject this$, RemoteObject? returnValue, bool? canBeRestarted})
CallFrame.fromJson(Map<String, dynamic> json)
factory

Properties

callFrameId → CallFrameId
Call frame identifier. This identifier is only valid while the virtual machine is paused.
final
canBeRestarted → bool?
Valid only while the VM is paused and indicates whether this frame can be restarted or not. Note that a true value here does not guarantee that Debugger#restartFrame with this CallFrameId will be successful, but it is very likely.
final
functionLocation → Location?
Location in the source code.
final
functionName → String
Name of the JavaScript function called on this call frame.
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location
Location in the source code.
final
returnValue → RemoteObject?
The value being returned, if the function is at return point.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeChain → List<Scope>
Scope chain for this call frame.
final
this$ → RemoteObject
this object for this call frame.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited