DebugSymbols class

Debug symbols available for a wasm script.

Constructors

DebugSymbols({required DebugSymbolsType type, String? externalURL})
DebugSymbols.fromJson(Map<String, dynamic> json)
factory

Properties

externalURL → String?
URL of the external symbol source.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DebugSymbolsType
Type of the debug symbols.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited