DisassembleWasmModuleResult class

Constructors

DisassembleWasmModuleResult({String? streamId, required int totalNumberOfLines, required List<int> functionBodyOffsets, required WasmDisassemblyChunk chunk})
DisassembleWasmModuleResult.fromJson(Map<String, dynamic> json)
factory

Properties

chunk → WasmDisassemblyChunk
The first chunk of disassembly.
final
functionBodyOffsets → List<int>
The offsets of all function bodies, in the format start1, end1, start2, end2, ... where all ends are exclusive.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamId → String?
For large modules, return a stream from which additional chunks of disassembly can be read successively.
final
totalNumberOfLines → int
The total number of lines in the disassembly text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited