GetScriptSourceResult class

Constructors

GetScriptSourceResult({required String scriptSource, String? bytecode})
GetScriptSourceResult.fromJson(Map<String, dynamic> json)
factory

Properties

bytecode → String?
Wasm bytecode.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptSource → String
Script source (empty in case of Wasm bytecode).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited