Location class

Location in the source code.

Constructors

Location({required ScriptId scriptId, required int lineNumber, int? columnNumber})
Location.fromJson(Map<String, dynamic> json)
factory

Properties

columnNumber → int?
Column number in the script (0-based).
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
Line number in the script (0-based).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptId → ScriptId
Script identifier as reported in the Debugger.scriptParsed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited