PausedEvent class

Constructors

PausedEvent({required List<CallFrame> callFrames, required PausedEventReason reason, Map<String, dynamic>? data, List<String>? hitBreakpoints, StackTraceData? asyncStackTrace, StackTraceId? asyncStackTraceId})
PausedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

asyncStackTrace → StackTraceData?
Async stack trace, if any.
final
asyncStackTraceId → StackTraceId?
Async stack trace, if any.
final
callFrames → List<CallFrame>
Call stack the virtual machine stopped on.
final
data → Map<String, dynamic>?
Object containing break-specific auxiliary properties.
final
hashCode → int
The hash code for this object.
no setterinherited
hitBreakpoints → List<String>?
Hit breakpoints IDs
final
reason → PausedEventReason
Pause reason.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited