ResolvedBreakpoint class

Constructors

ResolvedBreakpoint({required BreakpointId breakpointId, required Location location})
ResolvedBreakpoint.fromJson(Map<String, dynamic> json)
factory

Properties

breakpointId → BreakpointId
Breakpoint unique identifier.
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location
Actual breakpoint location.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited