Scope class

Scope description.

Constructors

Scope({required ScopeType type, required RemoteObject object, String? name, Location? startLocation, Location? endLocation})
Scope.fromJson(Map<String, dynamic> json)
factory

Properties

endLocation → Location?
Location in the source code where scope ends
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
object → RemoteObject
Object representing the scope. For global and with scopes it represents the actual object; for the rest of the scopes, it is artificial transient object enumerating scope variables as its properties.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLocation → Location?
Location in the source code where scope starts
final
type → ScopeType
Scope type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited