ScriptFailedToParseEvent class

Constructors

ScriptFailedToParseEvent({required ScriptId scriptId, required String url, required int startLine, required int startColumn, required int endLine, required int endColumn, required ExecutionContextId executionContextId, required String hash, required String buildId, Map<String, dynamic>? executionContextAuxData, String? sourceMapURL, bool? hasSourceURL, bool? isModule, int? length, StackTraceData? stackTrace, int? codeOffset, ScriptLanguage? scriptLanguage, String? embedderName})
ScriptFailedToParseEvent.fromJson(Map<String, dynamic> json)
factory

Properties

buildId → String
For Wasm modules, the content of the build_id custom section. For JavaScript the debugId magic comment.
final
codeOffset → int?
If the scriptLanguage is WebAssembly, the code section offset in the module.
final
embedderName → String?
The name the embedder supplied for this script.
final
endColumn → int
Length of the last line of the script.
final
endLine → int
Last line of the script.
final
executionContextAuxData → Map<String, dynamic>?
Embedder-specific auxiliary data likely matching {isDefault: boolean, type: 'default'|'isolated'|'worker', frameId: string}
final
executionContextId → ExecutionContextId
Specifies script creation context.
final
hash → String
Content hash of the script, SHA-256.
final
hashCode → int
The hash code for this object.
no setterinherited
hasSourceURL → bool?
True, if this script has sourceURL.
final
isModule → bool?
True, if this script is ES6 module.
final
length → int?
This script length.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptId → ScriptId
Identifier of the script parsed.
final
scriptLanguage → ScriptLanguage?
The language of the script.
final
sourceMapURL → String?
URL of source map associated with script (if any).
final
stackTrace → StackTraceData?
JavaScript top stack frame of where the script parsed event was triggered if available.
final
startColumn → int
Column offset of the script within the resource with given URL.
final
startLine → int
Line offset of the script within the resource with given URL (for script tags).
final
url → String
URL or name of the script parsed (if any).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited