WasmDisassemblyChunk class

Constructors

WasmDisassemblyChunk({required List<String> lines, required List<int> bytecodeOffsets})
WasmDisassemblyChunk.fromJson(Map<String, dynamic> json)
factory

Properties

bytecodeOffsets → List<int>
The bytecode offsets describing the start of each line.
final
hashCode → int
The hash code for this object.
no setterinherited
lines → List<String>
The next chunk of disassembled lines.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited