PromptDevice class

Device information displayed in a user prompt to select a device.

Constructors

PromptDevice({required DeviceId id, required String name})
PromptDevice.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → DeviceId
final
name → String
Display name as it appears in a device request user prompt.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited