setVirtualWalletBehavior method

Future<void> setVirtualWalletBehavior(
  1. VirtualWalletAction action, {
  2. String? protocol,
  3. Map<String, dynamic>? response,
  4. FrameId? frameId,
})

Sets the behavior of the virtual wallet for digital credential requests issued from this frame. action The action of the virtual wallet. protocol The protocol identifier (e.g. "openid4vp"). Required when |action| is "respond", forbidden otherwise. response The response data object returned by the wallet. Required when |action| is "respond", forbidden otherwise. frameId The frame to scope the virtual wallet behavior to.

Implementation

Future<void> setVirtualWalletBehavior(
  VirtualWalletAction action, {
  String? protocol,
  Map<String, dynamic>? response,
  page.FrameId? frameId,
}) async {
  await _client.send('DigitalCredentials.setVirtualWalletBehavior', {
    'action': action,
    'protocol': ?protocol,
    'response': ?response,
    'frameId': ?frameId,
  });
}