AttributeModifiedEvent class

Constructors

AttributeModifiedEvent({required NodeId nodeId, required String name, required String value})
AttributeModifiedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Attribute name.
final
nodeId → NodeId
Id of the node that has changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Attribute value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited