BoxModel class

Box model.

Constructors

BoxModel({required Quad content, required Quad padding, required Quad border, required Quad margin, required int width, required int height, ShapeOutsideInfo? shapeOutside})
BoxModel.fromJson(Map<String, dynamic> json)
factory

Properties

border → Quad
Border box
final
content → Quad
Content box
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Node height
final
margin → Quad
Margin box
final
padding → Quad
Padding box
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeOutside → ShapeOutsideInfo?
Shape outside coordinates
final
width → int
Node width
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited