ChildNodeCountUpdatedEvent class

Constructors

ChildNodeCountUpdatedEvent({required NodeId nodeId, required int childNodeCount})
ChildNodeCountUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

childNodeCount → int
New node count.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeId → NodeId
Id of the node that has changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited