ChildNodeInsertedEvent class

Constructors

ChildNodeInsertedEvent({required NodeId parentNodeId, required NodeId previousNodeId, required Node node})
ChildNodeInsertedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
node → Node
Inserted node data.
final
parentNodeId → NodeId
Id of the node that has changed.
final
previousNodeId → NodeId
Id of the previous sibling.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited