DistributedNodesUpdatedEvent class

Constructors

DistributedNodesUpdatedEvent({required NodeId insertionPointId, required List<BackendNode> distributedNodes})
DistributedNodesUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

distributedNodes → List<BackendNode>
Distributed nodes for given insertion point.
final
hashCode → int
The hash code for this object.
no setterinherited
insertionPointId → NodeId
Insertion point where distributed nodes were updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited