GetFrameOwnerResult class

Constructors

GetFrameOwnerResult({required BackendNodeId backendNodeId, NodeId? nodeId})
GetFrameOwnerResult.fromJson(Map<String, dynamic> json)
factory

Properties

backendNodeId → BackendNodeId
Resulting node.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeId → NodeId?
Id of the node at given coordinates, only when enabled and requested document.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited