Node class

DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes. DOMNode is a base node mirror type.

Constructors

Node({required NodeId nodeId, NodeId? parentId, required BackendNodeId backendNodeId, required int nodeType, required String nodeName, required String localName, required String nodeValue, int? childNodeCount, List<Node>? children, List<String>? attributes, String? documentURL, String? baseURL, String? publicId, String? systemId, String? internalSubset, String? xmlVersion, String? name, String? value, PseudoType? pseudoType, String? pseudoIdentifier, ShadowRootType? shadowRootType, FrameId? frameId, Node? contentDocument, List<Node>? shadowRoots, Node? templateContent, List<Node>? pseudoElements, List<BackendNode>? distributedNodes, bool? isSVG, CompatibilityMode? compatibilityMode, BackendNode? assignedSlot, bool? isScrollable, bool? affectedByStartingStyles, List<StyleSheetId>? adoptedStyleSheets, AdProvenance? adProvenance})
Node.fromJson(Map<String, dynamic> json)
factory

Properties

adoptedStyleSheets → List<StyleSheetId>?
final
adProvenance → AdProvenance?
final
affectedByStartingStyles → bool?
final
assignedSlot → BackendNode?
final
attributes → List<String>?
Attributes of the Element node in the form of flat array [name1, value1, name2, value2].
final
backendNodeId → BackendNodeId
The BackendNodeId for this node.
final
baseURL → String?
Base URL that Document or FrameOwner node uses for URL completion.
final
childNodeCount → int?
Child count for Container nodes.
final
children → List<Node>?
Child nodes of this node when requested with children.
final
compatibilityMode → CompatibilityMode?
final
contentDocument → Node?
Content document for frame owner elements.
final
distributedNodes → List<BackendNode>?
Distributed nodes for given insertion point.
final
documentURL → String?
Document URL that Document or FrameOwner node points to.
final
frameId → FrameId?
Frame ID for frame owner elements.
final
hashCode → int
The hash code for this object.
no setterinherited
internalSubset → String?
DocumentType's internalSubset.
final
isScrollable → bool?
final
isSVG → bool?
Whether the node is SVG.
final
localName → String
Node's localName.
final
name → String?
Attr's name.
final
nodeId → NodeId
Node identifier that is passed into the rest of the DOM messages as the nodeId. Backend will only push node with given id once. It is aware of all requested nodes and will only fire DOM events for nodes known to the client.
final
nodeName → String
Node's nodeName.
final
nodeType → int
Node's nodeType.
final
nodeValue → String
Node's nodeValue.
final
parentId → NodeId?
The id of the parent node if any.
final
pseudoElements → List<Node>?
Pseudo elements associated with this node.
final
pseudoIdentifier → String?
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
final
pseudoType → PseudoType?
Pseudo element type for this node.
final
publicId → String?
DocumentType's publicId.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowRoots → List<Node>?
Shadow root list for given element host.
final
shadowRootType → ShadowRootType?
Shadow root type.
final
systemId → String?
DocumentType's systemId.
final
templateContent → Node?
Content document fragment for template elements.
final
value → String?
Attr's value.
final
xmlVersion → String?
Document's XML version in case of XML documents.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited