RGBA class

A structure holding an RGBA color.

Constructors

RGBA({required int r, required int g, required int b, num? a})
RGBA.fromJson(Map<String, dynamic> json)
factory

Properties

a → num?
The alpha component, in the 0-1 range (default: 1).
final
b → int
The blue component, in the 0-255 range.
final
g → int
The green component, in the 0-255 range.
final
hashCode → int
The hash code for this object.
no setterinherited
r → int
The red component, in the 0-255 range.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited