Rect class

Rectangle.

Constructors

Rect({required num x, required num y, required num width, required num height})
Rect.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → num
Rectangle height
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num
Rectangle width
final
x → num
X coordinate
final
y → num
Y coordinate
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited