ScrollableFlagUpdatedEvent class

Constructors

ScrollableFlagUpdatedEvent({required NodeId nodeId, required bool isScrollable})
ScrollableFlagUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isScrollable → bool
If the node is scrollable.
final
nodeId → NodeId
The id of the node.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited