DOMNode class

A Node in the DOM tree.

Constructors

DOMNode({required int nodeType, required String nodeName, required String nodeValue, String? textValue, String? inputValue, bool? inputChecked, bool? optionSelected, required BackendNodeId backendNodeId, List<int>? childNodeIndexes, List<NameValue>? attributes, List<int>? pseudoElementIndexes, int? layoutNodeIndex, String? documentURL, String? baseURL, String? contentLanguage, String? documentEncoding, String? publicId, String? systemId, FrameId? frameId, int? contentDocumentIndex, PseudoType? pseudoType, ShadowRootType? shadowRootType, bool? isClickable, List<EventListener>? eventListeners, String? currentSourceURL, String? originURL, num? scrollOffsetX, num? scrollOffsetY})
DOMNode.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → List<NameValue>?
Attributes of an Element node.
final
backendNodeId → BackendNodeId
Node's id, corresponds to DOM.Node.backendNodeId.
final
baseURL → String?
Base URL that Document or FrameOwner node uses for URL completion.
final
childNodeIndexes → List<int>?
The indexes of the node's child nodes in the domNodes array returned by getSnapshot, if any.
final
contentDocumentIndex → int?
The index of a frame owner element's content document in the domNodes array returned by getSnapshot, if any.
final
contentLanguage → String?
Only set for documents, contains the document's content language.
final
currentSourceURL → String?
The selected url for nodes with a srcset attribute.
final
documentEncoding → String?
Only set for documents, contains the document's character set encoding.
final
documentURL → String?
Document URL that Document or FrameOwner node points to.
final
eventListeners → List<EventListener>?
Details of the node's event listeners, if any.
final
frameId → FrameId?
Frame ID for frame owner elements and also for the document node.
final
hashCode → int
The hash code for this object.
no setterinherited
inputChecked → bool?
Only set for radio and checkbox input elements, indicates if the element has been checked
final
inputValue → String?
Only set for input elements, contains the input's associated text value.
final
isClickable → bool?
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
final
layoutNodeIndex → int?
The index of the node's related layout tree node in the layoutTreeNodes array returned by getSnapshot, if any.
final
nodeName → String
Node's nodeName.
final
nodeType → int
Node's nodeType.
final
nodeValue → String
Node's nodeValue.
final
optionSelected → bool?
Only set for option elements, indicates if the element has been selected
final
originURL → String?
The url of the script (if any) that generates this node.
final
pseudoElementIndexes → List<int>?
Indexes of pseudo elements associated with this node in the domNodes array returned by getSnapshot, if any.
final
pseudoType → PseudoType?
Type of a pseudo element node.
final
publicId → String?
DocumentType node's publicId.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollOffsetX → num?
Scroll offsets, set when this node is a Document.
final
scrollOffsetY → num?
final
shadowRootType → ShadowRootType?
Shadow root type.
final
systemId → String?
DocumentType node's systemId.
final
textValue → String?
Only set for textarea elements, contains the text value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited