InlineTextBox class

Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.

Constructors

InlineTextBox({required Rect boundingBox, required int startCharacterIndex, required int numCharacters})
InlineTextBox.fromJson(Map<String, dynamic> json)
factory

Properties

boundingBox → Rect
The bounding box in document coordinates. Note that scroll offset of the document is ignored.
final
hashCode → int
The hash code for this object.
no setterinherited
numCharacters → int
The number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCharacterIndex → int
The starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited