LayoutTreeNode class

Details of an element in the DOM tree with a LayoutObject.

Constructors

LayoutTreeNode({required int domNodeIndex, required Rect boundingBox, String? layoutText, List<InlineTextBox>? inlineTextNodes, int? styleIndex, int? paintOrder, bool? isStackingContext})
LayoutTreeNode.fromJson(Map<String, dynamic> json)
factory

Properties

boundingBox → Rect
The bounding box in document coordinates. Note that scroll offset of the document is ignored.
final
domNodeIndex → int
The index of the related DOM node in the domNodes array returned by getSnapshot.
final
hashCode → int
The hash code for this object.
no setterinherited
inlineTextNodes → List<InlineTextBox>?
The post-layout inline text nodes, if any.
final
isStackingContext → bool?
Set to true to indicate the element begins a new stacking context.
final
layoutText → String?
Contents of the LayoutText, if any.
final
paintOrder → int?
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleIndex → int?
Index into the computedStyles array returned by getSnapshot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited