LayoutTreeSnapshot class

Table of details of an element in the DOM tree with a LayoutObject.

Constructors

LayoutTreeSnapshot({required List<int> nodeIndex, required List<ArrayOfStrings> styles, required List<Rectangle> bounds, required List<StringIndex> text, required RareBooleanData stackingContexts, List<int>? paintOrders, List<Rectangle>? offsetRects, List<Rectangle>? scrollRects, List<Rectangle>? clientRects, List<StringIndex>? blendedBackgroundColors, List<num>? textColorOpacities})
LayoutTreeSnapshot.fromJson(Map<String, dynamic> json)
factory

Properties

blendedBackgroundColors → List<StringIndex>?
The list of background colors that are blended with colors of overlapping elements.
final
bounds → List<Rectangle>
The absolute position bounding box.
final
clientRects → List<Rectangle>?
The client rect of nodes. Only available when includeDOMRects is set to true
final
hashCode → int
The hash code for this object.
no setterinherited
nodeIndex → List<int>
Index of the corresponding node in the NodeTreeSnapshot array returned by captureSnapshot.
final
offsetRects → List<Rectangle>?
The offset rect of nodes. Only available when includeDOMRects is set to true
final
paintOrders → List<int>?
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollRects → List<Rectangle>?
The scroll rect of nodes. Only available when includeDOMRects is set to true
final
stackingContexts → RareBooleanData
Stacking context information.
final
styles → List<ArrayOfStrings>
Array of indexes specifying computed style strings, filtered according to the computedStyles parameter passed to captureSnapshot.
final
text → List<StringIndex>
Contents of the LayoutText, if any.
final
textColorOpacities → List<num>?
The list of computed text opacities.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited