NodeTreeSnapshot class

Table containing nodes.

Constructors

NodeTreeSnapshot({List<int>? parentIndex, List<int>? nodeType, RareStringData? shadowRootType, List<StringIndex>? nodeName, List<StringIndex>? nodeValue, List<BackendNodeId>? backendNodeId, List<ArrayOfStrings>? attributes, RareStringData? textValue, RareStringData? inputValue, RareBooleanData? inputChecked, RareBooleanData? optionSelected, RareIntegerData? contentDocumentIndex, RareStringData? pseudoType, RareStringData? pseudoIdentifier, RareBooleanData? isClickable, RareStringData? currentSourceURL, RareStringData? originURL})
NodeTreeSnapshot.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → List<ArrayOfStrings>?
Attributes of an Element node. Flatten name, value pairs.
final
backendNodeId → List<BackendNodeId>?
Node's id, corresponds to DOM.Node.backendNodeId.
final
contentDocumentIndex → RareIntegerData?
The index of the document in the list of the snapshot documents.
final
currentSourceURL → RareStringData?
The selected url for nodes with a srcset attribute.
final
hashCode → int
The hash code for this object.
no setterinherited
inputChecked → RareBooleanData?
Only set for radio and checkbox input elements, indicates if the element has been checked
final
inputValue → RareStringData?
Only set for input elements, contains the input's associated text value.
final
isClickable → RareBooleanData?
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
final
nodeName → List<StringIndex>?
Node's nodeName.
final
nodeType → List<int>?
Node's nodeType.
final
nodeValue → List<StringIndex>?
Node's nodeValue.
final
optionSelected → RareBooleanData?
Only set for option elements, indicates if the element has been selected
final
originURL → RareStringData?
The url of the script (if any) that generates this node.
final
parentIndex → List<int>?
Parent node index.
final
pseudoIdentifier → RareStringData?
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
final
pseudoType → RareStringData?
Type of a pseudo element node.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowRootType → RareStringData?
Type of the shadow root the Node is in. String values are equal to the ShadowRootType enum.
final
textValue → RareStringData?
Only set for textarea elements, contains the text value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited