RareStringData class

Data that is only present on rare nodes.

Constructors

RareStringData({required List<int> index, required List<StringIndex> value})
RareStringData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → List<StringIndex>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited