TextBoxSnapshot class

Table of details of the post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.

Constructors

TextBoxSnapshot({required List<int> layoutIndex, required List<Rectangle> bounds, required List<int> start, required List<int> length})
TextBoxSnapshot.fromJson(Map<String, dynamic> json)
factory

Properties

bounds → List<Rectangle>
The absolute position bounding box.
final
hashCode → int
The hash code for this object.
no setterinherited
layoutIndex → List<int>
Index of the layout tree node that owns this box collection.
final
length → List<int>
The number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → List<int>
The starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited