DOMStorageApi class

Query and modify DOM storage.

Constructors

DOMStorageApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onDomStorageItemAdded → Stream<DomStorageItemAddedEvent>
no setter
onDomStorageItemRemoved → Stream<DomStorageItemRemovedEvent>
no setter
onDomStorageItemsCleared → Stream<StorageId>
no setter
onDomStorageItemUpdated → Stream<DomStorageItemUpdatedEvent>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear(StorageId storageId) → Future<void>
disable() → Future<void>
Disables storage tracking, prevents storage events from being sent to the client.
enable() → Future<void>
Enables storage tracking, storage events will now be delivered to the client.
getDOMStorageItems(StorageId storageId) → Future<List<Item>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDOMStorageItem(StorageId storageId, String key) → Future<void>
setDOMStorageItem(StorageId storageId, String key, String value) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited