StorageId class

DOM Storage identifier.

Constructors

StorageId({String? securityOrigin, SerializedStorageKey? storageKey, required bool isLocalStorage})
StorageId.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLocalStorage → bool
Whether the storage is local storage (not session storage).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityOrigin → String?
Security origin for the storage.
final
storageKey → SerializedStorageKey?
Represents a key by which DOM Storage keys its CachedStorageAreas
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited