DisplayFeature class

Constructors

DisplayFeature({required DisplayFeatureOrientation orientation, required int offset, required int maskLength})
DisplayFeature.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maskLength → int
A display feature may mask content such that it is not physically displayed - this length along with the offset describes this area. A display feature that only splits content will have a 0 mask_length.
final
offset → int
The offset from the screen origin in either the x (for vertical orientation) or y (for horizontal orientation) direction.
final
orientation → DisplayFeatureOrientation
Orientation of a display feature in relation to screen
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited