setPrimaryScreen method

Future<void> setPrimaryScreen(
  1. ScreenId screenId
)

Set primary screen. Only supported in headless mode. Note that this changes the coordinate system origin to the top-left of the new primary screen, updating the bounds and work areas of all existing screens accordingly.

Implementation

Future<void> setPrimaryScreen(ScreenId screenId) async {
  await _client.send('Emulation.setPrimaryScreen', {'screenId': screenId});
}