isInternal property
Indicates whether the screen is internal to the device or external, attached to the device.
Implementation
final bool isInternal;
Indicates whether the screen is internal to the device or external, attached to the device.
final bool isInternal;