ScreenOrientationLockChangedEvent class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
locked
→ bool
-
Whether the screen orientation is currently locked.
final
-
orientation
→ ScreenOrientation?
-
The orientation lock type requested by the page. Only set when locked is true.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited