SensorReading class

Constructors

SensorReading({SensorReadingSingle? single, SensorReadingXYZ? xyz, SensorReadingQuaternion? quaternion})
SensorReading.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
quaternion → SensorReadingQuaternion?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → SensorReadingSingle?
final
xyz → SensorReadingXYZ?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited