UserAgentMetadata class

Used to specify User Agent Client Hints to emulate. See https://wicg.github.io/ua-client-hints Missing optional values will be filled in by the target with what it would normally use.

Constructors

UserAgentMetadata({List<UserAgentBrandVersion>? brands, List<UserAgentBrandVersion>? fullVersionList, required String platform, required String platformVersion, required String architecture, required String model, required bool mobile, String? bitness, bool? wow64, List<String>? formFactors})
UserAgentMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

architecture → String
final
bitness → String?
final
brands → List<UserAgentBrandVersion>?
Brands appearing in Sec-CH-UA.
final
formFactors → List<String>?
Used to specify User Agent form-factor values. See https://wicg.github.io/ua-client-hints/#sec-ch-ua-form-factors
final
fullVersionList → List<UserAgentBrandVersion>?
Brands appearing in Sec-CH-UA-Full-Version-List.
final
hashCode → int
The hash code for this object.
no setterinherited
mobile → bool
final
model → String
final
platform → String
final
platformVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wow64 → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited