Account class

Corresponds to IdentityRequestAccount

Constructors

Account({required String accountId, required String email, required String name, required String givenName, required String pictureUrl, required String idpConfigUrl, required String idpLoginUrl, required LoginState loginState, String? termsOfServiceUrl, String? privacyPolicyUrl})
Account.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String
final
email → String
final
givenName → String
final
hashCode → int
The hash code for this object.
no setterinherited
idpConfigUrl → String
final
idpLoginUrl → String
final
loginState → LoginState
final
name → String
final
pictureUrl → String
final
privacyPolicyUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termsOfServiceUrl → String?
These two are only set if the loginState is signUp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited