AuthRequiredEvent class

Constructors

AuthRequiredEvent({required RequestId requestId, required RequestData request, required FrameId frameId, required ResourceType resourceType, required AuthChallenge authChallenge})
AuthRequiredEvent.fromJson(Map<String, dynamic> json)
factory

Properties

authChallenge → AuthChallenge
Details of the Authorization Challenge encountered. If this is set, client should respond with continueRequest that contains AuthChallengeResponse.
final
frameId → FrameId
The id of the frame that initiated the request.
final
hashCode → int
The hash code for this object.
no setterinherited
request → RequestData
The details of the request.
final
requestId → RequestId
Each request the page makes will have a unique id.
final
resourceType → ResourceType
How the requested resource will be used.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited