RequestPausedEvent class

Constructors

RequestPausedEvent({required RequestId requestId, required RequestData request, required FrameId frameId, required ResourceType resourceType, ErrorReason? responseErrorReason, int? responseStatusCode, String? responseStatusText, List<HeaderEntry>? responseHeaders, RequestId? networkId, RequestId? redirectedRequestId})
RequestPausedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
The id of the frame that initiated the request.
final
hashCode → int
The hash code for this object.
no setterinherited
networkId → RequestId?
If the intercepted request had a corresponding Network.requestWillBeSent event fired for it, then this networkId will be the same as the requestId present in the requestWillBeSent event.
final
redirectedRequestId → RequestId?
If the request is due to a redirect response from the server, the id of the request that has caused the redirect.
final
request → RequestData
The details of the request.
final
requestId → RequestId
Each request the page makes will have a unique id.
final
resourceType → ResourceType
How the requested resource will be used.
final
responseErrorReason → ErrorReason?
Response error if intercepted at response stage.
final
responseHeaders → List<HeaderEntry>?
Response headers if intercepted at the response stage.
final
responseStatusCode → int?
Response code if intercepted at response stage.
final
responseStatusText → String?
Response status text if intercepted at response stage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited