BucketFileSystemLocator class

Constructors

BucketFileSystemLocator({required SerializedStorageKey storageKey, String? bucketName, required List<String> pathComponents})
BucketFileSystemLocator.fromJson(Map<String, dynamic> json)
factory

Properties

bucketName → String?
Bucket name. Not passing a bucketName will retrieve the default Bucket. (https://developer.mozilla.org/en-US/docs/Web/API/Storage_API#storage_buckets)
final
hashCode → int
The hash code for this object.
no setterinherited
pathComponents → List<String>
Path to the directory using each path component as an array item.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageKey → SerializedStorageKey
Storage key
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited