Directory class

Constructors

Directory({required String name, required List<String> nestedDirectories, required List<File> nestedFiles})
Directory.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
nestedDirectories → List<String>
final
nestedFiles → List<File>
Files that are directly nested under this directory.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited