File class

Constructors

File({required String name, required TimeSinceEpoch lastModified, required num size, required String type})
File.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastModified → TimeSinceEpoch
Timestamp
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num
Size in bytes
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited