SamplingHeapProfileSample class

A single sample from a sampling profile.

Constructors

SamplingHeapProfileSample({required num size, required int nodeId, required num ordinal})
SamplingHeapProfileSample.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeId → int
Id of the corresponding profile tree node.
final
ordinal → num
Time-ordered sample ordinal number. It is unique across all profiles retrieved between startSampling and stopSampling.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num
Allocation size in bytes attributed to the sample.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited