DataEntry class

Data entry.

Constructors

DataEntry({required RemoteObject key, required RemoteObject primaryKey, required RemoteObject value})
DataEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → RemoteObject
Key object.
final
primaryKey → RemoteObject
Primary key object.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → RemoteObject
Value object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited