DatabaseWithObjectStores class

Database with an array of object stores.

Constructors

DatabaseWithObjectStores({required String name, required num version, required List<ObjectStore> objectStores})
DatabaseWithObjectStores.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Database name.
final
objectStores → List<ObjectStore>
Object stores in this database.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → num
Database version (type is not 'integer', as the standard requires the version number to be 'unsigned long long')
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited