GetMetadataResult class

Constructors

GetMetadataResult({required num entriesCount, required num keyGeneratorValue})
GetMetadataResult.fromJson(Map<String, dynamic> json)
factory

Properties

entriesCount → num
the entries count
final
hashCode → int
The hash code for this object.
no setterinherited
keyGeneratorValue → num
the current value of key generator, to become the next inserted key into the object store. Valid if objectStore.autoIncrement is true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited