Key class

Key.

Constructors

Key({required KeyType type, num? number, String? string, num? date, List<Key>? array})
Key.fromJson(Map<String, dynamic> json)
factory

Properties

array → List<Key>?
Array value.
final
date → num?
Date value.
final
hashCode → int
The hash code for this object.
no setterinherited
number → num?
Number value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → String?
String value.
final
type → KeyType
Key type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited