KeyPath class

Key path.

Constructors

KeyPath({required KeyPathType type, String? string, List<String>? array})
KeyPath.fromJson(Map<String, dynamic> json)
factory

Properties

array → List<String>?
Array value.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → String?
String value.
final
type → KeyPathType
Key path type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited