KeyRange class

Key range.

Constructors

KeyRange({Key? lower, Key? upper, required bool lowerOpen, required bool upperOpen})
KeyRange.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lower → Key?
Lower bound.
final
lowerOpen → bool
If true lower bound is open.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upper → Key?
Upper bound.
final
upperOpen → bool
If true upper bound is open.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited