ObjectStore class

Object store.

Constructors

ObjectStore({required String name, required KeyPath keyPath, required bool autoIncrement, required List<ObjectStoreIndex> indexes})
ObjectStore.fromJson(Map<String, dynamic> json)
factory

Properties

autoIncrement → bool
If true, object store has auto increment flag set.
final
hashCode → int
The hash code for this object.
no setterinherited
indexes → List<ObjectStoreIndex>
Indexes in this object store.
final
keyPath → KeyPath
Object store key path.
final
name → String
Object store name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited