ObjectStoreIndex class

Object store index.

Constructors

ObjectStoreIndex({required String name, required KeyPath keyPath, required bool unique, required bool multiEntry})
ObjectStoreIndex.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyPath → KeyPath
Index key path.
final
multiEntry → bool
If true, index allows multiple entries for a key.
final
name → String
Index name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique → bool
If true, index is unique.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited