RequestDataResult class

Constructors

RequestDataResult({required List<DataEntry> objectStoreDataEntries, required bool hasMore})
RequestDataResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
If true, there are more entries to fetch in the given range.
final
objectStoreDataEntries → List<DataEntry>
Array of object store data entries.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited