DragData class

Constructors

DragData({required List<DragDataItem> items, List<String>? files, required int dragOperationsMask})
DragData.fromJson(Map<String, dynamic> json)
factory

Properties

dragOperationsMask → int
Bit field representing allowed drag operations. Copy = 1, Link = 2, Move = 16
final
files → List<String>?
List of filenames that should be included when dropping
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<DragDataItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited