DragDataItem class

Constructors

DragDataItem({required String mimeType, required String data, String? title, String? baseURL})
DragDataItem.fromJson(Map<String, dynamic> json)
factory

Properties

baseURL → String?
Stores the base URL for the contained markup. Only valid when mimeType == "text/html".
final
data → String
Depending of the value of mimeType, it contains the dragged link, text, HTML markup or any other data.
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
Mime type of the dragged data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Title associated with a link. Only valid when mimeType == "text/uri-list".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited