Layer class

Information about a compositing layer.

Constructors

Layer({required LayerId layerId, LayerId? parentLayerId, BackendNodeId? backendNodeId, required num offsetX, required num offsetY, required num width, required num height, List<num>? transform, num? anchorX, num? anchorY, num? anchorZ, required int paintCount, required bool drawsContent, bool? invisible, List<ScrollRect>? scrollRects, StickyPositionConstraint? stickyPositionConstraint})
Layer.fromJson(Map<String, dynamic> json)
factory

Properties

anchorX → num?
Transform anchor point X, absent if no transform specified
final
anchorY → num?
Transform anchor point Y, absent if no transform specified
final
anchorZ → num?
Transform anchor point Z, absent if no transform specified
final
backendNodeId → BackendNodeId?
The backend id for the node associated with this layer.
final
drawsContent → bool
Indicates whether this layer hosts any content, rather than being used for transform/scrolling purposes only.
final
hashCode → int
The hash code for this object.
no setterinherited
height → num
Layer height.
final
invisible → bool?
Set if layer is not visible.
final
layerId → LayerId
The unique id for this layer.
final
offsetX → num
Offset from parent layer, X coordinate.
final
offsetY → num
Offset from parent layer, Y coordinate.
final
paintCount → int
Indicates how many time this layer has painted.
final
parentLayerId → LayerId?
The id of parent (not present for root).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollRects → List<ScrollRect>?
Rectangles scrolling on main thread only.
final
stickyPositionConstraint → StickyPositionConstraint?
Sticky position constraint information
final
transform → List<num>?
Transformation matrix for layer, default is identity matrix
final
width → num
Layer width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited