PictureTile class

Serialized fragment of layer picture along with its offset within the layer.

Constructors

PictureTile({required num x, required num y, required String picture})
PictureTile.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
picture → String
Base64-encoded snapshot data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → num
Offset from owning layer left boundary
final
y → num
Offset from owning layer top boundary
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited