StickyPositionConstraint class

Sticky position constraints.

Constructors

StickyPositionConstraint({required Rect stickyBoxRect, required Rect containingBlockRect, LayerId? nearestLayerShiftingStickyBox, LayerId? nearestLayerShiftingContainingBlock})
StickyPositionConstraint.fromJson(Map<String, dynamic> json)
factory

Properties

containingBlockRect → Rect
Layout rectangle of the containing block of the sticky element
final
hashCode → int
The hash code for this object.
no setterinherited
nearestLayerShiftingContainingBlock → LayerId?
The nearest sticky layer that shifts the containing block
final
nearestLayerShiftingStickyBox → LayerId?
The nearest sticky layer that shifts the sticky box
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickyBoxRect → Rect
Layout rectangle of the sticky element before being shifted
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited