LogApi class

Provides access to log entries.

Constructors

LogApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onEntryAdded → Stream<LogEntry>
Issued when new message was logged.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
Clears the log.
disable() → Future<void>
Disables log domain, prevents further log entries from being reported to the client.
enable() → Future<void>
Enables log domain, sends the entries collected so far to the client by means of the entryAdded notification.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startViolationsReport(List<ViolationSetting> config) → Future<void>
start violation reporting. config Configuration for violations.
stopViolationsReport() → Future<void>
Stop violation reporting.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited