LogEntry class

Log entry.

Constructors

LogEntry({required LogEntrySource source, required LogEntryLevel level, required String text, LogEntryCategory? category, required Timestamp timestamp, String? url, int? lineNumber, StackTraceData? stackTrace, RequestId? networkRequestId, String? workerId, List<RemoteObject>? args})
LogEntry.fromJson(Map<String, dynamic> json)
factory

Properties

args → List<RemoteObject>?
Call arguments.
final
category → LogEntryCategory?
final
hashCode → int
The hash code for this object.
no setterinherited
level → LogEntryLevel
Log entry severity.
final
lineNumber → int?
Line number in the resource.
final
networkRequestId → RequestId?
Identifier of the network request associated with this entry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → LogEntrySource
Log entry source.
final
stackTrace → StackTraceData?
JavaScript stack trace.
final
text → String
Logged text.
final
timestamp → Timestamp
Timestamp when this entry was added.
final
url → String?
URL of the resource if known.
final
workerId → String?
Identifier of the worker associated with this entry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited