ViolationSetting class

Violation configuration setting.

Constructors

ViolationSetting({required ViolationSettingName name, required num threshold})
ViolationSetting.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → ViolationSettingName
Violation type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold → num
Time threshold to trigger upon.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited