PlayerError class

Corresponds to kMediaError

Constructors

PlayerError({required String errorType, required int code, required List<PlayerErrorSourceLocation> stack, required List<PlayerError> cause, required Map<String, dynamic> data})
PlayerError.fromJson(Map<String, dynamic> json)
factory

Properties

cause → List<PlayerError>
Errors potentially have a root cause error, ie, a DecoderError might be caused by an WindowsError
final
code → int
Code is the numeric enum entry for a specific set of error codes, such as PipelineStatusCodes in media/base/pipeline_status.h
final
data → Map<String, dynamic>
Extra data attached to an error, such as an HRESULT, Video Codec, etc.
final
errorType → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → List<PlayerErrorSourceLocation>
A trace of where this error was caused / where it passed through.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited