PlayerErrorsRaisedEvent class

Constructors

PlayerErrorsRaisedEvent({required PlayerId playerId, required List<PlayerError> errors})
PlayerErrorsRaisedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

errors → List<PlayerError>
final
hashCode → int
The hash code for this object.
no setterinherited
playerId → PlayerId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited