DOMCounter class

DOM object counter data.

Constructors

DOMCounter({required String name, required int count})
DOMCounter.fromJson(Map<String, dynamic> json)
factory

Properties

count → int
Object count.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Object name. Note: object names should be presumed volatile and clients should not expect the returned names to be consistent across runs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited