GetDOMCountersResult class

Constructors

GetDOMCountersResult({required int documents, required int nodes, required int jsEventListeners})
GetDOMCountersResult.fromJson(Map<String, dynamic> json)
factory

Properties

documents → int
final
hashCode → int
The hash code for this object.
no setterinherited
jsEventListeners → int
final
nodes → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited