MemoryApi class

Constructors

MemoryApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

forciblyPurgeJavaScriptMemory() → Future<void>
Simulate OomIntervention by purging V8 memory.
getAllTimeSamplingProfile() → Future<SamplingProfile>
Retrieve native memory allocations profile collected since renderer process startup.
getBrowserSamplingProfile() → Future<SamplingProfile>
Retrieve native memory allocations profile collected since browser process startup.
getDOMCounters() → Future<GetDOMCountersResult>
Retruns current DOM object counters.
getDOMCountersForLeakDetection() → Future<List<DOMCounter>>
Retruns DOM object counters after preparing renderer for leak detection. Returns: DOM object counters.
getSamplingProfile() → Future<SamplingProfile>
Retrieve native memory allocations profile collected since last startSampling call.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareForLeakDetection() → Future<void>
Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc.
setPressureNotificationsSuppressed(bool suppressed) → Future<void>
Enable/disable suppressing memory pressure notifications in all processes. suppressed If true, memory pressure notifications will be suppressed.
simulatePressureNotification(PressureLevel level) → Future<void>
Simulate a memory pressure notification in all processes. level Memory pressure level of the notification.
startSampling({int? samplingInterval, bool? suppressRandomness}) → Future<void>
Start collecting native memory profile. samplingInterval Average number of bytes between samples. suppressRandomness Do not randomize intervals between samples.
stopSampling() → Future<void>
Stop collecting native memory profile.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited