Module class

Executable module information

Constructors

Module({required String name, required String uuid, required String baseAddress, required num size})
Module.fromJson(Map<String, dynamic> json)
factory

Properties

baseAddress → String
Base address where the module is loaded into memory. Encoded as a decimal or hexadecimal (0x prefixed) string.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the module.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num
Size of the module in bytes.
final
uuid → String
UUID of the module.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited