SamplingProfile class

Array of heap profile samples.

Constructors

SamplingProfile({required List<SamplingProfileNode> samples, required List<Module> modules})
SamplingProfile.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
modules → List<Module>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples → List<SamplingProfileNode>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited