SamplingProfileNode class

Heap profile sample.

Constructors

SamplingProfileNode({required num size, required num total, required List<String> stack})
SamplingProfileNode.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num
Size of the sampled allocation.
final
stack → List<String>
Execution stack at the point of allocation.
final
total → num
Total bytes attributed to this sample.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited