protocol/network library

Classes

AssociatedCookie
A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
AuthChallenge
Authorization challenge for HTTP status code 401 or 407.
AuthChallengeResponse
Response to an AuthChallenge.
BlockedSetCookieWithReason
A cookie which was not stored from a response with the corresponding reason.
BlockPattern
CachedResource
Information about the cached resource.
ChallengeEventDetails
Session event details specific to challenges.
ClientSecurityState
ConnectTiming
ContentSecurityPolicyStatus
Cookie object
CookieParam
Cookie parameter object
CookiePartitionKey
cookiePartitionKey object The representation of the components of the key that are created by the cookiePartitionKey class contained in net/cookies/cookie_partition_key.h.
CorsErrorStatus
CreationEventDetails
Session event details specific to creation.
CrossOriginEmbedderPolicyStatus
CrossOriginOpenerPolicyStatus
DataReceivedEvent
DeviceBoundSession
A device bound session.
DeviceBoundSessionCookieCraving
A device bound session's cookie craving.
DeviceBoundSessionEventOccurredEvent
DeviceBoundSessionInclusionRules
A device bound session's inclusion rules.
DeviceBoundSessionKey
Unique identifier for a device bound session.
DeviceBoundSessionUrlRule
A device bound session's inclusion URL rule.
DeviceBoundSessionWithUsage
How a device bound session was used during a request.
DirectTCPSocketAbortedEvent
DirectTCPSocketChunkReceivedEvent
DirectTCPSocketChunkSentEvent
DirectTCPSocketClosedEvent
DirectTCPSocketCreatedEvent
DirectTCPSocketOpenedEvent
DirectTCPSocketOptions
DirectUDPMessage
DirectUDPSocketAbortedEvent
DirectUDPSocketChunkReceivedEvent
DirectUDPSocketChunkSentEvent
DirectUDPSocketClosedEvent
DirectUDPSocketCreatedEvent
DirectUDPSocketJoinedMulticastGroupEvent
DirectUDPSocketLeftMulticastGroupEvent
DirectUDPSocketOpenedEvent
DirectUDPSocketOptions
EventSourceMessageReceivedEvent
ExemptedSetCookieWithReason
A cookie should have been blocked by 3PCD but is exempted and stored from a response with the corresponding reason. A cookie could only have at most one exemption reason.
GetRequestPostDataResult
GetResponseBodyForInterceptionResult
GetResponseBodyResult
Initiator
Information about the request initiator.
LoadingFailedEvent
LoadingFinishedEvent
LoadNetworkResourceOptions
An options object that may be extended later to better support CORS, CORB and streaming.
LoadNetworkResourcePageResult
An object providing the result of a network resource load.
NetworkApi
Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.
NetworkConditions
PostDataEntry
Post data entry for HTTP request
RefreshEventDetails
Session event details specific to refresh.
ReportingApiEndpoint
ReportingApiEndpointsChangedForOriginEvent
ReportingApiReport
An object representing a report generated by the Reporting API.
RequestData
HTTP request data.
RequestInterceptedEvent
RequestPattern
Request pattern for interception.
RequestWillBeSentEvent
RequestWillBeSentExtraInfoEvent
ResourceChangedPriorityEvent
ResourceTiming
Timing information for the request.
ResponseData
HTTP response data.
ResponseReceivedEarlyHintsEvent
ResponseReceivedEvent
ResponseReceivedExtraInfoEvent
SecurityDetails
Security details about a request.
SecurityIsolationStatus
ServiceWorkerRouterInfo
SignedCertificateTimestamp
Details of a signed certificate timestamp (SCT).
SignedExchangeError
Information about a signed exchange response.
SignedExchangeHeader
Information about a signed exchange header. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#cbor-representation
SignedExchangeInfo
Information about a signed exchange response.
SignedExchangeReceivedEvent
SignedExchangeSignature
Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
TerminationEventDetails
Session event details specific to termination.
TrustTokenOperationDoneEvent
TrustTokenParams
Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
WebSocketClosedEvent
WebSocketCreatedEvent
WebSocketFrame
WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.
WebSocketFrameErrorEvent
WebSocketFrameReceivedEvent
WebSocketFrameSentEvent
WebSocketHandshakeResponseReceivedEvent
WebSocketRequest
WebSocket request data.
WebSocketResponse
WebSocket response data.
WebSocketWillSendHandshakeRequestEvent
WebTransportClosedEvent
WebTransportConnectionEstablishedEvent
WebTransportCreatedEvent

Enums

AlternateProtocolUsage
The reason why Chrome uses a specific transport protocol for HTTP semantics.
AuthChallengeResponseResponse
AuthChallengeSource
BlockedReason
The reason why request was blocked.
CertificateTransparencyCompliance
Whether the request complied with Certificate Transparency policy.
ChallengeEventDetailsChallengeResult
ConnectionType
The underlying connection technology that the browser is supposedly using.
ContentEncoding
List of content encodings supported by the backend.
ContentSecurityPolicySource
CookieBlockedReason
Types of reasons why a cookie may not be sent with a request.
CookieExemptionReason
Types of reasons why a cookie should have been blocked by 3PCD but is exempted for the request.
CookiePriority
Represents the cookie's 'Priority' status: https://tools.ietf.org/html/draft-west-cookie-priority-00
CookieSameSite
Represents the cookie's 'SameSite' status: https://tools.ietf.org/html/draft-west-first-party-cookies
CookieSourceScheme
Represents the source scheme of the origin that originally set the cookie. A value of "Unset" allows protocol clients to emulate legacy cookie scope for the scheme. This is a temporary ability and it will be removed in the future.
CorsError
The reason why request was blocked.
CrossOriginEmbedderPolicyValue
CrossOriginOpenerPolicyValue
DeviceBoundSessionFetchResult
A fetch result for a device bound session creation or refresh.
DeviceBoundSessionUrlRuleRuleType
DeviceBoundSessionWithUsageUsage
DirectSocketDnsQueryType
ErrorReason
Network level fetch failure reason.
InitiatorType
InterceptionStage
Stages of the interception to begin intercepting. Request will intercept before the request is sent. Response will intercept after the response is received.
IPAddressSpace
LocalNetworkAccessRequestPolicy
RefreshEventDetailsRefreshResult
RenderBlockingBehavior
The render blocking behavior of a resource request.
ReportStatus
The status of a Reporting API report.
RequestReferrerPolicy
ResourcePriority
Loading priority of a resource request.
ResourceType
Resource type as it was perceived by the rendering engine.
ServiceWorkerResponseSource
Source of serviceworker response.
ServiceWorkerRouterSource
Source of service worker router.
SetCookieBlockedReason
Types of reasons why a cookie may not be stored from a response.
SignedExchangeErrorField
Field type for a signed exchange related error.
TerminationEventDetailsDeletionReason
TrustTokenOperationDoneEventStatus
TrustTokenOperationType
TrustTokenParamsRefreshPolicy

Extension Types

DeviceBoundSessionEventId
A unique identifier for a device bound session event.
Headers
Request / response headers as keys / values of JSON object.
InterceptionId
Unique intercepted request identifier.
LoaderId
Unique loader identifier.
MonotonicTime
Monotonically increasing time in seconds since an arbitrary point in the past.
ReportId
RequestId
Unique network request identifier. Note that this does not identify individual HTTP requests that are part of a network request.
TimeSinceEpoch
UTC time in seconds, counted from January 1, 1970.