AssociatedCookie class

A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.

Constructors

AssociatedCookie({required Cookie cookie, required List<CookieBlockedReason> blockedReasons, CookieExemptionReason? exemptionReason})
AssociatedCookie.fromJson(Map<String, dynamic> json)
factory

Properties

blockedReasons → List<CookieBlockedReason>
The reason(s) the cookie was blocked. If empty means the cookie is included.
final
The cookie object representing the cookie which was not sent.
final
exemptionReason → CookieExemptionReason?
The reason the cookie should have been blocked by 3PCD but is exempted. A cookie could only have at most one exemption reason.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited