AuthChallenge class

Authorization challenge for HTTP status code 401 or 407.

Constructors

AuthChallenge({AuthChallengeSource? source, required String origin, required String scheme, required String realm})
AuthChallenge.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
origin → String
Origin of the challenger.
final
realm → String
The realm of the challenge. May be empty.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The authentication scheme used, such as basic or digest
final
source → AuthChallengeSource?
Source of the authentication challenge.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited