block property
Whether or not to block the pattern. If false, a matching request will not be blocked even if it matches a later
BlockPattern.
Implementation
final bool block;
Whether or not to block the pattern. If false, a matching request will not be blocked even if it matches a later
BlockPattern.
final bool block;