CachedResource class

Information about the cached resource.

Constructors

CachedResource({required String url, required ResourceType type, ResponseData? response, required num bodySize})
CachedResource.fromJson(Map<String, dynamic> json)
factory

Properties

bodySize → num
Cached response body size.
final
hashCode → int
The hash code for this object.
no setterinherited
response → ResponseData?
Cached response data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ResourceType
Type of this resource.
final
url → String
Resource URL. This is the url of the original network request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited