ChallengeEventDetails class

Session event details specific to challenges.

Constructors

ChallengeEventDetails({required ChallengeEventDetailsChallengeResult challengeResult, required String challenge})
ChallengeEventDetails.fromJson(Map<String, dynamic> json)
factory

Properties

challenge → String
The challenge set.
final
challengeResult → ChallengeEventDetailsChallengeResult
The result of a challenge.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited