ClientSecurityState class

Constructors

ClientSecurityState({required bool initiatorIsSecureContext, required IPAddressSpace initiatorIPAddressSpace, required LocalNetworkAccessRequestPolicy localNetworkAccessRequestPolicy})
ClientSecurityState.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
initiatorIPAddressSpace → IPAddressSpace
final
initiatorIsSecureContext → bool
final
localNetworkAccessRequestPolicy → LocalNetworkAccessRequestPolicy
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited