ContentSecurityPolicyStatus class

Constructors

ContentSecurityPolicyStatus({required String effectiveDirectives, required bool isEnforced, required ContentSecurityPolicySource source})
ContentSecurityPolicyStatus.fromJson(Map<String, dynamic> json)
factory

Properties

effectiveDirectives → String
final
hashCode → int
The hash code for this object.
no setterinherited
isEnforced → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ContentSecurityPolicySource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited