CookieParam class

Cookie parameter object

Constructors

CookieParam({required String name, required String value, String? url, String? domain, String? path, bool? secure, bool? httpOnly, CookieSameSite? sameSite, TimeSinceEpoch? expires, CookiePriority? priority, CookieSourceScheme? sourceScheme, int? sourcePort, CookiePartitionKey? partitionKey})
CookieParam.fromJson(Map<String, dynamic> json)
factory

Properties

domain → String?
Cookie domain.
final
expires → TimeSinceEpoch?
Cookie expiration date, session cookie if not set
final
hashCode → int
The hash code for this object.
no setterinherited
httpOnly → bool?
True if cookie is http-only.
final
name → String
Cookie name.
final
partitionKey → CookiePartitionKey?
Cookie partition key. If not set, the cookie will be set as not partitioned.
final
path → String?
Cookie path.
final
priority → CookiePriority?
Cookie Priority.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameSite → CookieSameSite?
Cookie SameSite type.
final
secure → bool?
True if cookie is secure.
final
sourcePort → int?
Cookie source port. Valid values are {-1, 1, 65535}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.
final
sourceScheme → CookieSourceScheme?
Cookie source scheme type.
final
url → String?
The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.
final
value → String
Cookie value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited