CreationEventDetails class
Session event details specific to creation.
Constructors
- CreationEventDetails({required DeviceBoundSessionFetchResult fetchResult, DeviceBoundSession? newSession})
-
CreationEventDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- fetchResult → DeviceBoundSessionFetchResult
-
The result of the fetch attempt.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newSession → DeviceBoundSession?
-
The session if there was a newly created session. This is populated for
all successful creation events.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited