newSession property
The session if there was a newly created session. This is populated for all successful creation events.
Implementation
final DeviceBoundSession? newSession;
The session if there was a newly created session. This is populated for all successful creation events.
final DeviceBoundSession? newSession;