DataReceivedEvent class

Constructors

DataReceivedEvent({required RequestId requestId, required MonotonicTime timestamp, required int dataLength, required int encodedDataLength, String? data})
DataReceivedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

data → String?
Data that was received.
final
dataLength → int
Data chunk length.
final
encodedDataLength → int
Actual bytes received (might be less than dataLength for compressed encodings).
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → RequestId
Request identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited