DeviceBoundSessionEventOccurredEvent class

Constructors

DeviceBoundSessionEventOccurredEvent({required DeviceBoundSessionEventId eventId, required String site, required bool succeeded, String? sessionId, CreationEventDetails? creationEventDetails, RefreshEventDetails? refreshEventDetails, TerminationEventDetails? terminationEventDetails, ChallengeEventDetails? challengeEventDetails})
DeviceBoundSessionEventOccurredEvent.fromJson(Map<String, dynamic> json)
factory

Properties

challengeEventDetails ChallengeEventDetails?
final
creationEventDetails CreationEventDetails?
The below are the different session event type details. Exactly one is populated.
final
eventId DeviceBoundSessionEventId
A unique identifier for this session event.
final
hashCode int
The hash code for this object.
no setterinherited
refreshEventDetails RefreshEventDetails?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event is associated with. May not be populated for failed events.
final
site String
The site this session event is associated with.
final
succeeded bool
Whether this event was considered successful.
final
terminationEventDetails TerminationEventDetails?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited