creationEventDetails property
The below are the different session event type details. Exactly one is populated.
Implementation
final CreationEventDetails? creationEventDetails;
The below are the different session event type details. Exactly one is populated.
final CreationEventDetails? creationEventDetails;