DeviceBoundSessionFailedRequest class

Details about a failed device bound session network request.

Constructors

DeviceBoundSessionFailedRequest({required String requestUrl, String? netError, int? responseError, String? responseErrorBody})
DeviceBoundSessionFailedRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
netError → String?
The net error of the response if it was not OK.
final
requestUrl → String
The failed request URL.
final
responseError → int?
The response code if the net error was OK and the response code was not 200.
final
responseErrorBody → String?
The body of the response if the net error was OK, the response code was not 200, and the response body was not empty.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited