includeSite property
Whether the whole site is included. See comments on
net::device_bound_sessions::SessionInclusionRules::include_site_ for more
details; this boolean is true if that value is populated.
Implementation
final bool includeSite;
Whether the whole site is included. See comments on
net::device_bound_sessions::SessionInclusionRules::include_site_ for more
details; this boolean is true if that value is populated.
final bool includeSite;