DeviceBoundSessionKey class

Unique identifier for a device bound session.

Constructors

DeviceBoundSessionKey({required String site, required String id})
DeviceBoundSessionKey.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The id of the session.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
site String
The site the session is set up for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited