DeviceBoundSessionWithUsage class

How a device bound session was used during a request.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionKey DeviceBoundSessionKey
The key for the session.
final
usage DeviceBoundSessionWithUsageUsage
How the session was used (or not used).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited