DirectTCPSocketCreatedEvent class

Constructors

DirectTCPSocketCreatedEvent({required RequestId identifier, required String remoteAddr, required int remotePort, required DirectTCPSocketOptions options, required MonotonicTime timestamp, Initiator? initiator})
DirectTCPSocketCreatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → RequestId
final
initiator → Initiator?
final
options → DirectTCPSocketOptions
final
remoteAddr → String
final
remotePort → int
Unsigned int 16.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited