DirectTCPSocketOpenedEvent class

Constructors

DirectTCPSocketOpenedEvent({required RequestId identifier, required String remoteAddr, required int remotePort, required MonotonicTime timestamp, String? localAddr, int? localPort})
DirectTCPSocketOpenedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → RequestId
final
localAddr → String?
final
localPort → int?
Expected to be unsigned integer.
final
remoteAddr → String
final
remotePort → int
Expected to be unsigned integer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited