DirectTCPSocketOptions class

Constructors

DirectTCPSocketOptions({required bool noDelay, num? keepAliveDelay, num? sendBufferSize, num? receiveBufferSize, DirectSocketDnsQueryType? dnsQueryType})
DirectTCPSocketOptions.fromJson(Map<String, dynamic> json)
factory

Properties

dnsQueryType → DirectSocketDnsQueryType?
final
hashCode → int
The hash code for this object.
no setterinherited
keepAliveDelay → num?
Expected to be unsigned integer.
final
noDelay → bool
TCP_NODELAY option
final
receiveBufferSize → num?
Expected to be unsigned integer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendBufferSize → num?
Expected to be unsigned integer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited