DirectUDPMessage class

Constructors

DirectUDPMessage({required String data, String? remoteAddr, int? remotePort})
DirectUDPMessage.fromJson(Map<String, dynamic> json)
factory

Properties

data → String
final
hashCode → int
The hash code for this object.
no setterinherited
remoteAddr → String?
Null for connected mode.
final
remotePort → int?
Null for connected mode. Expected to be unsigned integer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited