DirectUDPSocketChunkReceivedEvent class

Constructors

DirectUDPSocketChunkReceivedEvent({required RequestId identifier, required DirectUDPMessage message, required MonotonicTime timestamp})
DirectUDPSocketChunkReceivedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → RequestId
final
message → DirectUDPMessage
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited