DirectUDPSocketOptions class

Constructors

DirectUDPSocketOptions({String? remoteAddr, int? remotePort, String? localAddr, int? localPort, DirectSocketDnsQueryType? dnsQueryType, num? sendBufferSize, num? receiveBufferSize, bool? multicastLoopback, int? multicastTimeToLive, bool? multicastAllowAddressSharing})
DirectUDPSocketOptions.fromJson(Map<String, dynamic> json)
factory

Properties

dnsQueryType → DirectSocketDnsQueryType?
final
hashCode → int
The hash code for this object.
no setterinherited
localAddr → String?
final
localPort → int?
Unsigned int 16.
final
multicastAllowAddressSharing → bool?
final
multicastLoopback → bool?
final
multicastTimeToLive → int?
Unsigned int 8.
final
receiveBufferSize → num?
Expected to be unsigned integer.
final
remoteAddr → String?
final
remotePort → int?
Unsigned int 16.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendBufferSize → num?
Expected to be unsigned integer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited