EventSourceMessageReceivedEvent class

Constructors

EventSourceMessageReceivedEvent({required RequestId requestId, required MonotonicTime timestamp, required String eventName, required String eventId, required String data})
EventSourceMessageReceivedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

data → String
Message content.
final
eventId → String
Message identifier.
final
eventName → String
Message type.
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → RequestId
Request identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited