GetRequestPostDataResult class

Constructors

GetRequestPostDataResult({required String postData, required bool base64Encoded})
GetRequestPostDataResult.fromJson(Map<String, dynamic> json)
factory

Properties

base64Encoded bool
True, if content was sent as base64.
final
hashCode int
The hash code for this object.
no setterinherited
postData String
Request body string, omitting files from multipart requests
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited