Initiator class

Information about the request initiator.

Constructors

Initiator({required InitiatorType type, StackTraceData? stack, String? url, num? lineNumber, num? columnNumber, RequestId? requestId})
Initiator.fromJson(Map<String, dynamic> json)
factory

Properties

columnNumber → num?
Initiator column number, set for Parser type or for Script type (when script is importing module) (0-based).
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → num?
Initiator line number, set for Parser type or for Script type (when script is importing module) (0-based).
final
requestId → RequestId?
Set if another request triggered this request (e.g. preflight).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → StackTraceData?
Initiator JavaScript stack trace, set for Script only. Requires the Debugger domain to be enabled.
final
type → InitiatorType
Type of this initiator.
final
url → String?
Initiator URL, set for Parser type or for Script type (when script is importing module) or for SignedExchange type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited