LoadNetworkResourceOptions class

An options object that may be extended later to better support CORS, CORB and streaming.

Constructors

LoadNetworkResourceOptions({required bool disableCache, required bool includeCredentials})
LoadNetworkResourceOptions.fromJson(Map<String, dynamic> json)
factory

Properties

disableCache → bool
final
hashCode → int
The hash code for this object.
no setterinherited
includeCredentials → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited