LoadNetworkResourcePageResult class

An object providing the result of a network resource load.

Constructors

LoadNetworkResourcePageResult({required bool success, num? netError, String? netErrorName, num? httpStatusCode, StreamHandle? stream, Headers? headers})
LoadNetworkResourcePageResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Headers?
Response headers.
final
httpStatusCode → num?
final
netError → num?
Optional values used for error reporting.
final
netErrorName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → StreamHandle?
If successful, one of the following two fields holds the result.
final
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited