LoadingFailedEvent class

Constructors

LoadingFailedEvent({required RequestId requestId, required MonotonicTime timestamp, required ResourceType type, required String errorText, bool? canceled, BlockedReason? blockedReason, CorsErrorStatus? corsErrorStatus})
LoadingFailedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

blockedReason → BlockedReason?
The reason why loading was blocked, if any.
final
canceled → bool?
True if loading was canceled.
final
corsErrorStatus → CorsErrorStatus?
The reason why loading was blocked by CORS, if any.
final
errorText → String
Error message. List of network errors: https://cs.chromium.org/chromium/src/net/base/net_error_list.h
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → RequestId
Request identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final
type → ResourceType
Resource type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited