LoadingFinishedEvent class

Constructors

LoadingFinishedEvent({required RequestId requestId, required MonotonicTime timestamp, required num encodedDataLength})
LoadingFinishedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

encodedDataLength → num
Total number of bytes received for this request.
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → RequestId
Request identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited