emulateNetworkConditions method

  1. @Deprecated('This command is deprecated')
Future<void> emulateNetworkConditions(
  1. bool offline,
  2. num latency,
  3. num downloadThroughput,
  4. num uploadThroughput, {
  5. ConnectionType? connectionType,
  6. num? packetLoss,
  7. int? packetQueueLength,
  8. bool? packetReordering,
})

Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect. offline True to emulate internet disconnection. latency Minimum latency from request sent to response headers received (ms). downloadThroughput Maximal aggregated download throughput (bytes/sec). -1 disables download throttling. uploadThroughput Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling. connectionType Connection type if known. packetLoss WebRTC packet loss (percent, 0-100). 0 disables packet loss emulation, 100 drops all the packets. packetQueueLength WebRTC packet queue length (packet). 0 removes any queue length limitations. packetReordering WebRTC packetReordering feature.

Implementation

@Deprecated('This command is deprecated')
Future<void> emulateNetworkConditions(
  bool offline,
  num latency,
  num downloadThroughput,
  num uploadThroughput, {
  ConnectionType? connectionType,
  num? packetLoss,
  int? packetQueueLength,
  bool? packetReordering,
}) async {
  await _client.send('Network.emulateNetworkConditions', {
    'offline': offline,
    'latency': latency,
    'downloadThroughput': downloadThroughput,
    'uploadThroughput': uploadThroughput,
    if (connectionType != null) 'connectionType': connectionType,
    if (packetLoss != null) 'packetLoss': packetLoss,
    if (packetQueueLength != null) 'packetQueueLength': packetQueueLength,
    if (packetReordering != null) 'packetReordering': packetReordering,
  });
}