newSession property

DeviceBoundSession? newSession
final

The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.

Implementation

final DeviceBoundSession? newSession;