RefreshEventDetailsRefreshResult enum

Inheritance
Available extensions

Values

refreshed → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('Refreshed')
initializedService → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('InitializedService')
unreachable → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('Unreachable')
serverError → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('ServerError')
refreshQuotaExceeded → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('RefreshQuotaExceeded')
fatalError → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('FatalError')
signingQuotaExceeded → const RefreshEventDetailsRefreshResult
const RefreshEventDetailsRefreshResult('SigningQuotaExceeded')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RefreshEventDetailsRefreshResult>
A constant List of the values in this enum, in order of their declaration.