ReportingApiReport class

An object representing a report generated by the Reporting API.

Constructors

ReportingApiReport({required ReportId id, required String initiatorUrl, required String destination, required String type, required TimeSinceEpoch timestamp, required int depth, required int completedAttempts, required Map<String, dynamic> body, required ReportStatus status})
ReportingApiReport.fromJson(Map<String, dynamic> json)
factory

Properties

body → Map<String, dynamic>
final
completedAttempts → int
The number of delivery attempts made so far, not including an active attempt.
final
depth → int
How many uploads deep the related request was.
final
destination → String
The name of the endpoint group that should be used to deliver the report.
final
hashCode → int
The hash code for this object.
no setterinherited
id → ReportId
final
initiatorUrl → String
The URL of the document that triggered the report.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ReportStatus
final
timestamp → TimeSinceEpoch
When the report was generated.
final
type → String
The type of the report (specifies the set of data that is contained in the report body).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited