RequestData class

HTTP request data.

Constructors

RequestData({required String url, String? urlFragment, required String method, required Headers headers, bool? hasPostData, List<PostDataEntry>? postDataEntries, MixedContentType? mixedContentType, required ResourcePriority initialPriority, required RequestReferrerPolicy referrerPolicy, bool? isLinkPreload, TrustTokenParams? trustTokenParams, bool? isSameSite, bool? isAdRelated})
RequestData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasPostData → bool?
True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.
final
headers → Headers
HTTP request headers.
final
initialPriority → ResourcePriority
Priority of the resource request at the time request is sent.
final
isAdRelated → bool?
True when the resource request is ad-related.
final
isLinkPreload → bool?
Whether is loaded via link preload.
final
isSameSite → bool?
True if this resource request is considered to be the 'same site' as the request corresponding to the main frame.
final
method → String
HTTP request method.
final
mixedContentType → MixedContentType?
The mixed content type of the request.
final
postDataEntries → List<PostDataEntry>?
Request body elements (post data broken into individual entries).
final
referrerPolicy → RequestReferrerPolicy
The referrer policy of the request, as defined in https://www.w3.org/TR/referrer-policy/
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trustTokenParams → TrustTokenParams?
Set for requests when the TrustToken API is used. Contains the parameters passed by the developer (e.g. via "fetch") as understood by the backend.
final
url → String
Request URL (without fragment).
final
urlFragment → String?
Fragment of the requested URL starting with hash, if present.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited