RequestPattern class

Request pattern for interception.

Constructors

RequestPattern({String? urlPattern, ResourceType? resourceType, InterceptionStage? interceptionStage})
RequestPattern.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
interceptionStage → InterceptionStage?
Stage at which to begin intercepting requests. Default is Request.
final
resourceType → ResourceType?
If set, only requests for matching resource types will be intercepted.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlPattern → String?
Wildcards ('*' -> zero or more, '?' -> exactly one) are allowed. Escape character is backslash. Omitting is equivalent to "*".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited