RequestWillBeSentExtraInfoEvent class

Constructors

RequestWillBeSentExtraInfoEvent({required RequestId requestId, required List<AssociatedCookie> associatedCookies, required Headers headers, required ConnectTiming connectTiming, List<DeviceBoundSessionWithUsage>? deviceBoundSessionUsages, ClientSecurityState? clientSecurityState, bool? siteHasCookieInOtherPartition, String? appliedNetworkConditionsId})
RequestWillBeSentExtraInfoEvent.fromJson(Map<String, dynamic> json)
factory

Properties

appliedNetworkConditionsId → String?
The network conditions id if this request was affected by network conditions configured via emulateNetworkConditionsByRule.
final
associatedCookies → List<AssociatedCookie>
A list of cookies potentially associated to the requested URL. This includes both cookies sent with the request and the ones not sent; the latter are distinguished by having blockedReasons field set.
final
clientSecurityState → ClientSecurityState?
The client security state set for the request.
final
connectTiming → ConnectTiming
Connection timing information for the request.
final
deviceBoundSessionUsages → List<DeviceBoundSessionWithUsage>?
How the request site's device bound sessions were used during this request.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
Raw request headers as they will be sent over the wire.
final
requestId → RequestId
Request identifier. Used to match this information to an existing requestWillBeSent event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteHasCookieInOtherPartition → bool?
Whether the site has partitioned cookies stored in a partition different than the current one.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited