appliedNetworkConditionsId property
The network conditions id if this request was affected by network conditions configured via emulateNetworkConditionsByRule.
Implementation
final String? appliedNetworkConditionsId;
The network conditions id if this request was affected by network conditions configured via emulateNetworkConditionsByRule.
final String? appliedNetworkConditionsId;