ResponseData class

HTTP response data.

Constructors

ResponseData({required String url, required int status, required String statusText, required Headers headers, required String mimeType, required String charset, Headers? requestHeaders, required bool connectionReused, required num connectionId, String? remoteIPAddress, int? remotePort, bool? fromDiskCache, bool? fromServiceWorker, bool? fromPrefetchCache, bool? fromEarlyHints, ServiceWorkerRouterInfo? serviceWorkerRouterInfo, required num encodedDataLength, ResourceTiming? timing, ServiceWorkerResponseSource? serviceWorkerResponseSource, TimeSinceEpoch? responseTime, String? cacheStorageCacheName, String? protocol, AlternateProtocolUsage? alternateProtocolUsage, required SecurityState securityState, SecurityDetails? securityDetails})
ResponseData.fromJson(Map<String, dynamic> json)
factory

Properties

alternateProtocolUsage → AlternateProtocolUsage?
The reason why Chrome uses a specific transport protocol for HTTP semantics.
final
cacheStorageCacheName → String?
Cache Storage Cache Name.
final
charset → String
Resource charset as determined by the browser (if applicable).
final
connectionId → num
Physical connection id that was actually used for this request.
final
connectionReused → bool
Specifies whether physical connection was actually reused for this request.
final
encodedDataLength → num
Total number of bytes received for this request so far.
final
fromDiskCache → bool?
Specifies that the request was served from the disk cache.
final
fromEarlyHints → bool?
Specifies that the request was served from the prefetch cache.
final
fromPrefetchCache → bool?
Specifies that the request was served from the prefetch cache.
final
fromServiceWorker → bool?
Specifies that the request was served from the ServiceWorker.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
HTTP response headers.
final
mimeType → String
Resource mimeType as determined by the browser.
final
protocol → String?
Protocol used to fetch this request.
final
remoteIPAddress → String?
Remote IP address.
final
remotePort → int?
Remote port.
final
requestHeaders → Headers?
Refined HTTP request headers that were actually transmitted over the network.
final
responseTime → TimeSinceEpoch?
The time at which the returned response was generated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityDetails → SecurityDetails?
Security details for the request.
final
securityState → SecurityState
Security state of the request resource.
final
serviceWorkerResponseSource → ServiceWorkerResponseSource?
Response source of response from ServiceWorker.
final
serviceWorkerRouterInfo → ServiceWorkerRouterInfo?
Information about how ServiceWorker Static Router API was used. If this field is set with matchedSourceType field, a matching rule is found. If this field is set without matchedSource, no matching rule is found. Otherwise, the API is not used.
final
status → int
HTTP response status code.
final
statusText → String
HTTP response status text.
final
timing → ResourceTiming?
Timing information for the given request.
final
url → String
Response URL. This URL can be different from CachedResource.url in case of redirect.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited