ResponseReceivedEarlyHintsEvent class

Constructors

ResponseReceivedEarlyHintsEvent({required RequestId requestId, required Headers headers})
ResponseReceivedEarlyHintsEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
Raw response headers as they were received over the wire. Duplicate headers in the response are represented as a single key with their values concatentated using \n as the separator. See also headersText that contains verbatim text for HTTP/1.*.
final
requestId → RequestId
Request identifier. Used to match this information to another responseReceived event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited