SecurityDetails class

Security details about a request.

Constructors

SecurityDetails({required String protocol, required String keyExchange, String? keyExchangeGroup, required String cipher, String? mac, required CertificateId certificateId, required String subjectName, required List<String> sanList, required String issuer, required TimeSinceEpoch validFrom, required TimeSinceEpoch validTo, required List<SignedCertificateTimestamp> signedCertificateTimestampList, required CertificateTransparencyCompliance certificateTransparencyCompliance, int? serverSignatureAlgorithm, required bool encryptedClientHello})
SecurityDetails.fromJson(Map<String, dynamic> json)
factory

Properties

certificateId → CertificateId
Certificate ID value.
final
certificateTransparencyCompliance → CertificateTransparencyCompliance
Whether the request complied with Certificate Transparency policy
final
cipher → String
Cipher name.
final
encryptedClientHello → bool
Whether the connection used Encrypted ClientHello
final
hashCode → int
The hash code for this object.
no setterinherited
issuer → String
Name of the issuing CA.
final
keyExchange → String
Key Exchange used by the connection, or the empty string if not applicable.
final
keyExchangeGroup → String?
(EC)DH group used by the connection, if applicable.
final
mac → String?
TLS MAC. Note that AEAD ciphers do not have separate MACs.
final
protocol → String
Protocol name (e.g. "TLS 1.2" or "QUIC").
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanList → List<String>
Subject Alternative Name (SAN) DNS names and IP addresses.
final
serverSignatureAlgorithm → int?
The signature algorithm used by the server in the TLS server signature, represented as a TLS SignatureScheme code point. Omitted if not applicable or not known.
final
signedCertificateTimestampList → List<SignedCertificateTimestamp>
List of signed certificate timestamps (SCTs).
final
subjectName → String
Certificate subject name.
final
validFrom → TimeSinceEpoch
Certificate valid from date.
final
validTo → TimeSinceEpoch
Certificate valid to (expiration) date
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited