ServiceWorkerRouterInfo class

Constructors

ServiceWorkerRouterInfo({int? ruleIdMatched, ServiceWorkerRouterSource? matchedSourceType, ServiceWorkerRouterSource? actualSourceType})
ServiceWorkerRouterInfo.fromJson(Map<String, dynamic> json)
factory

Properties

actualSourceType → ServiceWorkerRouterSource?
The actual router source used.
final
hashCode → int
The hash code for this object.
no setterinherited
matchedSourceType → ServiceWorkerRouterSource?
The router source of the matched rule. If there is a matched rule, this field will be set, otherwise no value will be set.
final
ruleIdMatched → int?
ID of the rule matched. If there is a matched rule, this field will be set, otherwiser no value will be set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited