SignedCertificateTimestamp class

Details of a signed certificate timestamp (SCT).

Constructors

SignedCertificateTimestamp({required String status, required String origin, required String logDescription, required String logId, required num timestamp, required String hashAlgorithm, required String signatureAlgorithm, required String signatureData})
SignedCertificateTimestamp.fromJson(Map<String, dynamic> json)
factory

Properties

hashAlgorithm → String
Hash algorithm.
final
hashCode → int
The hash code for this object.
no setterinherited
logDescription → String
Log name / description.
final
logId → String
Log ID.
final
origin → String
Origin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureAlgorithm → String
Signature algorithm.
final
signatureData → String
Signature data.
final
status → String
Validation status.
final
timestamp → num
Issuance date. Unlike TimeSinceEpoch, this contains the number of milliseconds since January 1, 1970, UTC, not the number of seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited