SignedExchangeHeader class

Constructors

SignedExchangeHeader({required String requestUrl, required int responseCode, required Headers responseHeaders, required List<SignedExchangeSignature> signatures, required String headerIntegrity})
SignedExchangeHeader.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerIntegrity → String
Signed exchange header integrity hash in the form of sha256-<base64-hash-value>.
final
requestUrl → String
Signed exchange request URL.
final
responseCode → int
Signed exchange response code.
final
responseHeaders → Headers
Signed exchange response headers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures → List<SignedExchangeSignature>
Signed exchange response signature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited