SignedExchangeSignature class

Constructors

SignedExchangeSignature({required String label, required String signature, required String integrity, String? certUrl, String? certSha256, required String validityUrl, required int date, required int expires, List<String>? certificates})
SignedExchangeSignature.fromJson(Map<String, dynamic> json)
factory

Properties

certificates → List<String>?
The encoded certificates.
final
certSha256 → String?
The hex string of signed exchange signature cert sha256.
final
certUrl → String?
Signed exchange signature cert Url.
final
date → int
Signed exchange signature date.
final
expires → int
Signed exchange signature expires.
final
hashCode → int
The hash code for this object.
no setterinherited
integrity → String
Signed exchange signature integrity.
final
label → String
Signed exchange signature label.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → String
The hex string of signed exchange signature.
final
validityUrl → String
Signed exchange signature validity Url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited