TrustTokenOperationDoneEvent class

Constructors

TrustTokenOperationDoneEvent({required TrustTokenOperationDoneEventStatus status, required TrustTokenOperationType type, required RequestId requestId, String? topLevelOrigin, String? issuerOrigin, int? issuedTokenCount})
TrustTokenOperationDoneEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
issuedTokenCount → int?
The number of obtained Trust Tokens on a successful "Issuance" operation.
final
issuerOrigin → String?
Origin of the issuer in case of a "Issuance" or "Redemption" operation.
final
requestId → RequestId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TrustTokenOperationDoneEventStatus
Detailed success or error status of the operation. 'AlreadyExists' also signifies a successful operation, as the result of the operation already exists und thus, the operation was abort preemptively (e.g. a cache hit).
final
topLevelOrigin → String?
Top level origin. The context in which the operation was attempted.
final
type → TrustTokenOperationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited