WebSocketCreatedEvent class

Constructors

WebSocketCreatedEvent({required RequestId requestId, required String url, Initiator? initiator})
WebSocketCreatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
initiator → Initiator?
Request initiator.
final
requestId → RequestId
Request identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
WebSocket request URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited