WebSocketFrame class

WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.

Constructors

WebSocketFrame({required num opcode, required bool mask, required String payloadData})
WebSocketFrame.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mask → bool
WebSocket message mask.
final
opcode → num
WebSocket message opcode.
final
payloadData → String
WebSocket message payload data. If the opcode is 1, this is a text message and payloadData is a UTF-8 string. If the opcode isn't 1, then payloadData is a base64 encoded string representing binary data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited