WebSocketHandshakeResponseReceivedEvent class

Constructors

WebSocketHandshakeResponseReceivedEvent({required RequestId requestId, required MonotonicTime timestamp, required WebSocketResponse response})
WebSocketHandshakeResponseReceivedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestId → RequestId
Request identifier.
final
response → WebSocketResponse
WebSocket response data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited