WebSocketResponse class

WebSocket response data.

Constructors

WebSocketResponse({required int status, required String statusText, required Headers headers, String? headersText, Headers? requestHeaders, String? requestHeadersText})
WebSocketResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
HTTP response headers.
final
headersText → String?
HTTP response headers text.
final
requestHeaders → Headers?
HTTP request headers.
final
requestHeadersText → String?
HTTP request headers text.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
HTTP response status code.
final
statusText → String
HTTP response status text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited