WebSocketWillSendHandshakeRequestEvent class

Constructors

WebSocketWillSendHandshakeRequestEvent({required RequestId requestId, required MonotonicTime timestamp, required TimeSinceEpoch wallTime, required WebSocketRequest request})
WebSocketWillSendHandshakeRequestEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
request → WebSocketRequest
WebSocket request data.
final
requestId → RequestId
Request identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final
wallTime → TimeSinceEpoch
UTC Timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited