WebTransportConnectionEstablishedEvent class

Constructors

WebTransportConnectionEstablishedEvent({required RequestId transportId, required MonotonicTime timestamp})
WebTransportConnectionEstablishedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
Timestamp.
final
transportId → RequestId
WebTransport identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited