protocol/overlay library
Classes
- BoxStyle
- Style information for drawing a box.
- ContainerQueryContainerHighlightConfig
- ContainerQueryHighlightConfig
- DisplayCutoutConfig
- Configuration for a display cutout.
- FlexContainerHighlightConfig
- Configuration data for the highlighting of Flex container elements.
- FlexItemHighlightConfig
- Configuration data for the highlighting of Flex item elements.
- FlexNodeHighlightConfig
- GridHighlightConfig
- Configuration data for the highlighting of Grid elements.
- GridNodeHighlightConfig
- Configurations for Persistent Grid Highlight
- HighlightConfig
- Configuration data for the highlighting of page elements.
- HingeConfig
- Configuration for dual screen hinge
- InspectedElementAnchorConfig
- IsolatedElementHighlightConfig
- IsolationModeHighlightConfig
- LineStyle
- Style information for drawing a line.
- OverlayApi
- This domain provides various functionality related to drawing atop the inspected page.
- ScrollSnapContainerHighlightConfig
- ScrollSnapHighlightConfig
- SourceOrderConfig
- Configuration data for drawing the source order of an elements children.
- WindowControlsOverlayConfig
- Configuration for Window Controls Overlay
Enums
- ColorFormat
- ContrastAlgorithm
- DisplayCutoutShape
- Supported display cutout shapes.
- InspectMode
- LineStylePattern