BoxStyle class

Style information for drawing a box.

Constructors

BoxStyle({RGBA? fillColor, RGBA? hatchColor})
BoxStyle.fromJson(Map<String, dynamic> json)
factory

Properties

fillColor → RGBA?
The background color for the box (default: transparent)
final
hashCode → int
The hash code for this object.
no setterinherited
hatchColor → RGBA?
The hatching color for the box (default: transparent)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited