ContainerQueryContainerHighlightConfig class

Constructors

ContainerQueryContainerHighlightConfig({LineStyle? containerBorder, LineStyle? descendantBorder})
ContainerQueryContainerHighlightConfig.fromJson(Map<String, dynamic> json)
factory

Properties

containerBorder → LineStyle?
The style of the container border.
final
descendantBorder → LineStyle?
The style of the descendants' borders.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited