FlexContainerHighlightConfig class

Configuration data for the highlighting of Flex container elements.

Constructors

FlexContainerHighlightConfig({LineStyle? containerBorder, LineStyle? lineSeparator, LineStyle? itemSeparator, BoxStyle? mainDistributedSpace, BoxStyle? crossDistributedSpace, BoxStyle? rowGapSpace, BoxStyle? columnGapSpace, LineStyle? crossAlignment})
FlexContainerHighlightConfig.fromJson(Map<String, dynamic> json)
factory

Properties

columnGapSpace → BoxStyle?
Style of empty space caused by columns gaps (gap/column-gap).
final
containerBorder → LineStyle?
The style of the container border
final
crossAlignment → LineStyle?
Style of the self-alignment line (align-items).
final
crossDistributedSpace → BoxStyle?
Style of content-distribution space on the cross axis (align-content).
final
hashCode → int
The hash code for this object.
no setterinherited
itemSeparator → LineStyle?
The style of the separator between items
final
lineSeparator → LineStyle?
The style of the separator between lines
final
mainDistributedSpace → BoxStyle?
Style of content-distribution space on the main axis (justify-content).
final
rowGapSpace → BoxStyle?
Style of empty space caused by row gaps (gap/row-gap).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited