GridHighlightConfig class

Configuration data for the highlighting of Grid elements.

Constructors

GridHighlightConfig({bool? showGridExtensionLines, bool? showPositiveLineNumbers, bool? showNegativeLineNumbers, bool? showAreaNames, bool? showLineNames, bool? showTrackSizes, RGBA? gridBorderColor, RGBA? rowLineColor, RGBA? columnLineColor, bool? gridBorderDash, bool? rowLineDash, bool? columnLineDash, RGBA? rowGapColor, RGBA? rowHatchColor, RGBA? columnGapColor, RGBA? columnHatchColor, RGBA? areaBorderColor, RGBA? gridBackgroundColor})
GridHighlightConfig.fromJson(Map<String, dynamic> json)
factory

Properties

areaBorderColor → RGBA?
The named grid areas border color (Default: transparent).
final
columnGapColor → RGBA?
The column gap highlight fill color (default: transparent).
final
columnHatchColor → RGBA?
The column gap hatching fill color (default: transparent).
final
columnLineColor → RGBA?
The column line color (default: transparent).
final
columnLineDash → bool?
Whether column lines are dashed (default: false).
final
gridBackgroundColor → RGBA?
The grid container background color (Default: transparent).
final
gridBorderColor → RGBA?
The grid container border highlight color (default: transparent).
final
gridBorderDash → bool?
Whether the grid border is dashed (default: false).
final
hashCode → int
The hash code for this object.
no setterinherited
rowGapColor → RGBA?
The row gap highlight fill color (default: transparent).
final
rowHatchColor → RGBA?
The row gap hatching fill color (default: transparent).
final
rowLineColor → RGBA?
The row line color (default: transparent).
final
rowLineDash → bool?
Whether row lines are dashed (default: false).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAreaNames → bool?
Show area name labels (default: false).
final
showGridExtensionLines → bool?
Whether the extension lines from grid cells to the rulers should be shown (default: false).
final
showLineNames → bool?
Show line name labels (default: false).
final
showNegativeLineNumbers → bool?
Show Negative line number labels (default: false).
final
showPositiveLineNumbers → bool?
Show Positive line number labels (default: false).
final
showTrackSizes → bool?
Show track size labels (default: false).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited