HingeConfig class

Configuration for dual screen hinge

Constructors

HingeConfig({required Rect rect, RGBA? contentColor, RGBA? outlineColor})
HingeConfig.fromJson(Map<String, dynamic> json)
factory

Properties

contentColor → RGBA?
The content box highlight fill color (default: a dark color).
final
hashCode → int
The hash code for this object.
no setterinherited
outlineColor → RGBA?
The content box highlight outline color (default: transparent).
final
rect → Rect
A rectangle represent hinge
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited