InspectedElementAnchorConfig class

Constructors

InspectedElementAnchorConfig({NodeId? nodeId, BackendNodeId? backendNodeId})
InspectedElementAnchorConfig.fromJson(Map<String, dynamic> json)
factory

Properties

backendNodeId BackendNodeId?
Identifier of the backend node to highlight.
final
hashCode int
The hash code for this object.
no setterinherited
nodeId NodeId?
Identifier of the node to highlight.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited