LineStyle class

Style information for drawing a line.

Constructors

LineStyle({RGBA? color, LineStylePattern? pattern})
LineStyle.fromJson(Map<String, dynamic> json)
factory

Properties

color → RGBA?
The color of the line (default: transparent)
final
hashCode → int
The hash code for this object.
no setterinherited
pattern → LineStylePattern?
The line pattern (default: solid)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited