ScrollSnapContainerHighlightConfig class

Constructors

ScrollSnapContainerHighlightConfig({LineStyle? snapportBorder, LineStyle? snapAreaBorder, RGBA? scrollMarginColor, RGBA? scrollPaddingColor})
ScrollSnapContainerHighlightConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollMarginColor → RGBA?
The margin highlight fill color (default: transparent).
final
scrollPaddingColor → RGBA?
The padding highlight fill color (default: transparent).
final
snapAreaBorder → LineStyle?
The style of the snap area border (default: transparent)
final
snapportBorder → LineStyle?
The style of the snapport border (default: transparent)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited