SourceOrderConfig class

Configuration data for drawing the source order of an elements children.

Constructors

SourceOrderConfig({required RGBA parentOutlineColor, required RGBA childOutlineColor})
SourceOrderConfig.fromJson(Map<String, dynamic> json)
factory

Properties

childOutlineColor → RGBA
the color to outline the child elements in.
final
hashCode → int
The hash code for this object.
no setterinherited
parentOutlineColor → RGBA
the color to outline the given element in.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited