WindowControlsOverlayConfig class

Configuration for Window Controls Overlay

Constructors

WindowControlsOverlayConfig({required bool showCSS, required String selectedPlatform, required String themeColor})
WindowControlsOverlayConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedPlatform → String
Selected platforms to show the overlay.
final
showCSS → bool
Whether the title bar CSS should be shown when emulating the Window Controls Overlay.
final
themeColor → String
The theme color defined in app manifest.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited