BackForwardCacheBlockingDetails class

Constructors

BackForwardCacheBlockingDetails({String? url, String? function, required int lineNumber, required int columnNumber})
BackForwardCacheBlockingDetails.fromJson(Map<String, dynamic> json)
factory

Properties

columnNumber → int
Column number in the script (0-based).
final
function → String?
Function name where blockage happened. Optional because of anonymous functions and tests.
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
Line number in the script (0-based).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
Url of the file where blockage happened. Optional because of tests.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited