BackForwardCacheNotRestoredExplanation class

Properties

context → String?
Context associated with the reason. The meaning of this context is dependent on the reason:
final
details → List<BackForwardCacheBlockingDetails>?
final
hashCode → int
The hash code for this object.
no setterinherited
reason → BackForwardCacheNotRestoredReason
Not restored reason
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BackForwardCacheNotRestoredReasonType
Type of the reason
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited