BackForwardCacheNotUsedEvent class

Constructors

BackForwardCacheNotUsedEvent({required LoaderId loaderId, required FrameId frameId, required List<BackForwardCacheNotRestoredExplanation> notRestoredExplanations, BackForwardCacheNotRestoredExplanationTree? notRestoredExplanationsTree})
BackForwardCacheNotUsedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
The frame id of the associated frame.
final
hashCode → int
The hash code for this object.
no setterinherited
loaderId → LoaderId
The loader id for the associated navigation.
final
notRestoredExplanations → List<BackForwardCacheNotRestoredExplanation>
Array of reasons why the page could not be cached. This must not be empty.
final
notRestoredExplanationsTree → BackForwardCacheNotRestoredExplanationTree?
Tree structure of reasons why the page could not be cached for each frame.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited