CompilationCacheParams class

Per-script compilation cache parameters for Page.produceCompilationCache

Constructors

CompilationCacheParams({required String url, bool? eager})
CompilationCacheParams.fromJson(Map<String, dynamic> json)
factory

Properties

eager → bool?
A hint to the backend whether eager compilation is recommended. (the actual compilation mode used is upon backend discretion).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The URL of the script to produce a compilation cache entry for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited