FrameAttachedEvent class

Constructors

FrameAttachedEvent({required FrameId frameId, required FrameId parentFrameId, StackTraceData? stack})
FrameAttachedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
Id of the frame that has been attached.
final
hashCode → int
The hash code for this object.
no setterinherited
parentFrameId → FrameId
Parent frame identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → StackTraceData?
JavaScript stack trace of when frame was attached, only set if frame initiated from script.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited