FrameDetachedEvent class

Constructors

FrameDetachedEvent({required FrameId frameId, required FrameDetachedEventReason reason})
FrameDetachedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
Id of the frame that has been detached.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → FrameDetachedEventReason
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited