FrameNavigatedEvent class

Constructors

FrameNavigatedEvent({required FrameInfo frame, required NavigationType type})
FrameNavigatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frame → FrameInfo
Frame object.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NavigationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited