FrameRequestedNavigationEvent class

Constructors

FrameRequestedNavigationEvent({required FrameId frameId, required ClientNavigationReason reason, required String url, required ClientNavigationDisposition disposition})
FrameRequestedNavigationEvent.fromJson(Map<String, dynamic> json)
factory

Properties

disposition → ClientNavigationDisposition
The disposition for the navigation.
final
frameId → FrameId
Id of the frame that is being navigated.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → ClientNavigationReason
The reason for the navigation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The destination URL for the requested navigation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited