FrameResource class

Information about the Resource on the page.

Constructors

FrameResource({required String url, required ResourceType type, required String mimeType, TimeSinceEpoch? lastModified, num? contentSize, bool? failed, bool? canceled})
FrameResource.fromJson(Map<String, dynamic> json)
factory

Properties

canceled → bool?
True if the resource was canceled during loading.
final
contentSize → num?
Resource content size.
final
failed → bool?
True if the resource failed to load.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → TimeSinceEpoch?
last-modified timestamp as reported by server.
final
mimeType → String
Resource mimeType as determined by the browser.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ResourceType
Type of this resource.
final
url → String
Resource URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited