FrameResourceTree class

Information about the Frame hierarchy along with their cached resources.

Constructors

FrameResourceTree({required FrameInfo frame, List<FrameResourceTree>? childFrames, required List<FrameResource> resources})
FrameResourceTree.fromJson(Map<String, dynamic> json)
factory

Properties

childFrames → List<FrameResourceTree>?
Child frames.
final
frame → FrameInfo
Frame information for this tree item.
final
hashCode → int
The hash code for this object.
no setterinherited
resources → List<FrameResource>
Information about frame resources.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited