FrameScheduledNavigationEvent class

Constructors

FrameScheduledNavigationEvent({required FrameId frameId, required num delay, required ClientNavigationReason reason, required String url})
FrameScheduledNavigationEvent.fromJson(Map<String, dynamic> json)
factory

Properties

delay → num
Delay (in seconds) until the navigation is scheduled to begin. The navigation is not guaranteed to start.
final
frameId → FrameId
Id of the frame that has scheduled a navigation.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → ClientNavigationReason
The reason for the navigation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The destination URL for the scheduled navigation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited