FrameStartedNavigatingEvent class

Constructors

FrameStartedNavigatingEvent({required FrameId frameId, required String url, required LoaderId loaderId, required FrameStartedNavigatingEventNavigationType navigationType})
FrameStartedNavigatingEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
ID of the frame that is being navigated.
final
hashCode → int
The hash code for this object.
no setterinherited
loaderId → LoaderId
Loader identifier. Even though it is present in case of same-document navigation, the previously committed loaderId would not change unless the navigation changes from a same-document to a cross-document navigation.
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The URL the navigation started with. The final URL can be different.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited