GetLayoutMetricsResult class

Constructors

GetLayoutMetricsResult({required LayoutViewport cssLayoutViewport, required VisualViewport cssVisualViewport, required Rect cssContentSize})
GetLayoutMetricsResult.fromJson(Map<String, dynamic> json)
factory

Properties

cssContentSize → Rect
Size of scrollable area in CSS pixels.
final
cssLayoutViewport → LayoutViewport
Metrics relating to the layout viewport in CSS pixels.
final
cssVisualViewport → VisualViewport
Metrics relating to the visual viewport in CSS pixels.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited