ImageResource class

The image definition used in both icon and screenshot.

Constructors

ImageResource({required String url, String? sizes, String? type})
ImageResource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizes → String?
final
type → String?
final
url → String
The src field in the definition, but changing to url in favor of consistency.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited