InstallabilityError class

The installability error

Constructors

InstallabilityError({required String errorId, required List<InstallabilityErrorArgument> errorArguments})
InstallabilityError.fromJson(Map<String, dynamic> json)
factory

Properties

errorArguments → List<InstallabilityErrorArgument>
The list of error arguments (e.g. {name:'minimum-icon-size-in-pixels', value:'64'}).
final
errorId → String
The error id (e.g. 'manifest-missing-suitable-icon').
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited