LayoutViewport class

Layout viewport position and dimensions.

Constructors

LayoutViewport({required int pageX, required int pageY, required int clientWidth, required int clientHeight})
LayoutViewport.fromJson(Map<String, dynamic> json)
factory

Properties

clientHeight → int
Height (CSS pixels), excludes scrollbar if present.
final
clientWidth → int
Width (CSS pixels), excludes scrollbar if present.
final
hashCode → int
The hash code for this object.
no setterinherited
pageX → int
Horizontal offset relative to the document (CSS pixels).
final
pageY → int
Vertical offset relative to the document (CSS pixels).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited