LifecycleEventEvent class

Constructors

LifecycleEventEvent({required FrameId frameId, required LoaderId loaderId, required String name, required MonotonicTime timestamp})
LifecycleEventEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
Id of the frame.
final
hashCode → int
The hash code for this object.
no setterinherited
loaderId → LoaderId
Loader identifier. Empty string if the request is fetched from worker.
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → MonotonicTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited