NavigateResult class

Constructors

factory

Properties

errorText → String?
User friendly error message, present if and only if navigation has failed.
final
frameId → FrameId
Frame id that has navigated (or failed to navigate)
final
hashCode → int
The hash code for this object.
no setterinherited
isDownload → bool?
Whether the navigation resulted in a download.
final
loaderId → LoaderId?
Loader identifier. This is omitted in case of same-document navigation, as the previously committed loaderId would not change.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited