NavigationEntry class

Navigation history entry.

Constructors

factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Unique id of the navigation history entry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Title of the navigation history entry.
final
transitionType → TransitionType
Transition type.
final
url → String
URL of the navigation history entry.
final
userTypedURL → String
URL that the user typed in the url bar.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited