PermissionsPolicyFeatureState class

Constructors

PermissionsPolicyFeatureState({required PermissionsPolicyFeature feature, required bool allowed, PermissionsPolicyBlockLocator? locator})
PermissionsPolicyFeatureState.fromJson(Map<String, dynamic> json)
factory

Properties

allowed → bool
final
feature → PermissionsPolicyFeature
final
hashCode → int
The hash code for this object.
no setterinherited
locator → PermissionsPolicyBlockLocator?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited