PrintToPDFResult class

Constructors

PrintToPDFResult({required String data, StreamHandle? stream})
PrintToPDFResult.fromJson(Map<String, dynamic> json)
factory

Properties

data → String
Base64-encoded pdf data. Empty if |returnAsStream| is specified.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → StreamHandle?
A handle of the stream that holds resulting PDF data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited