ScreencastFrameMetadata class

Screencast frame metadata.

Constructors

ScreencastFrameMetadata({required num offsetTop, required num pageScaleFactor, required num deviceWidth, required num deviceHeight, required num scrollOffsetX, required num scrollOffsetY, TimeSinceEpoch? timestamp})
ScreencastFrameMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

deviceHeight → num
Device screen height in DIP.
final
deviceWidth → num
Device screen width in DIP.
final
hashCode → int
The hash code for this object.
no setterinherited
offsetTop → num
Top offset in DIP.
final
pageScaleFactor → num
Page scale factor.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollOffsetX → num
Position of horizontal scroll in CSS pixels.
final
scrollOffsetY → num
Position of vertical scroll in CSS pixels.
final
timestamp → TimeSinceEpoch?
Frame swap timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited