ScriptFontFamilies class

Font families collection for a script.

Constructors

ScriptFontFamilies({required String script, required FontFamilies fontFamilies})
ScriptFontFamilies.fromJson(Map<String, dynamic> json)
factory

Properties

fontFamilies → FontFamilies
Generic font families collection for the script.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → String
Name of the script which these font families are defined for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited