ShareTarget class

Constructors

ShareTarget({required String action, required String method, required String enctype, String? title, String? text, String? url, List<FileFilter>? files})
ShareTarget.fromJson(Map<String, dynamic> json)
factory

Properties

action → String
final
enctype → String
final
files → List<FileFilter>?
final
hashCode → int
The hash code for this object.
no setterinherited
method → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
title → String?
Embed the ShareTargetParams
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited