VisualViewport class

Visual viewport position, dimensions, and scale.

Constructors

VisualViewport({required num offsetX, required num offsetY, required num pageX, required num pageY, required num clientWidth, required num clientHeight, required num scale, num? zoom})
VisualViewport.fromJson(Map<String, dynamic> json)
factory

Properties

clientHeight → num
Height (CSS pixels), excludes scrollbar if present.
final
clientWidth → num
Width (CSS pixels), excludes scrollbar if present.
final
hashCode → int
The hash code for this object.
no setterinherited
offsetX → num
Horizontal offset relative to the layout viewport (CSS pixels).
final
offsetY → num
Vertical offset relative to the layout viewport (CSS pixels).
final
pageX → num
Horizontal offset relative to the document (CSS pixels).
final
pageY → num
Vertical offset relative to the document (CSS pixels).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → num
Scale relative to the ideal viewport (size at width=device-width).
final
zoom → num?
Page zoom factor (CSS to device independent pixels ratio).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited