WindowOpenEvent class

Constructors

WindowOpenEvent({required String url, required String windowName, required List<String> windowFeatures, required bool userGesture})
WindowOpenEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The URL for the new window.
final
userGesture → bool
Whether or not it was triggered by user gesture.
final
windowFeatures → List<String>
An array of enabled window features.
final
windowName → String
Window name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited