MetricsEvent class

Constructors

MetricsEvent({required List<Metric> metrics, required String title})
MetricsEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metrics → List<Metric>
Current values of the metrics.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Timestamp title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited