LayoutShift class

Constructors

LayoutShift({required num value, required bool hadRecentInput, required TimeSinceEpoch lastInputTime, required List<LayoutShiftAttribution> sources})
LayoutShift.fromJson(Map<String, dynamic> json)
factory

Properties

hadRecentInput → bool
final
hashCode → int
The hash code for this object.
no setterinherited
lastInputTime → TimeSinceEpoch
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources → List<LayoutShiftAttribution>
final
value → num
Score increment produced by this event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited