LayoutShiftAttribution class

Constructors

LayoutShiftAttribution({required Rect previousRect, required Rect currentRect, BackendNodeId? nodeId})
LayoutShiftAttribution.fromJson(Map<String, dynamic> json)
factory

Properties

currentRect → Rect
final
hashCode → int
The hash code for this object.
no setterinherited
nodeId → BackendNodeId?
final
previousRect → Rect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited