PerformanceTimelineApi class

Reporting of performance timeline events, as specified in https://w3c.github.io/performance-timeline/#dom-performanceobserver.

Constructors

PerformanceTimelineApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onTimelineEventAdded → Stream<TimelineEvent>
Sent when a performance timeline event is added. See reportPerformanceTimeline method.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enable(List<String> eventTypes) → Future<void>
Previously buffered events would be reported before method returns. See also: timelineEventAdded eventTypes The types of event to report, as specified in https://w3c.github.io/performance-timeline/#dom-performanceentry-entrytype The specified filter overrides any previous filters, passing empty filter disables recording. Note that not all types exposed to the web platform are currently supported.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited