TimelineEvent class

Constructors

TimelineEvent({required FrameId frameId, required String type, required String name, required TimeSinceEpoch time, num? duration, LargestContentfulPaint? lcpDetails, LayoutShift? layoutShiftDetails})
TimelineEvent.fromJson(Map<String, dynamic> json)
factory

Properties

duration → num?
Event duration, if applicable.
final
frameId → FrameId
Identifies the frame that this event is related to. Empty for non-frame targets.
final
hashCode → int
The hash code for this object.
no setterinherited
layoutShiftDetails → LayoutShift?
final
lcpDetails → LargestContentfulPaint?
final
name → String
Name may be empty depending on the type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → TimeSinceEpoch
Time in seconds since Epoch, monotonically increasing within document lifetime.
final
type → String
The event type, as specified in https://w3c.github.io/performance-timeline/#dom-performanceentry-entrytype This determines which of the optional "details" fields is present.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited