PrefetchStatusUpdatedEvent class

Constructors

PrefetchStatusUpdatedEvent({required PreloadingAttemptKey key, required PreloadPipelineId pipelineId, required FrameId initiatingFrameId, required String prefetchUrl, required PreloadingStatus status, required PrefetchStatus prefetchStatus, required RequestId requestId})
PrefetchStatusUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
initiatingFrameId → FrameId
The frame id of the frame initiating prefetch.
final
key → PreloadingAttemptKey
final
pipelineId → PreloadPipelineId
final
prefetchStatus → PrefetchStatus
final
prefetchUrl → String
final
requestId → RequestId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → PreloadingStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited