PreloadApi class

Constructors

PreloadApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onPrefetchStatusUpdated → Stream<PrefetchStatusUpdatedEvent>
Fired when a prefetch attempt is updated.
no setter
onPreloadEnabledStateUpdated → Stream<PreloadEnabledStateUpdatedEvent>
Fired when a preload enabled state is updated.
no setter
onPreloadingAttemptSourcesUpdated → Stream<PreloadingAttemptSourcesUpdatedEvent>
Send a list of sources for all preloading attempts in a document.
no setter
onPrerenderStatusUpdated → Stream<PrerenderStatusUpdatedEvent>
Fired when a prerender attempt is updated.
no setter
onRuleSetRemoved → Stream<RuleSetId>
no setter
onRuleSetUpdated → Stream<RuleSet>
Upsert. Currently, it is only emitted when a rule set added.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable() → Future<void>
enable() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited