PreloadEnabledStateUpdatedEvent class

Constructors

PreloadEnabledStateUpdatedEvent({required bool disabledByPreference, required bool disabledByDataSaver, required bool disabledByBatterySaver, required bool disabledByHoldbackPrefetchSpeculationRules, required bool disabledByHoldbackPrerenderSpeculationRules})
PreloadEnabledStateUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

disabledByBatterySaver → bool
final
disabledByDataSaver → bool
final
disabledByHoldbackPrefetchSpeculationRules → bool
final
disabledByHoldbackPrerenderSpeculationRules → bool
final
disabledByPreference → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited