PreloadingAttemptKey class

A key that identifies a preloading attempt.

The url used is the url specified by the trigger (i.e. the initial URL), and not the final url that is navigated to. For example, prerendering allows same-origin main frame navigations during the attempt, but the attempt is still keyed with the initial URL.

Constructors

PreloadingAttemptKey({required LoaderId loaderId, required SpeculationAction action, required String url, bool? formSubmission, SpeculationTargetHint? targetHint})
PreloadingAttemptKey.fromJson(Map<String, dynamic> json)
factory

Properties

action → SpeculationAction
final
formSubmission → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
loaderId → LoaderId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetHint → SpeculationTargetHint?
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited