PreloadingAttemptSourcesUpdatedEvent class

Constructors

PreloadingAttemptSourcesUpdatedEvent({required LoaderId loaderId, required List<PreloadingAttemptSource> preloadingAttemptSources})
PreloadingAttemptSourcesUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
loaderId → LoaderId
final
preloadingAttemptSources → List<PreloadingAttemptSource>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited