PrerenderStatusUpdatedEvent class

Constructors

PrerenderStatusUpdatedEvent({required PreloadingAttemptKey key, required PreloadPipelineId pipelineId, required PreloadingStatus status, PrerenderFinalStatus? prerenderStatus, String? disallowedMojoInterface, List<PrerenderMismatchedHeaders>? mismatchedHeaders})
PrerenderStatusUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

disallowedMojoInterface → String?
This is used to give users more information about the name of Mojo interface that is incompatible with prerender and has caused the cancellation of the attempt.
final
hashCode → int
The hash code for this object.
no setterinherited
key → PreloadingAttemptKey
final
mismatchedHeaders → List<PrerenderMismatchedHeaders>?
final
pipelineId → PreloadPipelineId
final
prerenderStatus → PrerenderFinalStatus?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → PreloadingStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited