ConsoleProfileFinishedEvent class

Constructors

ConsoleProfileFinishedEvent({required String id, required Location location, required Profile profile, String? title})
ConsoleProfileFinishedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
location → Location
Location of console.profileEnd().
final
profile → Profile
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Profile title passed as an argument to console.profile().
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited