FunctionCoverage class

Coverage data for a JavaScript function.

Constructors

FunctionCoverage({required String functionName, required List<CoverageRange> ranges, required bool isBlockCoverage})
FunctionCoverage.fromJson(Map<String, dynamic> json)
factory

Properties

functionName → String
JavaScript function name.
final
hashCode → int
The hash code for this object.
no setterinherited
isBlockCoverage → bool
Whether coverage data for this function has block granularity.
final
ranges → List<CoverageRange>
Source ranges inside the function with coverage data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited