ProfileNode class

Profile node. Holds callsite information, execution statistics and child nodes.

Constructors

ProfileNode({required int id, required CallFrame callFrame, int? hitCount, List<int>? children, String? deoptReason, List<PositionTickInfo>? positionTicks})
ProfileNode.fromJson(Map<String, dynamic> json)
factory

Properties

callFrame → CallFrame
Function location.
final
children → List<int>?
Child node ids.
final
deoptReason → String?
The reason of being not optimized. The function may be deoptimized or marked as don't optimize.
final
hashCode → int
The hash code for this object.
no setterinherited
hitCount → int?
Number of samples where this node was on top of the call stack.
final
id → int
Unique id of the node.
final
positionTicks → List<PositionTickInfo>?
An array of source position ticks.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited