CallArgument class

Represents function call argument. Either remote object id objectId, primitive value, unserializable primitive value or neither of (for undefined) them should be specified.

Constructors

CallArgument({dynamic value, UnserializableValue? unserializableValue, RemoteObjectId? objectId})
CallArgument.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
objectId → RemoteObjectId?
Remote object handle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unserializableValue → UnserializableValue?
Primitive value which can not be JSON-stringified.
final
value → dynamic
Primitive value or serializable javascript object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited