CallFrame class

Stack entry for runtime errors and assertions.

Constructors

CallFrame({required String functionName, required ScriptId scriptId, required String url, required int lineNumber, required int columnNumber})
CallFrame.fromJson(Map<String, dynamic> json)
factory

Properties

columnNumber → int
JavaScript script column number (0-based).
final
functionName → String
JavaScript function name.
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
JavaScript script line number (0-based).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptId → ScriptId
JavaScript script id.
final
url → String
JavaScript script name or url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited