ConsoleAPICalledEvent class

Constructors

ConsoleAPICalledEvent({required ConsoleAPICalledEventType type, required List<RemoteObject> args, required ExecutionContextId executionContextId, required Timestamp timestamp, StackTraceData? stackTrace, String? context})
ConsoleAPICalledEvent.fromJson(Map<String, dynamic> json)
factory

Properties

args → List<RemoteObject>
Call arguments.
final
context → String?
Console context descriptor for calls on non-default console context (not console.*): 'anonymous#unique-logger-id' for call on unnamed context, 'name#unique-logger-id' for call on named context.
final
executionContextId → ExecutionContextId
Identifier of the context where the call was made.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTraceData?
Stack trace captured when the call was made. The async stack chain is automatically reported for the following call types: assert, error, trace, warning. For other types the async call chain can be retrieved using Debugger.getStackTrace and stackTrace.parentId field.
final
timestamp → Timestamp
Call timestamp.
final
type → ConsoleAPICalledEventType
Type of the call.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited