CustomPreview class

Constructors

CustomPreview({required String header, RemoteObjectId? bodyGetterId})
CustomPreview.fromJson(Map<String, dynamic> json)
factory

Properties

bodyGetterId → RemoteObjectId?
If formatter returns true as a result of formatter.hasBody call then bodyGetterId will contain RemoteObjectId for the function that returns result of formatter.body(object, config) call. The result value is json ML array.
final
hashCode → int
The hash code for this object.
no setterinherited
The JSON-stringified result of formatter.header(object, config) call. It contains json ML array that represents RemoteObject.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited