ExceptionDetails class

Detailed information about exception (or error) that was thrown during script compilation or execution.

Constructors

ExceptionDetails({required int exceptionId, required String text, required int lineNumber, required int columnNumber, ScriptId? scriptId, String? url, StackTraceData? stackTrace, RemoteObject? exception, ExecutionContextId? executionContextId, Map<String, dynamic>? exceptionMetaData})
ExceptionDetails.fromJson(Map<String, dynamic> json)
factory

Properties

columnNumber → int
Column number of the exception location (0-based).
final
exception → RemoteObject?
Exception object if available.
final
exceptionId → int
Exception id.
final
exceptionMetaData → Map<String, dynamic>?
Dictionary with entries of meta data that the client associated with this exception, such as information about associated network requests, etc.
final
executionContextId → ExecutionContextId?
Identifier of the context where exception happened.
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
Line number of the exception location (0-based).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptId → ScriptId?
Script ID of the exception location.
final
stackTrace → StackTraceData?
JavaScript stack trace if available.
final
text → String
Exception text, which should be used together with exception object when available.
final
url → String?
URL of the exception location, to be used when the script was not reported.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited