ExceptionRevokedEvent class

Constructors

ExceptionRevokedEvent({required String reason, required int exceptionId})
ExceptionRevokedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

exceptionId → int
The id of revoked exception, as reported in exceptionThrown.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → String
Reason describing why exception was revoked.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited