ExecutionContextDescription class

Description of an isolated world.

Constructors

ExecutionContextDescription({required ExecutionContextId id, required String origin, required String name, required String uniqueId, Map<String, dynamic>? auxData})
ExecutionContextDescription.fromJson(Map<String, dynamic> json)
factory

Properties

auxData → Map<String, dynamic>?
Embedder-specific auxiliary data likely matching {isDefault: boolean, type: 'default'|'isolated'|'worker', frameId: string}
final
hashCode → int
The hash code for this object.
no setterinherited
id → ExecutionContextId
Unique id of the execution context. It can be used to specify in which execution context script evaluation should be performed.
final
name → String
Human readable name describing given context.
final
origin → String
Execution context origin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueId → String
A system-unique execution context identifier. Unlike the id, this is unique across multiple processes, so can be reliably used to identify specific context while backend performs a cross-process navigation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited