GetHeapUsageResult class

Constructors

GetHeapUsageResult({required num usedSize, required num totalSize, required num embedderHeapUsedSize, required num backingStorageSize})
GetHeapUsageResult.fromJson(Map<String, dynamic> json)
factory

Properties

backingStorageSize → num
Size in bytes of backing storage for array buffers and external strings.
final
embedderHeapUsedSize → num
Used size in bytes in the embedder's garbage-collected heap.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize → num
Allocated JavaScript heap size in bytes.
final
usedSize → num
Used JavaScript heap size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited