GetPropertiesResult class

Constructors

GetPropertiesResult({required List<PropertyDescriptor> result, List<InternalPropertyDescriptor>? internalProperties, List<PrivatePropertyDescriptor>? privateProperties, ExceptionDetails? exceptionDetails})
GetPropertiesResult.fromJson(Map<String, dynamic> json)
factory

Properties

exceptionDetails → ExceptionDetails?
Exception details.
final
hashCode → int
The hash code for this object.
no setterinherited
internalProperties → List<InternalPropertyDescriptor>?
Internal object properties (only of the element itself).
final
privateProperties → List<PrivatePropertyDescriptor>?
Object private properties.
final
result → List<PropertyDescriptor>
Object properties.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited