InspectRequestedEvent class

Constructors

InspectRequestedEvent({required RemoteObject object, required Map<String, dynamic> hints, ExecutionContextId? executionContextId})
InspectRequestedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

executionContextId → ExecutionContextId?
Identifier of the context where the call was made.
final
hashCode → int
The hash code for this object.
no setterinherited
hints → Map<String, dynamic>
final
object → RemoteObject
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited