InternalPropertyDescriptor class

Object internal property descriptor. This property isn't normally visible in JavaScript code.

Constructors

InternalPropertyDescriptor({required String name, RemoteObject? value})
InternalPropertyDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Conventional property name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → RemoteObject?
The value associated with the property.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited