ObjectPreview class

Object containing abbreviated remote object value.

Constructors

ObjectPreview({required ObjectPreviewType type, ObjectPreviewSubtype? subtype, String? description, required bool overflow, required List<PropertyPreview> properties, List<EntryPreview>? entries})
ObjectPreview.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
String representation of the object.
final
entries → List<EntryPreview>?
List of the entries. Specified for map and set subtype values only.
final
hashCode → int
The hash code for this object.
no setterinherited
overflow → bool
True iff some of the properties or entries of the original object did not fit.
final
properties → List<PropertyPreview>
List of the properties.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → ObjectPreviewSubtype?
Object subtype hint. Specified for object type values only.
final
type → ObjectPreviewType
Object type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited