PrivatePropertyDescriptor class

Object private field descriptor.

Constructors

PrivatePropertyDescriptor({required String name, RemoteObject? value, RemoteObject? get, RemoteObject? set})
PrivatePropertyDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

get → RemoteObject?
A function which serves as a getter for the private property, or undefined if there is no getter (accessor descriptors only).
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Private property name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set → RemoteObject?
A function which serves as a setter for the private property, or undefined if there is no setter (accessor descriptors only).
final
value → RemoteObject?
The value associated with the private property.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited