PropertyDescriptor class

Object property descriptor.

Constructors

PropertyDescriptor({required String name, RemoteObject? value, bool? writable, RemoteObject? get, RemoteObject? set, required bool configurable, required bool enumerable, bool? wasThrown, bool? isOwn, RemoteObject? symbol})
PropertyDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

configurable → bool
True if the type of this property descriptor may be changed and if the property may be deleted from the corresponding object.
final
enumerable → bool
True if this property shows up during enumeration of the properties on the corresponding object.
final
get → RemoteObject?
A function which serves as a getter for the property, or undefined if there is no getter (accessor descriptors only).
final
hashCode → int
The hash code for this object.
no setterinherited
isOwn → bool?
True if the property is owned for the object.
final
name → String
Property name or symbol description.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set → RemoteObject?
A function which serves as a setter for the property, or undefined if there is no setter (accessor descriptors only).
final
symbol → RemoteObject?
Property symbol object, if the property is of the symbol type.
final
value → RemoteObject?
The value associated with the property.
final
wasThrown → bool?
True if the result was thrown during the evaluation.
final
writable → bool?
True if the value associated with the property may be changed (data descriptors only).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited