PropertyPreview class

Constructors

PropertyPreview({required String name, required PropertyPreviewType type, String? value, ObjectPreview? valuePreview, PropertyPreviewSubtype? subtype})
PropertyPreview.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Property name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → PropertyPreviewSubtype?
Object subtype hint. Specified for object type values only.
final
type → PropertyPreviewType
Object type. Accessor means that the property itself is an accessor property.
final
value → String?
User-friendly property value string.
final
valuePreview → ObjectPreview?
Nested value preview.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited