PropertyPreviewType enum

Inheritance
Available extensions

Values

object → const PropertyPreviewType
const PropertyPreviewType('object')
function → const PropertyPreviewType
const PropertyPreviewType('function')
undefined → const PropertyPreviewType
const PropertyPreviewType('undefined')
string → const PropertyPreviewType
const PropertyPreviewType('string')
number → const PropertyPreviewType
const PropertyPreviewType('number')
boolean → const PropertyPreviewType
const PropertyPreviewType('boolean')
symbol → const PropertyPreviewType
const PropertyPreviewType('symbol')
accessor → const PropertyPreviewType
const PropertyPreviewType('accessor')
bigint → const PropertyPreviewType
const PropertyPreviewType('bigint')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PropertyPreviewType>
A constant List of the values in this enum, in order of their declaration.