RemoteObject class

Mirror object referencing original JavaScript object.

Constructors

RemoteObject({required RemoteObjectType type, RemoteObjectSubtype? subtype, String? className, dynamic value, UnserializableValue? unserializableValue, String? description, DeepSerializedValue? deepSerializedValue, RemoteObjectId? objectId, ObjectPreview? preview, CustomPreview? customPreview})
RemoteObject.fromJson(Map<String, dynamic> json)
factory

Properties

className → String?
Object class (constructor) name. Specified for object type values only.
final
customPreview → CustomPreview?
final
deepSerializedValue → DeepSerializedValue?
Deep serialized value.
final
description → String?
String representation of the object.
final
hashCode → int
The hash code for this object.
no setterinherited
objectId → RemoteObjectId?
Unique object identifier (for non-primitive values).
final
preview → ObjectPreview?
Preview containing abbreviated property values. Specified for object type values only.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → RemoteObjectSubtype?
Object subtype hint. Specified for object type values only. NOTE: If you change anything here, make sure to also update subtype in ObjectPreview and PropertyPreview below.
final
type → RemoteObjectType
Object type.
final
unserializableValue → UnserializableValue?
Primitive value which can not be JSON-stringified does not have value, but gets this property.
final
value → dynamic
Remote object value in case of primitive values or JSON values (if it was requested).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited