RunScriptResult class

Constructors

RunScriptResult({required RemoteObject result, ExceptionDetails? exceptionDetails})
RunScriptResult.fromJson(Map<String, dynamic> json)
factory

Properties

exceptionDetails → ExceptionDetails?
Exception details.
final
hashCode → int
The hash code for this object.
no setterinherited
result → RemoteObject
Run result.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited