SerializationOptions class

Represents options for serialization. Overrides generatePreview and returnByValue.

Constructors

SerializationOptions({required SerializationOptionsSerialization serialization, int? maxDepth, Map<String, dynamic>? additionalParameters})
SerializationOptions.fromJson(Map<String, dynamic> json)
factory

Properties

additionalParameters → Map<String, dynamic>?
Embedder-specific parameters. For example if connected to V8 in Chrome these control DOM serialization via maxNodeDepth: integer and includeShadowTree: "none" | "open" | "all". Values can be only of type string or integer.
final
hashCode → int
The hash code for this object.
no setterinherited
maxDepth → int?
Deep serialization depth. Default is full depth. Respected only in deep serialization mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialization → SerializationOptionsSerialization
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited