StackTraceData class

Call frames for assertions or error messages.

Constructors

StackTraceData({String? description, required List<CallFrame> callFrames, StackTraceData? parent, StackTraceId? parentId})
StackTraceData.fromJson(Map<String, dynamic> json)
factory

Properties

callFrames → List<CallFrame>
JavaScript function name.
final
description → String?
String label of this stack trace. For async traces this may be a name of the function that initiated the async call.
final
hashCode → int
The hash code for this object.
no setterinherited
parent → StackTraceData?
Asynchronous JavaScript stack trace that preceded this stack, if available.
final
parentId → StackTraceId?
Asynchronous JavaScript stack trace that preceded this stack, if available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited