StackTraceId class

If debuggerId is set stack trace comes from another debugger and can be resolved there. This allows to track cross-debugger calls. See Runtime.StackTrace and Debugger.paused for usages.

Constructors

StackTraceId({required String id, UniqueDebuggerId? debuggerId})
StackTraceId.fromJson(Map<String, dynamic> json)
factory

Properties

debuggerId → UniqueDebuggerId?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited