Domain class

Description of the protocol domain.

Constructors

Domain({required String name, required String version})
Domain.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Domain name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
Domain version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited