CertificateErrorEvent class

Constructors

CertificateErrorEvent({required int eventId, required String errorType, required String requestURL})
CertificateErrorEvent.fromJson(Map<String, dynamic> json)
factory

Properties

errorType → String
The type of the error.
final
eventId → int
The ID of the event.
final
hashCode → int
The hash code for this object.
no setterinherited
requestURL → String
The url that was requested.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited