InsecureContentStatus class

Information about insecure content on the page.

Constructors

InsecureContentStatus({required bool ranMixedContent, required bool displayedMixedContent, required bool containedMixedForm, required bool ranContentWithCertErrors, required bool displayedContentWithCertErrors, required SecurityState ranInsecureContentStyle, required SecurityState displayedInsecureContentStyle})
InsecureContentStatus.fromJson(Map<String, dynamic> json)
factory

Properties

containedMixedForm → bool
Always false.
final
displayedContentWithCertErrors → bool
Always false.
final
displayedInsecureContentStyle → SecurityState
Always set to unknown.
final
displayedMixedContent → bool
Always false.
final
hashCode → int
The hash code for this object.
no setterinherited
ranContentWithCertErrors → bool
Always false.
final
ranInsecureContentStyle → SecurityState
Always set to unknown.
final
ranMixedContent → bool
Always false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited