MixedContentType enum

A description of mixed content (HTTP resources on HTTPS pages), as defined by https://www.w3.org/TR/mixed-content/#categories

Inheritance
Available extensions

Values

blockable → const MixedContentType
const MixedContentType('blockable')
optionallyBlockable → const MixedContentType
const MixedContentType('optionally-blockable')
none → const MixedContentType
const MixedContentType('none')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MixedContentType>
A constant List of the values in this enum, in order of their declaration.