SecurityStateExplanation class

An explanation of an factor contributing to the security state.

Constructors

SecurityStateExplanation({required SecurityState securityState, required String title, required String summary, required String description, required MixedContentType mixedContentType, required List<String> certificate, List<String>? recommendations})
SecurityStateExplanation.fromJson(Map<String, dynamic> json)
factory

Properties

certificate → List<String>
Page certificate.
final
description → String
Full text explanation of the factor.
final
hashCode → int
The hash code for this object.
no setterinherited
mixedContentType → MixedContentType
The type of mixed content described by the explanation.
final
recommendations → List<String>?
Recommendations to fix any issues.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityState → SecurityState
Security state representing the severity of the factor being explained.
final
summary → String
Short phrase describing the type of factor.
final
title → String
Title describing the type of factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited