VisibleSecurityState class

Security state information about the page.

Constructors

VisibleSecurityState({required SecurityState securityState, CertificateSecurityState? certificateSecurityState, SafetyTipInfo? safetyTipInfo, required List<String> securityStateIssueIds})
VisibleSecurityState.fromJson(Map<String, dynamic> json)
factory

Properties

certificateSecurityState → CertificateSecurityState?
Security state details about the page certificate.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetyTipInfo → SafetyTipInfo?
The type of Safety Tip triggered on the page. Note that this field will be set even if the Safety Tip UI was not actually shown.
final
securityState → SecurityState
The security level of the page.
final
securityStateIssueIds → List<String>
Array of security state issues ids.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited