ServiceWorkerApi class

Constructors

ServiceWorkerApi(Client _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onWorkerErrorReported → Stream<ServiceWorkerErrorMessage>
no setter
onWorkerRegistrationUpdated → Stream<List<ServiceWorkerRegistration>>
no setter
onWorkerVersionUpdated → Stream<List<ServiceWorkerVersion>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deliverPushMessage(String origin, RegistrationID registrationId, String data) → Future<void>
disable() → Future<void>
dispatchPeriodicSyncEvent(String origin, RegistrationID registrationId, String tag) → Future<void>
dispatchSyncEvent(String origin, RegistrationID registrationId, String tag, bool lastChance) → Future<void>
enable() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setForceUpdateOnPageLoad(bool forceUpdateOnPageLoad) → Future<void>
skipWaiting(String scopeURL) → Future<void>
startWorker(String scopeURL) → Future<void>
stopAllWorkers() → Future<void>
stopWorker(String versionId) → Future<void>
toString() → String
A string representation of this object.
inherited
unregister(String scopeURL) → Future<void>
updateRegistration(String scopeURL) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited