ServiceWorkerErrorMessage class

ServiceWorker error message.

Constructors

ServiceWorkerErrorMessage({required String errorMessage, required RegistrationID registrationId, required String versionId, required String sourceURL, required int lineNumber, required int columnNumber})
ServiceWorkerErrorMessage.fromJson(Map<String, dynamic> json)
factory

Properties

columnNumber → int
final
errorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
final
registrationId → RegistrationID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceURL → String
final
versionId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited