ConnectRequestedEvent class

Constructors

ConnectRequestedEvent({required String requestId, required int contextId, required String reader, required ShareMode shareMode, required ProtocolSet preferredProtocols})
ConnectRequestedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

contextId int
final
hashCode int
The hash code for this object.
no setterinherited
preferredProtocols ProtocolSet
final
reader String
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareMode ShareMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited