EndTransactionRequestedEvent class

Constructors

EndTransactionRequestedEvent({required String requestId, required int handle, required Disposition disposition})
EndTransactionRequestedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

disposition Disposition
final
handle int
final
hashCode int
The hash code for this object.
no setterinherited
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited