ProtocolSet class

Maps to the |SCARD_PROTOCOL_*| flags.

Constructors

ProtocolSet({bool? t0, bool? t1, bool? raw})
ProtocolSet.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
raw bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
t0 bool?
final
t1 bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited