ReaderStateFlags class

Maps to the |SCARD_STATE_*| flags.

Constructors

ReaderStateFlags({bool? unaware, bool? ignore, bool? changed, bool? unknown, bool? unavailable, bool? empty, bool? present, bool? exclusive, bool? inuse, bool? mute, bool? unpowered})
ReaderStateFlags.fromJson(Map<String, dynamic> json)
factory

Properties

changed → bool?
final
empty → bool?
final
exclusive → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
ignore → bool?
final
inuse → bool?
final
mute → bool?
final
present → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unavailable → bool?
final
unaware → bool?
final
unknown → bool?
final
unpowered → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited