ReaderStateIn class

Constructors

ReaderStateIn({required String reader, required ReaderStateFlags currentState, required int currentInsertionCount})
ReaderStateIn.fromJson(Map<String, dynamic> json)
factory

Properties

currentInsertionCount → int
final
currentState → ReaderStateFlags
final
hashCode → int
The hash code for this object.
no setterinherited
reader → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited