SmartCardEmulationApi class

Constructors

SmartCardEmulationApi(Client _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
onBeginTransactionRequested Stream<BeginTransactionRequestedEvent>
Fired when |SCardBeginTransaction| is called.
no setter
onCancelRequested Stream<CancelRequestedEvent>
Fired when |SCardCancel| is called.
no setter
onConnectRequested Stream<ConnectRequestedEvent>
Fired when |SCardConnect| is called.
no setter
onControlRequested Stream<ControlRequestedEvent>
Fired when |SCardControl| is called.
no setter
onDisconnectRequested Stream<DisconnectRequestedEvent>
Fired when |SCardDisconnect| is called.
no setter
onEndTransactionRequested Stream<EndTransactionRequestedEvent>
Fired when |SCardEndTransaction| is called.
no setter
onEstablishContextRequested Stream<String>
Fired when |SCardEstablishContext| is called.
no setter
onGetAttribRequested Stream<GetAttribRequestedEvent>
Fired when |SCardGetAttrib| is called.
no setter
onGetStatusChangeRequested Stream<GetStatusChangeRequestedEvent>
Fired when |SCardGetStatusChange| is called. Timeout is specified in milliseconds.
no setter
onListReadersRequested Stream<ListReadersRequestedEvent>
Fired when |SCardListReaders| is called.
no setter
onReleaseContextRequested Stream<ReleaseContextRequestedEvent>
Fired when |SCardReleaseContext| is called.
no setter
onSetAttribRequested Stream<SetAttribRequestedEvent>
Fired when |SCardSetAttrib| is called.
no setter
onStatusRequested Stream<StatusRequestedEvent>
Fired when |SCardStatus| is called.
no setter
onTransmitRequested Stream<TransmitRequestedEvent>
Fired when |SCardTransmit| is called.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable() Future<void>
Disables the |SmartCardEmulation| domain.
enable() Future<void>
Enables the |SmartCardEmulation| domain.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportBeginTransactionResult(String requestId, int handle) Future<void>
Reports the result of a |SCardBeginTransaction| call. On success, this creates a new transaction object.
reportConnectResult(String requestId, int handle, {Protocol? activeProtocol}) Future<void>
Reports the successful result of a |SCardConnect| call.
reportDataResult(String requestId, String data) Future<void>
Reports the successful result of a call that sends back data on success. Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|.
reportError(String requestId, ResultCode resultCode) Future<void>
Reports an error result for the given request.
reportEstablishContextResult(String requestId, int contextId) Future<void>
Reports the successful result of a |SCardEstablishContext| call.
reportGetStatusChangeResult(String requestId, List<ReaderStateOut> readerStates) Future<void>
Reports the successful result of a |SCardGetStatusChange| call.
reportListReadersResult(String requestId, List<String> readers) Future<void>
Reports the successful result of a |SCardListReaders| call.
reportPlainResult(String requestId) Future<void>
Reports the successful result of a call that returns only a result code. Used for: |SCardCancel|, |SCardDisconnect|, |SCardSetAttrib|, |SCardEndTransaction|.
reportReleaseContextResult(String requestId) Future<void>
Reports the successful result of a |SCardReleaseContext| call.
reportStatusResult(String requestId, String readerName, ConnectionState state, String atr, {Protocol? protocol}) Future<void>
Reports the successful result of a |SCardStatus| call.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited