protocol/storage library

Classes

CacheStorageContentUpdatedEvent
CacheStorageListUpdatedEvent
GetUsageAndQuotaResult
IndexedDBContentUpdatedEvent
IndexedDBListUpdatedEvent
RelatedWebsiteSet
A single Related Website Set object.
SharedStorageAccessedEvent
SharedStorageAccessParams
Bundles the parameters for shared storage access events whose presence/absence can vary according to SharedStorageAccessType.
SharedStorageEntry
Struct for a single key-value pair in an origin's shared storage.
SharedStorageMetadata
Details for an origin's shared storage.
SharedStoragePrivateAggregationConfig
Represents a dictionary object passed in as privateAggregationConfig to run or selectURL.
SharedStorageReportingMetadata
Pair of reporting metadata details for a candidate URL for selectURL().
SharedStorageUrlWithMetadata
Bundles a candidate URL with its reporting metadata.
SharedStorageWorkletOperationExecutionFinishedEvent
StorageApi
StorageBucket
StorageBucketInfo
TrustTokens
Pair of issuer origin and number of available (signed, but not used) Trust Tokens from that issuer.
UsageForType
Usage for a storage type.

Enums

SharedStorageAccessMethod
Enum of shared storage access methods.
SharedStorageAccessScope
Enum of shared storage access scopes.
StorageBucketsDurability
StorageType
Enum of possible storage types.

Extension Types

SerializedStorageKey