InterestGroupAccessedEvent class

Constructors

InterestGroupAccessedEvent({required TimeSinceEpoch accessTime, required InterestGroupAccessType type, required String ownerOrigin, required String name, String? componentSellerOrigin, num? bid, String? bidCurrency, InterestGroupAuctionId? uniqueAuctionId})
InterestGroupAccessedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

accessTime → TimeSinceEpoch
final
bid → num?
For bid or somethingBid event, if done locally and not on a server.
final
bidCurrency → String?
final
componentSellerOrigin → String?
For topLevelBid/topLevelAdditionalBid, and when appropriate, win and additionalBidWin
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
ownerOrigin → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InterestGroupAccessType
final
uniqueAuctionId → InterestGroupAuctionId?
For non-global events --- links to interestGroupAuctionEvent
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited