InterestGroupAuctionFetchType enum

Enum of network fetches auctions can do.

Inheritance
Available extensions

Values

bidderJs → const InterestGroupAuctionFetchType
const InterestGroupAuctionFetchType('bidderJs')
bidderWasm → const InterestGroupAuctionFetchType
const InterestGroupAuctionFetchType('bidderWasm')
sellerJs → const InterestGroupAuctionFetchType
const InterestGroupAuctionFetchType('sellerJs')
bidderTrustedSignals → const InterestGroupAuctionFetchType
const InterestGroupAuctionFetchType('bidderTrustedSignals')
sellerTrustedSignals → const InterestGroupAuctionFetchType
const InterestGroupAuctionFetchType('sellerTrustedSignals')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<InterestGroupAuctionFetchType>
A constant List of the values in this enum, in order of their declaration.