SharedStorageAccessType enum
Enum of shared storage access types.
Values
- documentAddModule → const SharedStorageAccessType
-
const SharedStorageAccessType('documentAddModule') - documentSelectUrl → const SharedStorageAccessType
-
const SharedStorageAccessType('documentSelectURL') - documentRun → const SharedStorageAccessType
-
const SharedStorageAccessType('documentRun') - documentSet → const SharedStorageAccessType
-
const SharedStorageAccessType('documentSet') - documentAppend → const SharedStorageAccessType
-
const SharedStorageAccessType('documentAppend') - documentDelete → const SharedStorageAccessType
-
const SharedStorageAccessType('documentDelete') - documentClear → const SharedStorageAccessType
-
const SharedStorageAccessType('documentClear') - workletSet → const SharedStorageAccessType
-
const SharedStorageAccessType('workletSet') - workletAppend → const SharedStorageAccessType
-
const SharedStorageAccessType('workletAppend') - workletDelete → const SharedStorageAccessType
-
const SharedStorageAccessType('workletDelete') - workletClear → const SharedStorageAccessType
-
const SharedStorageAccessType('workletClear') - workletGet → const SharedStorageAccessType
-
const SharedStorageAccessType('workletGet') - workletKeys → const SharedStorageAccessType
-
const SharedStorageAccessType('workletKeys') - workletEntries → const SharedStorageAccessType
-
const SharedStorageAccessType('workletEntries') - workletLength → const SharedStorageAccessType
-
const SharedStorageAccessType('workletLength') - workletRemainingBudget → const SharedStorageAccessType
-
const SharedStorageAccessType('workletRemainingBudget')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SharedStorageAccessType> - A constant List of the values in this enum, in order of their declaration.