SharedStorageAccessedEvent class

Constructors

SharedStorageAccessedEvent({required TimeSinceEpoch accessTime, required SharedStorageAccessScope scope, required SharedStorageAccessMethod method, required FrameId mainFrameId, required String ownerOrigin, required String ownerSite, required SharedStorageAccessParams params})
SharedStorageAccessedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

accessTime → TimeSinceEpoch
Time of the access.
final
hashCode → int
The hash code for this object.
no setterinherited
mainFrameId → FrameId
DevTools Frame Token for the primary frame tree's root.
final
method → SharedStorageAccessMethod
Enum value indicating the Shared Storage API method invoked.
final
ownerOrigin → String
Serialization of the origin owning the Shared Storage data.
final
ownerSite → String
Serialization of the site owning the Shared Storage data.
final
params → SharedStorageAccessParams
The sub-parameters wrapped by params are all optional and their presence/absence depends on type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → SharedStorageAccessScope
Enum value indicating the access scope.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited