SharedStorageMetadata class

Details for an origin's shared storage.

Constructors

SharedStorageMetadata({required TimeSinceEpoch creationTime, required int length, required num remainingBudget, required int bytesUsed})
SharedStorageMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

bytesUsed → int
Total number of bytes stored as key-value pairs in origin's shared storage.
final
creationTime → TimeSinceEpoch
Time when the origin's shared storage was last created.
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
Number of key-value pairs stored in origin's shared storage.
final
remainingBudget → num
Current amount of bits of entropy remaining in the navigation budget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited