SharedStoragePrivateAggregationConfig class

Represents a dictionary object passed in as privateAggregationConfig to run or selectURL.

Constructors

SharedStoragePrivateAggregationConfig({String? aggregationCoordinatorOrigin, String? contextId, required int filteringIdMaxBytes, int? maxContributions})
SharedStoragePrivateAggregationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

aggregationCoordinatorOrigin → String?
The chosen aggregation service deployment.
final
contextId → String?
The context ID provided.
final
filteringIdMaxBytes → int
Configures the maximum size allowed for filtering IDs.
final
hashCode → int
The hash code for this object.
no setterinherited
maxContributions → int?
The limit on the number of contributions in the final report.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited