SharedStorageWorkletOperationExecutionFinishedEvent class

Constructors

SharedStorageWorkletOperationExecutionFinishedEvent({required TimeSinceEpoch finishedTime, required int executionTime, required SharedStorageAccessMethod method, required String operationId, required TargetID workletTargetId, required FrameId mainFrameId, required String ownerOrigin})
SharedStorageWorkletOperationExecutionFinishedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

executionTime → int
Time, in microseconds, from start of shared storage JS API call until end of operation execution in the worklet.
final
finishedTime → TimeSinceEpoch
Time that the operation finished.
final
hashCode → int
The hash code for this object.
no setterinherited
mainFrameId → FrameId
DevTools Frame Token for the primary frame tree's root.
final
method → SharedStorageAccessMethod
Enum value indicating the Shared Storage API method invoked.
final
operationId → String
ID of the operation call.
final
ownerOrigin → String
Serialization of the origin owning the Shared Storage data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workletTargetId → TargetID
Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited