StorageBucketInfo class

Constructors

StorageBucketInfo({required StorageBucket bucket, required String id, required TimeSinceEpoch expiration, required num quota, required bool persistent, required StorageBucketsDurability durability})
StorageBucketInfo.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → StorageBucket
final
durability → StorageBucketsDurability
final
expiration → TimeSinceEpoch
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
persistent → bool
final
quota → num
Storage quota (bytes).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited