TrustTokens class

Pair of issuer origin and number of available (signed, but not used) Trust Tokens from that issuer.

Constructors

TrustTokens({required String issuerOrigin, required num count})
TrustTokens.fromJson(Map<String, dynamic> json)
factory

Properties

count → num
final
hashCode → int
The hash code for this object.
no setterinherited
issuerOrigin → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited