protocol/system_info
library
Classes
-
GetInfoResult
-
-
GPUDevice
-
Describes a single graphics processor (GPU).
-
GPUInfo
-
Provides information about the GPU(s) on the system.
-
ProcessInfo
-
Represents process info.
-
Size
-
Describes the width and height dimensions of an entity.
-
SystemInfoApi
-
The SystemInfo domain defines methods and events for querying low-level system information.
-
VideoDecodeAcceleratorCapability
-
Describes a supported video decoding profile with its associated minimum and
maximum resolutions.
-
VideoEncodeAcceleratorCapability
-
Describes a supported video encoding profile with its associated maximum
resolution and maximum framerate.