GPUDevice class

Describes a single graphics processor (GPU).

Constructors

GPUDevice({required num vendorId, required num deviceId, num? subSysId, num? revision, required String vendorString, required String deviceString, required String driverVendor, required String driverVersion})
GPUDevice.fromJson(Map<String, dynamic> json)
factory

Properties

deviceId → num
PCI ID of the GPU device, if available; 0 otherwise.
final
deviceString → String
String description of the GPU device, if the PCI ID is not available.
final
driverVendor → String
String description of the GPU driver vendor.
final
driverVersion → String
String description of the GPU driver version.
final
hashCode → int
The hash code for this object.
no setterinherited
revision → num?
Revision of the GPU, only available on Windows.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subSysId → num?
Sub sys ID of the GPU, only available on Windows.
final
vendorId → num
PCI ID of the GPU vendor, if available; 0 otherwise.
final
vendorString → String
String description of the GPU vendor, if the PCI ID is not available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited