GPUInfo class

Provides information about the GPU(s) on the system.

Constructors

GPUInfo({required List<GPUDevice> devices, Map<String, dynamic>? auxAttributes, Map<String, dynamic>? featureStatus, required List<String> driverBugWorkarounds, required List<VideoDecodeAcceleratorCapability> videoDecoding, required List<VideoEncodeAcceleratorCapability> videoEncoding})
GPUInfo.fromJson(Map<String, dynamic> json)
factory

Properties

auxAttributes → Map<String, dynamic>?
An optional dictionary of additional GPU related attributes.
final
devices → List<GPUDevice>
The graphics devices on the system. Element 0 is the primary GPU.
final
driverBugWorkarounds → List<String>
An optional array of GPU driver bug workarounds.
final
featureStatus → Map<String, dynamic>?
An optional dictionary of graphics features and their status.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoDecoding → List<VideoDecodeAcceleratorCapability>
Supported accelerated video decoding capabilities.
final
videoEncoding → List<VideoEncodeAcceleratorCapability>
Supported accelerated video encoding capabilities.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited