ProcessInfo class

Represents process info.

Constructors

ProcessInfo({required String type, required int id, required num cpuTime})
ProcessInfo.fromJson(Map<String, dynamic> json)
factory

Properties

cpuTime → num
Specifies cumulative CPU usage in seconds across all threads of the process since the process start.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Specifies process id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Specifies process type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited