VideoDecodeAcceleratorCapability class

Describes a supported video decoding profile with its associated minimum and maximum resolutions.

Constructors

VideoDecodeAcceleratorCapability({required String profile, required Size maxResolution, required Size minResolution})
VideoDecodeAcceleratorCapability.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxResolution → Size
Maximum video dimensions in pixels supported for this |profile|.
final
minResolution → Size
Minimum video dimensions in pixels supported for this |profile|.
final
profile → String
Video codec profile that is supported, e.g. VP9 Profile 2.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited