VideoEncodeAcceleratorCapability class

Describes a supported video encoding profile with its associated maximum resolution and maximum framerate.

Constructors

VideoEncodeAcceleratorCapability({required String profile, required Size maxResolution, required int maxFramerateNumerator, required int maxFramerateDenominator})
VideoEncodeAcceleratorCapability.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxFramerateDenominator → int
final
maxFramerateNumerator → int
Maximum encoding framerate in frames per second supported for this |profile|, as fraction's numerator and denominator, e.g. 24/1 fps, 24000/1001 fps, etc.
final
maxResolution → Size
Maximum video dimensions in pixels supported for this |profile|.
final
profile → String
Video codec profile that is supported, e.g H264 Main.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited