FilterEntry class

A filter used by target query/discovery/auto-attach operations.

Constructors

FilterEntry({bool? exclude, String? type})
FilterEntry.fromJson(Map<String, dynamic> json)
factory

Properties

exclude → bool?
If set, causes exclusion of matching targets from the list.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
If not present, matches any type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited