GetBrowserContextsResult class
Constructors
-
GetBrowserContextsResult({required List<
BrowserContextID> browserContextIds, BrowserContextID? defaultBrowserContextId}) -
GetBrowserContextsResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
browserContextIds
→ List<
BrowserContextID> -
An array of browser context ids.
final
- defaultBrowserContextId → BrowserContextID?
-
The id of the default browser context if available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited