TargetInfo class

Constructors

TargetInfo({required TargetID targetId, required String type, required String title, required String url, required bool attached, TargetID? parentId, TargetID? openerId, required bool canAccessOpener, FrameId? openerFrameId, FrameId? parentFrameId, BrowserContextID? browserContextId, String? subtype, Map<String, dynamic>? embedderData})
TargetInfo.fromJson(Map<String, dynamic> json)
factory

Properties

attached → bool
Whether the target has an attached client.
final
browserContextId → BrowserContextID?
final
canAccessOpener → bool
Whether the target has access to the originating window.
final
embedderData → Map<String, dynamic>?
Embedder-specific target metadata. This is only set for targets of type "tab".
final
hashCode → int
The hash code for this object.
no setterinherited
openerFrameId → FrameId?
Frame id of originating window (is only set if target has an opener).
final
openerId → TargetID?
Opener target Id
final
parentFrameId → FrameId?
Id of the parent frame, present for "iframe" and "worker" targets. For nested workers, this is the "ancestor" frame that created the first worker in the nested chain.
final
parentId → TargetID?
Id of the parent target, if any. For example, "iframe" target may have a "page" parent.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → String?
Provides additional details for specific target types. For example, for the type of "page", this may be set to "prerender".
final
targetId → TargetID
final
title → String
final
type → String
List of types: https://source.chromium.org/chromium/chromium/src/+/main:content/browser/devtools/devtools_agent_host_impl.cc?ss=chromium&q=f:devtools%20-f:out%20%22::kTypeTab%5B%5D%22
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited