AcceptedEvent class

Constructors

AcceptedEvent({required int port, required String connectionId})
AcceptedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

connectionId → String
Connection id to be used.
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
Port number that was successfully bound.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited