BufferUsageEvent class

Constructors

BufferUsageEvent({num? percentFull, num? eventCount, num? value})
BufferUsageEvent.fromJson(Map<String, dynamic> json)
factory

Properties

eventCount → num?
An approximate number of events in the trace log.
final
hashCode → int
The hash code for this object.
no setterinherited
percentFull → num?
A number in range 0..1 that indicates the used size of event buffer as a fraction of its total size.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → num?
A number in range 0..1 that indicates the used size of event buffer as a fraction of its total size.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited