TracingApi class

Constructors

TracingApi(Client _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
onBufferUsage Stream<BufferUsageEvent>
no setter
onDataCollected Stream<List<Map<String, dynamic>>>
Contains a bucket of collected trace events. When tracing is stopped collected events will be sent as a sequence of dataCollected events followed by tracingComplete event.
no setter
onTracingComplete Stream<TracingCompleteEvent>
Signals that tracing is stopped and there is no trace buffers pending flush, all data were delivered via dataCollected events.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

end() Future<void>
Stop trace events collection.
getCategories() Future<List<String>>
Gets supported tracing categories. Returns: A list of supported tracing categories.
getTrackEventDescriptor() Future<String>
Return a descriptor for all available tracing categories. Returns: Base64-encoded serialized perfetto.protos.TrackEventDescriptor protobuf message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordClockSyncMarker(String syncId) Future<void>
Record a clock sync marker in the trace. syncId The ID of this clock sync marker
requestMemoryDump({bool? deterministic, MemoryDumpLevelOfDetail? levelOfDetail}) Future<RequestMemoryDumpResult>
Request a global memory dump. deterministic Enables more deterministic results by forcing garbage collection levelOfDetail Specifies level of details in memory dump. Defaults to "detailed".
start({String? categories, String? options, num? bufferUsageReportingInterval, String? transferMode, StreamFormat? streamFormat, StreamCompression? streamCompression, TraceConfig? traceConfig, String? perfettoConfig, TracingBackend? tracingBackend, int? screenshotMaxSize, int? screenshotMaxCount}) Future<void>
Start trace events collection. bufferUsageReportingInterval If set, the agent will issue bufferUsage events at this interval, specified in milliseconds transferMode Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ReportEvents). streamFormat Trace data format to use. This only applies when using ReturnAsStream transfer mode (defaults to json). streamCompression Compression format to use. This only applies when using ReturnAsStream transfer mode (defaults to none) perfettoConfig Base64-encoded serialized perfetto.protos.TraceConfig protobuf message When specified, the parameters categories, options, traceConfig are ignored. tracingBackend Backend type (defaults to auto) screenshotMaxSize Maximum width and height (in pixels) of each captured screenshot. Only used when the disabled-by-default-devtools.screenshot category is enabled. Defaults to 500. The combined memory footprint of screenshots (screenshotMaxSize * screenshotMaxSize * 4 * screenshotMaxCount) is clamped to the existing per-session budget. screenshotMaxCount Maximum number of screenshots captured during a single tracing session. Only used when the disabled-by-default-devtools.screenshot category is enabled. Defaults to 450. Clamped together with screenshotMaxSize to stay within the per-session screenshot memory budget.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited