TracingCompleteEvent class

Constructors

TracingCompleteEvent({required bool dataLossOccurred, StreamHandle? stream, StreamFormat? traceFormat, StreamCompression? streamCompression})
TracingCompleteEvent.fromJson(Map<String, dynamic> json)
factory

Properties

dataLossOccurred → bool
Indicates whether some trace data is known to have been lost, e.g. because the trace ring buffer wrapped around.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → StreamHandle?
A handle of the stream that holds resulting trace data.
final
streamCompression → StreamCompression?
Compression format of returned stream.
final
traceFormat → StreamFormat?
Trace data format of returned stream.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited