AudioNode class

Protocol object for AudioNode

Constructors

AudioNode({required GraphObjectId nodeId, required GraphObjectId contextId, required NodeType nodeType, required num numberOfInputs, required num numberOfOutputs, required num channelCount, required ChannelCountMode channelCountMode, required ChannelInterpretation channelInterpretation})
AudioNode.fromJson(Map<String, dynamic> json)
factory

Properties

channelCount → num
final
channelCountMode → ChannelCountMode
final
channelInterpretation → ChannelInterpretation
final
contextId → GraphObjectId
final
hashCode → int
The hash code for this object.
no setterinherited
nodeId → GraphObjectId
final
nodeType → NodeType
final
numberOfInputs → num
final
numberOfOutputs → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited