AudioParam class

Protocol object for AudioParam

Constructors

AudioParam({required GraphObjectId paramId, required GraphObjectId nodeId, required GraphObjectId contextId, required ParamType paramType, required AutomationRate rate, required num defaultValue, required num minValue, required num maxValue})
AudioParam.fromJson(Map<String, dynamic> json)
factory

Properties

contextId → GraphObjectId
final
defaultValue → num
final
hashCode → int
The hash code for this object.
no setterinherited
maxValue → num
final
minValue → num
final
nodeId → GraphObjectId
final
paramId → GraphObjectId
final
paramType → ParamType
final
rate → AutomationRate
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited