BaseAudioContext class

Protocol object for BaseAudioContext

Constructors

BaseAudioContext({required GraphObjectId contextId, required ContextType contextType, required ContextState contextState, ContextRealtimeData? realtimeData, required num callbackBufferSize, required num maxOutputChannelCount, required num sampleRate})
BaseAudioContext.fromJson(Map<String, dynamic> json)
factory

Properties

callbackBufferSize → num
Platform-dependent callback buffer size.
final
contextId → GraphObjectId
final
contextState → ContextState
final
contextType → ContextType
final
hashCode → int
The hash code for this object.
no setterinherited
maxOutputChannelCount → num
Number of output channels supported by audio hardware in use.
final
realtimeData → ContextRealtimeData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → num
Context sample rate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited