NodesDisconnectedEvent class

Constructors

NodesDisconnectedEvent({required GraphObjectId contextId, required GraphObjectId sourceId, required GraphObjectId destinationId, num? sourceOutputIndex, num? destinationInputIndex})
NodesDisconnectedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

contextId → GraphObjectId
final
destinationId → GraphObjectId
final
destinationInputIndex → num?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → GraphObjectId
final
sourceOutputIndex → num?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited