Credential class

Constructors

Credential({required String credentialId, required bool isResidentCredential, String? rpId, required String privateKey, String? userHandle, int? signCount, String? largeBlob, bool? backupEligibility, bool? backupState, String? userName, String? userDisplayName, List<String>? cmtgKeys, int? activeCmtgKeyIndex, bool? generateCmtgKeyOnNextOperation})
Credential.fromJson(Map<String, dynamic> json)
factory

Properties

activeCmtgKeyIndex int?
The 0-based index of the active key in cmtgKeys.
final
backupEligibility bool?
Assertions returned by this credential will have the backup eligibility (BE) flag set to this value. Defaults to the authenticator's defaultBackupEligibility value.
final
backupState bool?
Assertions returned by this credential will have the backup state (BS) flag set to this value. Defaults to the authenticator's defaultBackupState value.
final
cmtgKeys List<String>?
The CMTG keys associated with the credential.
final
credentialId String
final
generateCmtgKeyOnNextOperation bool?
If true, the authenticator will generate a new CMTG key on the next operation.
final
hashCode int
The hash code for this object.
no setterinherited
isResidentCredential bool
final
largeBlob String?
The large blob associated with the credential. See https://w3c.github.io/webauthn/#sctn-large-blob-extension
final
privateKey String
The ECDSA P-256 private key in PKCS#8 format.
final
rpId String?
Relying Party ID the credential is scoped to. Must be set when adding a credential.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signCount int?
Signature counter. Must be equal to or greater than -1. If -1, the credential won't have an associated signature counter, and every assertion operation will report a value of 0. See https://w3c.github.io/webauthn/#signature-counter
final
userDisplayName String?
The credential's user.displayName property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialuserentity-displayname
final
userHandle String?
An opaque byte sequence with a maximum size of 64 bytes mapping the credential to a specific user.
final
userName String?
The credential's user.name property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialentity-name
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited