generateCmtgKeyOnNextOperation property
If true, the authenticator will generate a new CMTG key on the next operation.
Implementation
final bool? generateCmtgKeyOnNextOperation;
If true, the authenticator will generate a new CMTG key on the next operation.
final bool? generateCmtgKeyOnNextOperation;