VirtualAuthenticatorOptions class

Constructors

VirtualAuthenticatorOptions({required AuthenticatorProtocol protocol, Ctap2Version? ctap2Version, required AuthenticatorTransport transport, bool? hasResidentKey, bool? hasUserVerification, bool? hasLargeBlob, bool? hasCredBlob, bool? hasMinPinLength, bool? hasPrf, bool? hasHmacSecret, bool? hasHmacSecretMc, bool? automaticPresenceSimulation, bool? isUserVerified, bool? defaultBackupEligibility, bool? defaultBackupState})
VirtualAuthenticatorOptions.fromJson(Map<String, dynamic> json)
factory

Properties

automaticPresenceSimulation → bool?
If set to true, tests of user presence will succeed immediately. Otherwise, they will not be resolved. Defaults to true.
final
ctap2Version → Ctap2Version?
Defaults to ctap2_0. Ignored if |protocol| == u2f.
final
defaultBackupEligibility → bool?
Credentials created by this authenticator will have the backup eligibility (BE) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
final
defaultBackupState → bool?
Credentials created by this authenticator will have the backup state (BS) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
final
hasCredBlob → bool?
If set to true, the authenticator will support the credBlob extension. https://fidoalliance.org/specs/fido-v2.1-rd-20201208/fido-client-to-authenticator-protocol-v2.1-rd-20201208.html#sctn-credBlob-extension Defaults to false.
final
hashCode → int
The hash code for this object.
no setterinherited
hasHmacSecret → bool?
If set to true, the authenticator will support the hmac-secret extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-hmac-secret-extension Defaults to false.
final
hasHmacSecretMc → bool?
If set to true, the authenticator will support the hmac-secret-mc extension. https://fidoalliance.org/specs/fido-v2.2-rd-20241003/fido-client-to-authenticator-protocol-v2.2-rd-20241003.html#sctn-hmac-secret-make-cred-extension Defaults to false.
final
hasLargeBlob → bool?
If set to true, the authenticator will support the largeBlob extension. https://w3c.github.io/webauthn#largeBlob Defaults to false.
final
hasMinPinLength → bool?
If set to true, the authenticator will support the minPinLength extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-minpinlength-extension Defaults to false.
final
hasPrf → bool?
If set to true, the authenticator will support the prf extension. https://w3c.github.io/webauthn/#prf-extension Defaults to false.
final
hasResidentKey → bool?
Defaults to false.
final
hasUserVerification → bool?
Defaults to false.
final
isUserVerified → bool?
Sets whether User Verification succeeds or fails for an authenticator. Defaults to false.
final
protocol → AuthenticatorProtocol
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transport → AuthenticatorTransport
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited