Annotation class

Tool annotations

Constructors

Annotation({bool? readOnly, bool? autosubmit})
Annotation.fromJson(Map<String, dynamic> json)
factory

Properties

autosubmit bool?
If the declarative tool was declared with the autosubmit attribute.
final
hashCode int
The hash code for this object.
no setterinherited
readOnly bool?
A hint indicating that the tool does not modify any state.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited