untrustedContent property
A hint indicating that the tool output may contain untrusted content, ex: UGC, 3rd party data.
Implementation
final bool? untrustedContent;
A hint indicating that the tool output may contain untrusted content, ex: UGC, 3rd party data.
final bool? untrustedContent;