ToolInvokedEvent class

Constructors

ToolInvokedEvent({required String toolName, required FrameId frameId, required String invocationId, required String input})
ToolInvokedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

frameId → FrameId
Frame id
final
hashCode → int
The hash code for this object.
no setterinherited
input → String
The input parameters used for the invocation.
final
invocationId → String
Invocation identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolName → String
Name of the tool to invoke.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited