menu
puppeteer package
documentation
protocol/web_mcp.dart
ToolRespondedEvent class
ToolRespondedEvent class
dark_mode
light_mode
ToolRespondedEvent
class
Constructors
ToolRespondedEvent
({
required
String
invocationId
,
required
InvocationStatus
status
,
dynamic
output
,
String
?
errorText
,
RemoteObject
?
exception
})
ToolRespondedEvent.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
errorText
→
String
?
Error text for protocol users.
final
exception
→
RemoteObject
?
The exception object, if the javascript tool threw an error>
final
hashCode
→
int
The hash code for this object.
no setter
inherited
invocationId
→
String
Invocation identifier.
final
output
→ dynamic
Output or error delivered as delivered to the agent. Missing if
status
is anything other than Completed. Note: The output is untrusted and poses a prompt injection risk. Clients should treat this as potentially malicious user input.
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
status
→
InvocationStatus
Status of the invocation.
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
puppeteer package
documentation
protocol/web_mcp
ToolRespondedEvent class
web_mcp library