click method
This method fetches an element with selector, scrolls it into view if
needed, and then uses Page.mouse to click in the center of the element.
If there's no element matching selector, the method throws an error.
Bear in mind that if click() triggers a navigation event and there's a
separate page.waitForNavigation() promise to be resolved, you may end
up with a race condition that yields unexpected results. The correct
pattern for click and wait for navigation is the following:
var responseFuture = page.waitForNavigation();
await frame.click('a');
var response = await responseFuture;
Parameters:
selector: Aselectorto search for element to click. If there are multiple elements satisfying the selector, the first will be clicked.button: <"left"|"right"|"middle"> Defaults toleftclickCount: defaults to 1delay: Time to wait betweenmousedownandmouseup. Default to zero.
Implementation
Future<void> click(
String selector, {
Duration? delay,
MouseButton? button,
int? clickCount,
}) {
return _secondaryWorld.click(
selector,
delay: delay,
button: button,
clickCount: clickCount,
);
}