focus method
This method fetches an element with selector and focuses it.
If there's no element matching selector, the method throws an error.
Parameters:
- A
selectorof an element to focus. If there are multiple elements satisfying the selector, the first will be focused. - Promise which resolves when the element matching
selectoris successfully focused. The promise will be rejected if there is no element matchingselector.
Implementation
Future<void> focus(String selector) {
return _secondaryWorld.focus(selector);
}