hover method
This method fetches an element with selector, scrolls it into view if
needed, and then uses Page.mouse to hover over the center of
the element.
If there's no element matching selector, the method throws an error.
Parameters:
A selector to search for element to hover. If there are multiple elements
satisfying the selector, the first will be hovered.
Returns: Future which resolves when the element matching selector is
successfully hovered. Future gets rejected if there's no element matching
selector.
Implementation
Future<void> hover(String selector) {
return _secondaryWorld.hover(selector);
}