isDetached property
bool
get
isDetached
Returns true if the frame has been detached, or false otherwise.
Implementation
bool get isDetached => _detached;
Returns true if the frame has been detached, or false otherwise.
bool get isDetached => _detached;