tap method
This method fetches an element with selector, scrolls it into view if
needed, and then uses page.touchscreen to tap in the center of the element.
If there's no element matching selector, the method throws an error.
Parameters:
A selector to search for element to tap. If there are multiple
elements satisfying the selector, the first will be tapped.
Implementation
Future<void> tap(String selector) {
return _secondaryWorld.tap(selector);
}