json property
Future
get
json
This method will throw if the response body is not parsable via jsonDecode.
Implementation
Future<dynamic> get json => text.then(jsonDecode);
This method will throw if the response body is not parsable via jsonDecode.
Future<dynamic> get json => text.then(jsonDecode);