AdFrameData class
Ad frame data.
Constructors
- AdFrameData({required FrameId frameId, String? initialOrigin, required num networkBytes, required num cpuTime})
-
AdFrameData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cpuTime → num
-
The CPU time of the frame, in milliseconds.
final
- frameId → FrameId
-
The DevTools frame token.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialOrigin → String?
-
The initial origin of the frame. To minimize the payload size, this is
only sent once per frame.
final
- networkBytes → num
-
The network bytes of the frame.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited