AdMetrics class
Ad metrics for a page.
Constructors
Properties
- averageViewportAdCount → num
-
The time-weighted average of the viewport ad count, measured across the
duration of the page.
final
- averageViewportAdDensityByArea → num
-
The time-weighted average of the viewport ad density by area, measured
across the duration of the page.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalAdCpuTime → num
-
The total ad CPU usage, in milliseconds.
final
- totalAdNetworkBytes → num
-
The total ad network bytes.
final
- viewportAdCount → int
-
The number of ads currently visible within the viewport.
final
- viewportAdDensityByArea → int
-
The viewport ad density by area, represented as a percentage (an integer
between 0 and 100).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited