AdAncestry class
Providence about how an ad script was determined to be such. It is an ad because its url matched a filterlist rule, or because some other ad script was on the stack when this script was loaded.
Constructors
-
AdAncestry({required List<
AdScriptIdentifier> adAncestryChain, String? rootScriptFilterlistRule}) -
AdAncestry.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
adAncestryChain
→ List<
AdScriptIdentifier> -
The ad-script in the stack when the offending script was loaded. This is
recursive down to the root script that was tagged due to the filterlist
rule.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rootScriptFilterlistRule → String?
-
The filterlist rule that caused the root (last) script in
adAncestryto be ad-tagged.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited