LazyLoadImageIssueDetails class
Details for issues about lazy-loaded images without explicit dimensions.
Constructors
- LazyLoadImageIssueDetails({required BackendNodeId nodeId, required String url, required FrameId frameId})
-
LazyLoadImageIssueDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- frameId → FrameId
-
Frame containing the image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeId → BackendNodeId
-
DOM node of the problematic HTMLImageElement.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
URL or src attribute of the image.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited