PerformanceIssueDetails class

Details for a performance issue.

Constructors

PerformanceIssueDetails({required PerformanceIssueType performanceIssueType, SourceCodeLocation? sourceCodeLocation})
PerformanceIssueDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
performanceIssueType PerformanceIssueType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceCodeLocation SourceCodeLocation?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited