AddressField class
Constructors
- AddressField({required String name, required String value})
-
AddressField.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
address field name, for example GIVEN_NAME.
The full list of supported field names:
https://source.chromium.org/chromium/chromium/src/+/main:components/autofill/core/browser/field_types.cc;l=38
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
address field value, for example Jon Doe.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited