CSSAtRule class

CSS generic @rule representation.

Constructors

CSSAtRule({required CSSAtRuleType type, CSSAtRuleSubsection? subsection, Value? name, StyleSheetId? styleSheetId, required StyleSheetOrigin origin, required CSSStyle style})
CSSAtRule.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → Value?
LINT.ThenChange(//third_party/blink/renderer/core/inspector/inspector_style_sheet.cc:FontVariantAlternatesFeatureType,//third_party/blink/renderer/core/inspector/inspector_css_agent.cc:FontVariantAlternatesFeatureType) Associated name, if applicable.
final
origin → StyleSheetOrigin
Parent stylesheet's origin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → CSSStyle
Associated style declaration.
final
styleSheetId → StyleSheetId?
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
final
subsection → CSSAtRuleSubsection?
Subsection of font-feature-values, if this is a subsection.
final
type → CSSAtRuleType
Type of at-rule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited