CSSNavigation class

CSS Navigation at-rule descriptor.

Constructors

CSSNavigation({required String text, bool? active, SourceRange? range, StyleSheetId? styleSheetId})
CSSNavigation.fromJson(Map<String, dynamic> json)
factory

Properties

active → bool?
Whether the navigation condition is satisfied.
final
hashCode → int
The hash code for this object.
no setterinherited
range → SourceRange?
The associated rule header range in the enclosing stylesheet (if available).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleSheetId → StyleSheetId?
Identifier of the stylesheet containing this object (if exists).
final
text → String
Navigation rule text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited