ComputedStyleExtraFields class
Constructors
- ComputedStyleExtraFields({required bool isAppearanceBase})
-
ComputedStyleExtraFields.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAppearanceBase → bool
-
Returns whether or not this node is being rendered with base appearance,
which happens when it has its appearance property set to base/base-select
or it is in the subtree of an element being rendered with base appearance.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited