isAppearanceBase property

bool isAppearanceBase
final

Returns whether or not this node is being rendered with base appearance, which happens when it has its appearance property set to base/base-select or it is in the subtree of an element being rendered with base appearance.

Implementation

final bool isAppearanceBase;