GetComputedStyleForNodeResult class
Properties
-
computedStyle
→ List<CSSComputedStyleProperty>
-
Computed style for the specified DOM node.
final
-
A list of non-standard "extra fields" which blink stores alongside each
computed style.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited