DigitalCredentialsApi class
This domain allows interacting with the Digital Credentials API for automation.
Constructors
- DigitalCredentialsApi(Client _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setVirtualWalletBehavior(
VirtualWalletAction action, {String? protocol, Map< String, dynamic> ? response, FrameId? frameId}) → Future<void> -
Sets the behavior of the virtual wallet for digital credential requests
issued from this frame.
actionThe action of the virtual wallet.protocolThe protocol identifier (e.g. "openid4vp"). Required when |action| is "respond", forbidden otherwise.responseThe response data object returned by the wallet. Required when |action| is "respond", forbidden otherwise.frameIdThe frame to scope the virtual wallet behavior to. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited