AdRelatedStateUpdatedEvent class

Constructors

AdRelatedStateUpdatedEvent({required NodeId nodeId, required bool isAdRelated})
AdRelatedStateUpdatedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isAdRelated bool
If the node is ad related.
final
nodeId NodeId
The id of the node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited