forceShowPopover method
Future<List<NodeId> >
forceShowPopover(
- NodeId nodeId,
- bool enable, {
- BackendNodeId? invokerNodeId,
When enabling, this API force-opens the popover identified by nodeId
and keeps it open until disabled.
nodeId Id of the popover HTMLElement
enable If true, opens the popover and keeps it open. If false, closes the
popover if it was previously force-opened.
invokerNodeId Optional ID of the element invoking this popover, used to establish the implicit anchor.
If not provided, it will fall back to the first invoker in the document, preferring
elements with a popovertarget attribute over those with a commandfor attribute. Note that
if there are multiple invokers, this is just an estimate.
Returns: List of popovers that were closed in order to respect popover stacking order.
Implementation
Future<List<NodeId>> forceShowPopover(
NodeId nodeId,
bool enable, {
BackendNodeId? invokerNodeId,
}) async {
var result = await _client.send('DOM.forceShowPopover', {
'nodeId': nodeId,
'enable': enable,
'invokerNodeId': ?invokerNodeId,
});
return (result['nodeIds'] as List)
.map((e) => NodeId.fromJson(e as int))
.toList();
}