ScreenInfo class
Screen information similar to the one returned by window.getScreenDetails() method, see https://w3c.github.io/window-management/#screendetailed.
Constructors
- ScreenInfo({required int left, required int top, required int width, required int height, required int availLeft, required int availTop, required int availWidth, required int availHeight, required num devicePixelRatio, required ScreenOrientation orientation, required int colorDepth, required bool isExtended, required bool isInternal, required bool isPrimary, required String label, required ScreenId id})
-
ScreenInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- availHeight → int
-
Height of the available screen area.
final
- availLeft → int
-
Offset of the left edge of the available screen area.
final
- availTop → int
-
Offset of the top edge of the available screen area.
final
- availWidth → int
-
Width of the available screen area.
final
- colorDepth → int
-
Specifies the screen's color depth in bits.
final
- devicePixelRatio → num
-
Specifies the screen's device pixel ratio.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Height of the screen.
final
- id → ScreenId
-
Specifies the unique identifier of the screen.
final
- isExtended → bool
-
Indicates whether the device has multiple screens.
final
- isInternal → bool
-
Indicates whether the screen is internal to the device or external, attached to the device.
final
- isPrimary → bool
-
Indicates whether the screen is set as the the operating system primary screen.
final
- label → String
-
Specifies the descriptive label for the screen.
final
- left → int
-
Offset of the left edge of the screen.
final
- orientation → ScreenOrientation
-
Specifies the screen's orientation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int
-
Offset of the top edge of the screen.
final
- width → int
-
Width of the screen.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited