WorkAreaInsets class
Constructors
- WorkAreaInsets({int? top, int? left, int? bottom, int? right})
-
WorkAreaInsets.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bottom → int?
-
Work area bottom inset in pixels. Default is 0;
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → int?
-
Work area left inset in pixels. Default is 0;
final
- right → int?
-
Work area right inset in pixels. Default is 0;
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int?
-
Work area top inset in pixels. Default is 0;
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited