ExtensionInfo class

Detailed information about an extension.

Constructors

ExtensionInfo({required String id, required String name, required String version, required String path, required bool enabled})
ExtensionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool
Extension enabled status.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Extension id.
final
name → String
Extension name.
final
path → String
The path from which the extension was loaded.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
Extension version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited