BlockPattern class

Constructors

BlockPattern({required String urlPattern, required bool block})
BlockPattern.fromJson(Map<String, dynamic> json)
factory

Properties

block → bool
Whether or not to block the pattern. If false, a matching request will not be blocked even if it matches a later BlockPattern.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlPattern → String
URL pattern to match. Patterns use the URLPattern constructor string syntax (https://urlpattern.spec.whatwg.org/) and must be absolute. Example: *://*:*/*.css.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited