DeviceBoundSession class

A device bound session.

Constructors

DeviceBoundSession({required DeviceBoundSessionKey key, required String refreshUrl, required DeviceBoundSessionInclusionRules inclusionRules, required List<DeviceBoundSessionCookieCraving> cookieCravings, required TimeSinceEpoch expiryDate, String? cachedChallenge, required List<String> allowedRefreshInitiators})
DeviceBoundSession.fromJson(Map<String, dynamic> json)
factory

Properties

allowedRefreshInitiators → List<String>
See comments on net::device_bound_sessions::Session::allowed_refresh_initiators_.
final
cachedChallenge → String?
See comments on net::device_bound_sessions::Session::cached_challenge__.
final
cookieCravings → List<DeviceBoundSessionCookieCraving>
See comments on net::device_bound_sessions::Session::cookie_cravings_.
final
expiryDate → TimeSinceEpoch
See comments on net::device_bound_sessions::Session::expiry_date_.
final
hashCode → int
The hash code for this object.
no setterinherited
inclusionRules → DeviceBoundSessionInclusionRules
See comments on net::device_bound_sessions::Session::inclusion_rules_.
final
key → DeviceBoundSessionKey
The site and session ID of the session.
final
refreshUrl → String
See comments on net::device_bound_sessions::Session::refresh_url_.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited