DeviceBoundSessionCookieCraving class

A device bound session's cookie craving.

Constructors

DeviceBoundSessionCookieCraving({required String name, required String domain, required String path, required bool secure, required bool httpOnly, CookieSameSite? sameSite})
DeviceBoundSessionCookieCraving.fromJson(Map<String, dynamic> json)
factory

Properties

domain → String
The domain of the craving.
final
hashCode → int
The hash code for this object.
no setterinherited
httpOnly → bool
The HttpOnly attribute of the craving attributes.
final
name → String
The name of the craving.
final
path → String
The path of the craving.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameSite → CookieSameSite?
The SameSite attribute of the craving attributes.
final
secure → bool
The Secure attribute of the craving attributes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited