DeviceBoundSessionFetchResult enum
A fetch result for a device bound session creation or refresh.
Values
- success → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('Success') - keyError → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('KeyError') - signingError → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('SigningError') - serverRequestedTermination → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('ServerRequestedTermination') - invalidSessionId → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidSessionId') - invalidChallenge → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidChallenge') - tooManyChallenges → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('TooManyChallenges') - invalidFetcherUrl → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidFetcherUrl') - invalidRefreshUrl → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidRefreshUrl') - transientHttpError → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('TransientHttpError') - scopeOriginSameSiteMismatch → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('ScopeOriginSameSiteMismatch') - refreshUrlSameSiteMismatch → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('RefreshUrlSameSiteMismatch') - mismatchedSessionId → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('MismatchedSessionId') - missingScope → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('MissingScope') - noCredentials → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('NoCredentials') -
const DeviceBoundSessionFetchResult('SubdomainRegistrationWellKnownUnavailable') -
const DeviceBoundSessionFetchResult('SubdomainRegistrationUnauthorized') - subdomainRegistrationWellKnownMalformed → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('SubdomainRegistrationWellKnownMalformed') -
const DeviceBoundSessionFetchResult('SessionProviderWellKnownUnavailable') -
const DeviceBoundSessionFetchResult('RelyingPartyWellKnownUnavailable') - federatedKeyThumbprintMismatch → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('FederatedKeyThumbprintMismatch') - invalidFederatedSessionUrl → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidFederatedSessionUrl') - invalidFederatedKey → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidFederatedKey') - tooManyRelyingOriginLabels → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('TooManyRelyingOriginLabels') - boundCookieSetForbidden → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('BoundCookieSetForbidden') - netError → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('NetError') - proxyError → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('ProxyError') - emptySessionConfig → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('EmptySessionConfig') - invalidCredentialsConfig → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsConfig') - invalidCredentialsType → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsType') - invalidCredentialsEmptyName → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsEmptyName') - invalidCredentialsCookie → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookie') - persistentHttpError → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('PersistentHttpError') - registrationAttemptedChallenge → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('RegistrationAttemptedChallenge') - invalidScopeOrigin → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidScopeOrigin') - scopeOriginContainsPath → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('ScopeOriginContainsPath') - refreshInitiatorNotString → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('RefreshInitiatorNotString') - refreshInitiatorInvalidHostPattern → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('RefreshInitiatorInvalidHostPattern') - invalidScopeSpecification → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidScopeSpecification') - missingScopeSpecificationType → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('MissingScopeSpecificationType') - emptyScopeSpecificationDomain → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('EmptyScopeSpecificationDomain') - emptyScopeSpecificationPath → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('EmptyScopeSpecificationPath') - invalidScopeSpecificationType → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidScopeSpecificationType') - invalidScopeIncludeSite → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidScopeIncludeSite') - missingScopeIncludeSite → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('MissingScopeIncludeSite') - federatedNotAuthorizedByProvider → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('FederatedNotAuthorizedByProvider') - federatedNotAuthorizedByRelyingParty → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('FederatedNotAuthorizedByRelyingParty') - sessionProviderWellKnownMalformed → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('SessionProviderWellKnownMalformed') - sessionProviderWellKnownHasProviderOrigin → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('SessionProviderWellKnownHasProviderOrigin') - relyingPartyWellKnownMalformed → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('RelyingPartyWellKnownMalformed') - relyingPartyWellKnownHasRelyingOrigins → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('RelyingPartyWellKnownHasRelyingOrigins') - invalidFederatedSessionProviderSessionMissing → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidFederatedSessionProviderSessionMissing') - invalidFederatedSessionWrongProviderOrigin → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidFederatedSessionWrongProviderOrigin') - invalidCredentialsCookieCreationTime → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookieCreationTime') - invalidCredentialsCookieName → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookieName') - invalidCredentialsCookieParsing → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookieParsing') - invalidCredentialsCookieUnpermittedAttribute → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookieUnpermittedAttribute') - invalidCredentialsCookieInvalidDomain → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookieInvalidDomain') - invalidCredentialsCookiePrefix → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidCredentialsCookiePrefix') - invalidScopeRulePath → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidScopeRulePath') - invalidScopeRuleHostPattern → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidScopeRuleHostPattern') - scopeRuleOriginScopedHostPatternMismatch → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('ScopeRuleOriginScopedHostPatternMismatch') - scopeRuleSiteScopedHostPatternMismatch → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('ScopeRuleSiteScopedHostPatternMismatch') - signingQuotaExceeded → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('SigningQuotaExceeded') - invalidConfigJson → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidConfigJson') - invalidFederatedSessionProviderFailedToRestoreKey → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('InvalidFederatedSessionProviderFailedToRestoreKey') - failedToUnwrapKey → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('FailedToUnwrapKey') - sessionDeletedDuringRefresh → const DeviceBoundSessionFetchResult
-
const DeviceBoundSessionFetchResult('SessionDeletedDuringRefresh')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DeviceBoundSessionFetchResult> - A constant List of the values in this enum, in order of their declaration.