DeviceBoundSessionInclusionRules class
A device bound session's inclusion rules.
Constructors
-
DeviceBoundSessionInclusionRules({required String origin, required bool includeSite, required List<
DeviceBoundSessionUrlRule> urlRules}) -
DeviceBoundSessionInclusionRules.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeSite → bool
-
Whether the whole site is included. See comments on
net::device_bound_sessions::SessionInclusionRules::include_site_for more details; this boolean is true if that value is populated.final - origin → String
-
See comments on
net::device_bound_sessions::SessionInclusionRules::origin_.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
urlRules
→ List<
DeviceBoundSessionUrlRule> -
See comments on
net::device_bound_sessions::SessionInclusionRules::url_rules_.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited