DeviceBoundSessionUrlRule class

A device bound session's inclusion URL rule.

Constructors

DeviceBoundSessionUrlRule({required DeviceBoundSessionUrlRuleRuleType ruleType, required String hostPattern, required String pathPrefix})
DeviceBoundSessionUrlRule.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hostPattern String
See comments on net::device_bound_sessions::SessionInclusionRules::UrlRule::host_pattern.
final
pathPrefix String
See comments on net::device_bound_sessions::SessionInclusionRules::UrlRule::path_prefix.
final
ruleType DeviceBoundSessionUrlRuleRuleType
See comments on net::device_bound_sessions::SessionInclusionRules::UrlRule::rule_type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited