RefreshEventDetails class
Session event details specific to refresh.
Constructors
- RefreshEventDetails({required RefreshEventDetailsRefreshResult refreshResult, DeviceBoundSessionFetchResult? fetchResult, DeviceBoundSession? newSession, required bool wasFullyProactiveRefresh})
-
RefreshEventDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- fetchResult → DeviceBoundSessionFetchResult?
-
If there was a fetch attempt, the result of that.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newSession → DeviceBoundSession?
-
The session display if there was a newly created session. This is populated
for any refresh event that modifies the session config.
final
- refreshResult → RefreshEventDetailsRefreshResult
-
The result of a refresh.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wasFullyProactiveRefresh → bool
-
See comments on
net::device_bound_sessions::RefreshEventResult::was_fully_proactive_refresh.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited