newSession property
The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
Implementation
final DeviceBoundSession? newSession;
The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
final DeviceBoundSession? newSession;