DisplayCutoutConfig class
Configuration for a display cutout.
Constructors
- DisplayCutoutConfig({required Rect rect, required DisplayCutoutShape shape, int? borderRadius, int? upperRadius, int? lowerRadius, int? cx, int? cy, int? radius, RGBA? contentColor})
-
DisplayCutoutConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- borderRadius → int?
-
Border radius for rounded cutout shapes.
final
- contentColor → RGBA?
-
The cutout fill color (default: black).
final
- cx → int?
-
Center x coordinate for circle cutout shapes.
final
- cy → int?
-
Center y coordinate for circle cutout shapes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowerRadius → int?
-
Lower transition radius for notch cutout shapes.
final
- radius → int?
-
Radius for circle cutout shapes.
final
- rect → Rect
-
A rectangle representing the cutout bounds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → DisplayCutoutShape
-
Shape used to draw the cutout.
final
- upperRadius → int?
-
Upper shoulder radius for notch cutout shapes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited