GetStatusChangeRequestedEvent class
Constructors
-
GetStatusChangeRequestedEvent({required String requestId, required int contextId, required List<
ReaderStateIn> readerStates, int? timeout}) -
GetStatusChangeRequestedEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contextId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
readerStates
→ List<
ReaderStateIn> -
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → int?
-
in milliseconds, if absent, it means "infinite"
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited