ReaderStateOut class
Constructors
- ReaderStateOut({required String reader, required ReaderStateFlags eventState, required int eventCount, required String atr})
-
ReaderStateOut.fromJson(Map<
String, dynamic> json) -
factory
Properties
- atr → String
-
final
- eventCount → int
-
final
- eventState → ReaderStateFlags
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reader → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited