ResultCode enum
Indicates the PC/SC error code.
This maps to: PC/SC Lite: https://pcsclite.apdu.fr/api/group__ErrorCodes.html Microsoft: https://learn.microsoft.com/en-us/windows/win32/secauthn/authentication-return-values
Values
- success → const ResultCode
-
const ResultCode('success') - removedCard → const ResultCode
-
const ResultCode('removed-card') - resetCard → const ResultCode
-
const ResultCode('reset-card') - unpoweredCard → const ResultCode
-
const ResultCode('unpowered-card') - unresponsiveCard → const ResultCode
-
const ResultCode('unresponsive-card') - unsupportedCard → const ResultCode
-
const ResultCode('unsupported-card') -
const ResultCode('reader-unavailable') -
const ResultCode('sharing-violation') - notTransacted → const ResultCode
-
const ResultCode('not-transacted') - noSmartcard → const ResultCode
-
const ResultCode('no-smartcard') - protoMismatch → const ResultCode
-
const ResultCode('proto-mismatch') - systemCancelled → const ResultCode
-
const ResultCode('system-cancelled') - notReady → const ResultCode
-
const ResultCode('not-ready') - cancelled → const ResultCode
-
const ResultCode('cancelled') - insufficientBuffer → const ResultCode
-
const ResultCode('insufficient-buffer') - invalidHandle → const ResultCode
-
const ResultCode('invalid-handle') - invalidParameter → const ResultCode
-
const ResultCode('invalid-parameter') - invalidValue → const ResultCode
-
const ResultCode('invalid-value') - noMemory → const ResultCode
-
const ResultCode('no-memory') - timeout → const ResultCode
-
const ResultCode('timeout') - unknownReader → const ResultCode
-
const ResultCode('unknown-reader') - unsupportedFeature → const ResultCode
-
const ResultCode('unsupported-feature') - noReadersAvailable → const ResultCode
-
const ResultCode('no-readers-available') - serviceStopped → const ResultCode
-
const ResultCode('service-stopped') - noService → const ResultCode
-
const ResultCode('no-service') - commError → const ResultCode
-
const ResultCode('comm-error') - internalError → const ResultCode
-
const ResultCode('internal-error') - serverTooBusy → const ResultCode
-
const ResultCode('server-too-busy') - unexpected → const ResultCode
-
const ResultCode('unexpected') - shutdown → const ResultCode
-
const ResultCode('shutdown') - unknownCard → const ResultCode
-
const ResultCode('unknown-card') - unknown → const ResultCode
-
const ResultCode('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ResultCode> - A constant List of the values in this enum, in order of their declaration.