createTarget method
Creates a new page.
url The initial URL the page will be navigated to. An empty string indicates about:blank.
left Frame left origin in DIP (requires newWindow to be true or headless shell).
top Frame top origin in DIP (requires newWindow to be true or headless shell).
width Frame width in DIP (requires newWindow to be true or headless shell).
height Frame height in DIP (requires newWindow to be true or headless shell).
windowState Frame window state (requires newWindow to be true or headless shell).
Default is normal.
browserContextId The browser context to create the page in.
enableBeginFrameControl Whether BeginFrames for this target will be controlled via DevTools (headless shell only,
not supported on MacOS yet, false by default).
newWindow Whether to create a new Window or Tab (false by default, not supported by headless shell).
background Whether to create the target in background or foreground (false by default, not supported
by headless shell).
forTab Whether to create the target of type "tab".
hidden Whether to create a hidden target. The hidden target is observable via protocol, but not
present in the tab UI strip. Cannot be created with forTab: true, newWindow: true or
background: false. The life-time of the tab is limited to the life-time of the session.
focus If specified, the option is used to determine if the new target should
be focused or not. By default, the focus behavior depends on the
value of the background field. For example, background=false and focus=false
will result in the target tab being opened but the browser window remain
unchanged (if it was in the background, it will remain in the background)
and background=false with focus=undefined will result in the window being focused.
Using background: true and focus: true is not supported and will result in an error.
Returns: The id of the page opened.
Implementation
Future<TargetID> createTarget(
String url, {
int? left,
int? top,
int? width,
int? height,
WindowState? windowState,
browser.BrowserContextID? browserContextId,
bool? enableBeginFrameControl,
bool? newWindow,
bool? background,
bool? forTab,
bool? hidden,
bool? focus,
}) async {
var result = await _client.send('Target.createTarget', {
'url': url,
if (left != null) 'left': left,
if (top != null) 'top': top,
if (width != null) 'width': width,
if (height != null) 'height': height,
if (windowState != null) 'windowState': windowState,
if (browserContextId != null) 'browserContextId': browserContextId,
if (enableBeginFrameControl != null)
'enableBeginFrameControl': enableBeginFrameControl,
if (newWindow != null) 'newWindow': newWindow,
if (background != null) 'background': background,
if (forTab != null) 'forTab': forTab,
if (hidden != null) 'hidden': hidden,
if (focus != null) 'focus': focus,
});
return TargetID.fromJson(result['targetId'] as String);
}