Contains a bucket of collected trace events. When tracing is stopped collected events will be
sent as a sequence of dataCollected events followed by tracingComplete event.
Request a global memory dump.
deterministic Enables more deterministic results by forcing garbage collection
levelOfDetail Specifies level of details in memory dump. Defaults to "detailed".
Start trace events collection.
bufferUsageReportingInterval If set, the agent will issue bufferUsage events at this interval, specified in milliseconds
transferMode Whether to report trace events as series of dataCollected events or to save trace to a
stream (defaults to ReportEvents).
streamFormat Trace data format to use. This only applies when using ReturnAsStream
transfer mode (defaults to json).
streamCompression Compression format to use. This only applies when using ReturnAsStream
transfer mode (defaults to none)
perfettoConfig Base64-encoded serialized perfetto.protos.TraceConfig protobuf message
When specified, the parameters categories, options, traceConfig
are ignored.
tracingBackend Backend type (defaults to auto)
screenshotMaxSize Maximum width and height (in pixels) of each captured screenshot.
Only used when the disabled-by-default-devtools.screenshot category is
enabled. Defaults to 500. The combined memory footprint of screenshots
(screenshotMaxSize * screenshotMaxSize * 4 * screenshotMaxCount)
is clamped to the existing per-session budget.
screenshotMaxCount Maximum number of screenshots captured during a single tracing session.
Only used when the disabled-by-default-devtools.screenshot category is
enabled. Defaults to 450. Clamped together with screenshotMaxSize to
stay within the per-session screenshot memory budget.