setCredentialProperties method
Allows setting credential properties.
https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties
signCount Must be equal to or greater than -1.
If -1, the signature counter is removed from the credential, and every
assertion operation will report a value of 0.
See https://w3c.github.io/webauthn/#signature-counter
Implementation
Future<void> setCredentialProperties(
AuthenticatorId authenticatorId,
String credentialId, {
bool? backupEligibility,
bool? backupState,
int? activeCmtgKeyIndex,
bool? generateCmtgKeyOnNextOperation,
int? signCount,
}) async {
await _client.send('WebAuthn.setCredentialProperties', {
'authenticatorId': authenticatorId,
'credentialId': credentialId,
'backupEligibility': ?backupEligibility,
'backupState': ?backupState,
'activeCmtgKeyIndex': ?activeCmtgKeyIndex,
'generateCmtgKeyOnNextOperation': ?generateCmtgKeyOnNextOperation,
'signCount': ?signCount,
});
}