Tool class
Definition of a tool that can be invoked.
Constructors
-
Tool({required String name, required String description, Map<
String, dynamic> ? inputSchema, Annotation? annotations, required FrameId frameId, BackendNodeId? backendNodeId, StackTraceData? stackTrace}) -
Tool.fromJson(Map<
String, dynamic> json) -
factory
Properties
- annotations → Annotation?
-
Optional annotations for the tool.
final
- backendNodeId → BackendNodeId?
-
Optional node ID for declarative tools.
final
- description → String
-
Tool description.
final
- frameId → FrameId
-
Frame identifier associated with the tool registration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputSchema
→ Map<
String, dynamic> ? -
Schema for the tool's input parameters.
final
- name → String
-
Tool name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTraceData?
-
The stack trace at the time of the registration.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited