WebMCPApi class
Constructors
- WebMCPApi(Client _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onToolsAdded
→ Stream<
List< Tool> > -
Event fired when new tools are added.
no setter
-
onToolsRemoved
→ Stream<
List< Tool> > -
Event fired when tools are removed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enable(
) → Future< void> - Enables the WebMCP domain, allowing events to be sent. Enabling the domain will trigger a toolsAdded event for all currently registered tools.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited